
# Libraries
library(lme4)       # for lmer
library(lmerTest)   # to get p-value from lmer
library(robustlmm)  # for robust estimation of lmer handling outliers
library(sjPlot)     # for tab_model
library(parameters) # for demean
library(ggpubr)     # for ggline
library(haven)      # to read sas7bdat
library(data.table) # faster than data.frame
library(performance)# for "vif" for lmer fit
library(glmmTMB)    # for negative binomial
library(spaMM)      # for spatial modeling
library(scales)     # for rescale
library(DHARMa)     # for simulateResiduals

memory.limit(300000000000) # Increase memory limit

load("Z:/CDCK01/Analysis/ZipCode/HomeVisit/HomeVisit01_data_2.RData")

zt<-zt[,.(RptTr,CPop1,CPopT ,ZipCode,Yearf,USDA_RUC,CPopBPc,CPopBP,CPopHPc,CPopHP,Longitude,Latitude,SingleTc,UnempTc,NoHighTc,RPovTc,RPovT,CPovTc,HValueT10kc,HValueT10k,VacantTc,VacantT,FBornTc,FBornT,ChildPTc,ChildPT,ElderTc,ElderT,MalePTc,MalePT,DisablTc,DisablT,MoveTc,MoveT,DHS_HVPr,IDHS_EIr,MHV_C5k,DHS_HVPrc,IDHS_EIrc,MHV_C5kc,DHS_HVPr_within,IDHS_EIr_within,MHV_C5k_within,DHS_HVPrc_within,IDHS_EIrc_within,MHV_C5kc_within,DHS_HVPr_between,IDHS_EIr_between,MHV_C5k_between,DHS_HVPrc_between,IDHS_EIrc_between,MHV_C5kc_between)]
z1<-z1[,.(Rpt1r,CPop1 ,ZipCode,Yearf,USDA_RUC,CPopBPc,CPopBP,CPopHPc,CPopHP,Longitude,Latitude,SingleTc,UnempTc,NoHighTc,RPovTc,RPovT,CPov1c,HValueT10kc,HValueT10k,VacantTc,VacantT,FBornTc,FBornT,ChildPTc,ChildPT,ElderTc,ElderT,MalePTc,MalePT,DisablTc,DisablT,MoveTc,MoveT,DHS_HVPr,IDHS_EIr,MHV_C5k,DHS_HVPrc,IDHS_EIrc,MHV_C5kc,DHS_HVPr_within,IDHS_EIr_within,MHV_C5k_within,DHS_HVPrc_within,IDHS_EIrc_within,MHV_C5kc_within,DHS_HVPr_between,IDHS_EIr_between,MHV_C5k_between,DHS_HVPrc_between,IDHS_EIrc_between,MHV_C5kc_between)]
z2<-z2[,.(Rpt2r,CPop2 ,ZipCode,Yearf,USDA_RUC,CPopBPc,CPopBP,CPopHPc,CPopHP,Longitude,Latitude,SingleTc,UnempTc,NoHighTc,RPovTc,RPovT,CPov2c,HValueT10kc,HValueT10k,VacantTc,VacantT,FBornTc,FBornT,ChildPTc,ChildPT,ElderTc,ElderT,MalePTc,MalePT,DisablTc,DisablT,MoveTc,MoveT,DHS_HVPr,IDHS_EIr,MHV_C5k,DHS_HVPrc,IDHS_EIrc,MHV_C5kc,DHS_HVPr_within,IDHS_EIr_within,MHV_C5k_within,DHS_HVPrc_within,IDHS_EIrc_within,MHV_C5kc_within,DHS_HVPr_between,IDHS_EIr_between,MHV_C5k_between,DHS_HVPrc_between,IDHS_EIrc_between,MHV_C5kc_between)]
z3<-z3[,.(Rpt3r,CPop3 ,ZipCode,Yearf,USDA_RUC,CPopBPc,CPopBP,CPopHPc,CPopHP,Longitude,Latitude,SingleTc,UnempTc,NoHighTc,RPovTc,RPovT,CPov3c,HValueT10kc,HValueT10k,VacantTc,VacantT,FBornTc,FBornT,ChildPTc,ChildPT,ElderTc,ElderT,MalePTc,MalePT,DisablTc,DisablT,MoveTc,MoveT,DHS_HVPr,IDHS_EIr,MHV_C5k,DHS_HVPrc,IDHS_EIrc,MHV_C5kc,DHS_HVPr_within,IDHS_EIr_within,MHV_C5k_within,DHS_HVPrc_within,IDHS_EIrc_within,MHV_C5kc_within,DHS_HVPr_between,IDHS_EIr_between,MHV_C5k_between,DHS_HVPrc_between,IDHS_EIrc_between,MHV_C5kc_between)]
zm<-zm[,.(RptMr,CPopTM,ZipCode,Yearf,USDA_RUC,CPopBPc,CPopBP,CPopHPc,CPopHP,Longitude,Latitude,SingleTc,UnempTc,NoHighTc,RPovTc,RPovT,CPovTc,HValueT10kc,HValueT10k,VacantTc,VacantT,FBornTc,FBornT,ChildPTc,ChildPT,ElderTc,ElderT,MalePTc,MalePT,DisablTc,DisablT,MoveTc,MoveT,DHS_HVPr,IDHS_EIr,MHV_C5k,DHS_HVPrc,IDHS_EIrc,MHV_C5kc,DHS_HVPr_within,IDHS_EIr_within,MHV_C5k_within,DHS_HVPrc_within,IDHS_EIrc_within,MHV_C5kc_within,DHS_HVPr_between,IDHS_EIr_between,MHV_C5k_between,DHS_HVPrc_between,IDHS_EIrc_between,MHV_C5kc_between)]
zf<-zf[,.(RptFr,CPopTF,ZipCode,Yearf,USDA_RUC,CPopBPc,CPopBP,CPopHPc,CPopHP,Longitude,Latitude,SingleTc,UnempTc,NoHighTc,RPovTc,RPovT,CPovTc,HValueT10kc,HValueT10k,VacantTc,VacantT,FBornTc,FBornT,ChildPTc,ChildPT,ElderTc,ElderT,MalePTc,MalePT,DisablTc,DisablT,MoveTc,MoveT,DHS_HVPr,IDHS_EIr,MHV_C5k,DHS_HVPrc,IDHS_EIrc,MHV_C5kc,DHS_HVPr_within,IDHS_EIr_within,MHV_C5k_within,DHS_HVPrc_within,IDHS_EIrc_within,MHV_C5kc_within,DHS_HVPr_between,IDHS_EIr_between,MHV_C5k_between,DHS_HVPrc_between,IDHS_EIrc_between,MHV_C5kc_between)]
zn<-zn[,.(NegTr,CPopT ,ZipCode,Yearf,USDA_RUC,CPopBPc,CPopBP,CPopHPc,CPopHP,Longitude,Latitude,SingleTc,UnempTc,NoHighTc,RPovTc,RPovT,CPovTc,HValueT10kc,HValueT10k,VacantTc,VacantT,FBornTc,FBornT,ChildPTc,ChildPT,ElderTc,ElderT,MalePTc,MalePT,DisablTc,DisablT,MoveTc,MoveT,DHS_HVPr,IDHS_EIr,MHV_C5k,DHS_HVPrc,IDHS_EIrc,MHV_C5kc,DHS_HVPr_within,IDHS_EIr_within,MHV_C5k_within,DHS_HVPrc_within,IDHS_EIrc_within,MHV_C5kc_within,DHS_HVPr_between,IDHS_EIr_between,MHV_C5k_between,DHS_HVPrc_between,IDHS_EIrc_between,MHV_C5kc_between)]
zp<-zp[,.(PhyTr,CPopT ,ZipCode,Yearf,USDA_RUC,CPopBPc,CPopBP,CPopHPc,CPopHP,Longitude,Latitude,SingleTc,UnempTc,NoHighTc,RPovTc,RPovT,CPovTc,HValueT10kc,HValueT10k,VacantTc,VacantT,FBornTc,FBornT,ChildPTc,ChildPT,ElderTc,ElderT,MalePTc,MalePT,DisablTc,DisablT,MoveTc,MoveT,DHS_HVPr,IDHS_EIr,MHV_C5k,DHS_HVPrc,IDHS_EIrc,MHV_C5kc,DHS_HVPr_within,IDHS_EIr_within,MHV_C5k_within,DHS_HVPrc_within,IDHS_EIrc_within,MHV_C5kc_within,DHS_HVPr_between,IDHS_EIr_between,MHV_C5k_between,DHS_HVPrc_between,IDHS_EIrc_between,MHV_C5kc_between)]
zs<-zs[,.(SexTr,CPopT ,ZipCode,Yearf,USDA_RUC,CPopBPc,CPopBP,CPopHPc,CPopHP,Longitude,Latitude,SingleTc,UnempTc,NoHighTc,RPovTc,RPovT,CPovTc,HValueT10kc,HValueT10k,VacantTc,VacantT,FBornTc,FBornT,ChildPTc,ChildPT,ElderTc,ElderT,MalePTc,MalePT,DisablTc,DisablT,MoveTc,MoveT,DHS_HVPr,IDHS_EIr,MHV_C5k,DHS_HVPrc,IDHS_EIrc,MHV_C5kc,DHS_HVPr_within,IDHS_EIr_within,MHV_C5k_within,DHS_HVPrc_within,IDHS_EIrc_within,MHV_C5kc_within,DHS_HVPr_between,IDHS_EIr_between,MHV_C5k_between,DHS_HVPrc_between,IDHS_EIrc_between,MHV_C5kc_between)]
zw<-zw[,.(RptWr,CPopW ,ZipCode,Yearf,USDA_RUC,CPopBPc,CPopBP,CPopHPc,CPopHP,Longitude,Latitude,SingleWc,UnempWc,NoHighWc,RPovWc,RPovW,CPovWc,HValueT10kc,HValueT10k,VacantTc,VacantT,FBornWc,FBornW,ChildPWc,ChildPW,ElderWc,ElderW,MalePWc,MalePW,DisablWc,DisablW,MoveWc,MoveW,DHS_HVPr,IDHS_EIr,MHV_C5k,DHS_HVPrc,IDHS_EIrc,MHV_C5kc,DHS_HVPr_within,IDHS_EIr_within,MHV_C5k_within,DHS_HVPrc_within,IDHS_EIrc_within,MHV_C5kc_within,DHS_HVPr_between,IDHS_EIr_between,MHV_C5k_between,DHS_HVPrc_between,IDHS_EIrc_between,MHV_C5kc_between)]
zb<-zb[,.(RptBr,CPopB ,ZipCode,Yearf,USDA_RUC,CPopBPc,CPopBP,CPopHPc,CPopHP,Longitude,Latitude,SingleBc,UnempBc,NoHighBc,RPovBc,RPovB,CPovBc,HValueT10kc,HValueT10k,VacantTc,VacantT,FBornBc,FBornB,ChildPBc,ChildPB,ElderBc,ElderB,MalePBc,MalePB,DisablBc,DisablB,MoveBc,MoveB,DHS_HVPr,IDHS_EIr,MHV_C5k,DHS_HVPrc,IDHS_EIrc,MHV_C5kc,DHS_HVPr_within,IDHS_EIr_within,MHV_C5k_within,DHS_HVPrc_within,IDHS_EIrc_within,MHV_C5kc_within,DHS_HVPr_between,IDHS_EIr_between,MHV_C5k_between,DHS_HVPrc_between,IDHS_EIrc_between,MHV_C5kc_between)]
zh<-zh[,.(RptHr,CPopH ,ZipCode,Yearf,USDA_RUC,CPopBPc,CPopBP,CPopHPc,CPopHP,Longitude,Latitude,SingleHc,UnempHc,NoHighHc,RPovHc,RPovH,CPovHc,HValueT10kc,HValueT10k,VacantTc,VacantT,FBornHc,FBornH,ChildPHc,ChildPH,ElderHc,ElderH,MalePHc,MalePH,DisablHc,DisablH,MoveHc,MoveH,DHS_HVPr,IDHS_EIr,MHV_C5k,DHS_HVPrc,IDHS_EIrc,MHV_C5kc,DHS_HVPr_within,IDHS_EIr_within,MHV_C5k_within,DHS_HVPrc_within,IDHS_EIrc_within,MHV_C5kc_within,DHS_HVPr_between,IDHS_EIr_between,MHV_C5k_between,DHS_HVPrc_between,IDHS_EIrc_between,MHV_C5kc_between)]

rm(z0,zt1,z11,z21,z31,zm1,zf1,zn1,zp1,zs1,zw1,zb1,zh1,zt2,z12,z22,z32,zm2,zf2,zn2,zp2,zs2,zw2,zb2,zh2)

# MHV_C4k = # children served by MIECHV per 1k children aged 0-4 years
# MHV_C5k = # children served by MIECHV per 1k children aged 0-5 years

zt<-zt[!is.na(zt$HValueT10kc),] # N=3827 -> 3824
zw<-zw[!is.na(zw$HValueT10kc),] # N=3554 -> 3551
zb<-zb[!is.na(zb$HValueT10kc),] # N=1665 -> 1662
zh<-zh[!is.na(zh$HValueT10kc),] # N=2327 -> 2327
zm<-zm[!is.na(zm$HValueT10kc),] # N=3827 -> 3824
zf<-zf[!is.na(zf$HValueT10kc),] # N=3827 -> 3824
z1<-z1[!is.na(z1$HValueT10kc),] # N=3827 -> 3824
z2<-z2[!is.na(z2$HValueT10kc),] # N=3827 -> 3824
z3<-z3[!is.na(z3$HValueT10kc),] # N=3827 -> 3824
zn<-zn[!is.na(zn$HValueT10kc),] # N=3827 -> 3824
zp<-zp[!is.na(zp$HValueT10kc),] # N=3827 -> 3824
zs<-zs[!is.na(zs$HValueT10kc),] # N=3827 -> 3824

sum(zt$CPopT )/sum(z$CPopT )*100 # 90.91
sum(zw$CPopW )/sum(z$CPopW )*100 # 84.61
sum(zb$CPopB )/sum(z$CPopB )*100 # 93.79
sum(zh$CPopH )/sum(z$CPopH )*100 # 95.23
sum(zm$CPopTM)/sum(z$CPopTM)*100 # 90.83
sum(zf$CPopTF)/sum(z$CPopTF)*100 # 90.98
sum(z1$CPop1 )/sum(z$CPop1 )*100 # 91.35
sum(z2$CPop2 )/sum(z$CPop2 )*100 # 90.92
sum(z3$CPop3 )/sum(z$CPop3 )*100 # 90.46

zt2<-zt[zt$Yearf%in%c(2015,2016,2017,2018),] # N=3824 -> 1896
zw2<-zw[zw$Yearf%in%c(2015,2016,2017,2018),] # N=3554 -> 1768
zb2<-zb[zb$Yearf%in%c(2015,2016,2017,2018),] # N=1665 ->  823
zh2<-zh[zh$Yearf%in%c(2015,2016,2017,2018),] # N=2327 -> 1185
zm2<-zm[zm$Yearf%in%c(2015,2016,2017,2018),] # N=3827 -> 1896
zf2<-zf[zf$Yearf%in%c(2015,2016,2017,2018),] # N=3827 -> 1896
z12<-z1[z1$Yearf%in%c(2015,2016,2017,2018),] # N=3827 -> 1896
z22<-z2[z2$Yearf%in%c(2015,2016,2017,2018),] # N=3827 -> 1896
z32<-z3[z3$Yearf%in%c(2015,2016,2017,2018),] # N=3827 -> 1896
zn2<-zn[zn$Yearf%in%c(2015,2016,2017,2018),] # N=3827 -> 1896
zp2<-zp[zp$Yearf%in%c(2015,2016,2017,2018),] # N=3827 -> 1896
zs2<-zs[zs$Yearf%in%c(2015,2016,2017,2018),] # N=3827 -> 1896

summary(zt$DHS_HVPr)
summary(zt$DHS_HVPr[zt$Yearf%in%c(2011,2012,2013,2014)])
summary(zt$DHS_HVPr[zt$Yearf%in%c(2015,2016,2017,2018)])
summary(zt2$MHV_C5k)

plot(density(zt$DHS_HVPr))
plot(density(zt2$MHV_C5k))

zt[ ,list(mean=mean(DHS_HVPr)), by=Yearf]
zt2[ ,list(mean=mean(MHV_C5k )), by=Yearf]

mean(zt$RptTr) # 44.728
mean(zn$NegTr) # 22.829
mean(zp$PhyTr) # 10.509
mean(zs$SexTr) # 5.357

mean(zt$RptTr) - mean(zn$NegTr) - mean(zp$PhyTr) - mean(zs$SexTr) # 6.033

quantile(zt$DHS_HVPr,c(0.1,0.25,0.75,0.9,0.92,0.99,0.995,1))

summary(zt$DHS_HVPr)
summary((zt$DHS_HVPr*zt$CPop1)/zt$CPopT)


mean(zt$DHS_HVPr)*sum(zt$CPop1)
summary(zt$DHS_HVPr)

###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
# Testing for Spatial Autocorrelation in the Residuals
# Testing for Spatial Autocorrelation in the Residuals
# Testing for Spatial Autocorrelation in the Residuals
# Testing for Spatial Autocorrelation in the Residuals
# Testing for Spatial Autocorrelation in the Residuals
# Testing for Spatial Autocorrelation in the Residuals
# Testing for Spatial Autocorrelation in the Residuals
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################

zt11<-zt[zt$Year==2011,]
zt12<-zt[zt$Year==2012,]
zt13<-zt[zt$Year==2013,]
zt14<-zt[zt$Year==2014,]
zt15<-zt[zt$Year==2015,]
zt16<-zt[zt$Year==2016,]
zt17<-zt[zt$Year==2017,]
zt18<-zt[zt$Year==2018,]
mta11 <-lm(RptTr~1,data=zt11)
mta12 <-lm(RptTr~1,data=zt12)
mta13 <-lm(RptTr~1,data=zt13)
mta14 <-lm(RptTr~1,data=zt14)
mta15 <-lm(RptTr~1,data=zt15)
mta16 <-lm(RptTr~1,data=zt16)
mta17 <-lm(RptTr~1,data=zt17)
mta18 <-lm(RptTr~1,data=zt18)
mtb11a<-lm(RptTr~DHS_HVPrc_within+DHS_HVPrc_between,data=zt11)
mtb12a<-lm(RptTr~DHS_HVPrc_within+DHS_HVPrc_between,data=zt12)
mtb13a<-lm(RptTr~DHS_HVPrc_within+DHS_HVPrc_between,data=zt13)
mtb14a<-lm(RptTr~DHS_HVPrc_within+DHS_HVPrc_between,data=zt14)
mtb15a<-lm(RptTr~DHS_HVPrc_within+DHS_HVPrc_between,data=zt15)
mtb16a<-lm(RptTr~DHS_HVPrc_within+DHS_HVPrc_between,data=zt16)
mtb17a<-lm(RptTr~DHS_HVPrc_within+DHS_HVPrc_between,data=zt17)
mtb18a<-lm(RptTr~DHS_HVPrc_within+DHS_HVPrc_between,data=zt18)
mtb11b<-lm(RptTr~IDHS_EIrc_within+IDHS_EIrc_between,data=zt11)
mtb12b<-lm(RptTr~IDHS_EIrc_within+IDHS_EIrc_between,data=zt12)
mtb13b<-lm(RptTr~IDHS_EIrc_within+IDHS_EIrc_between,data=zt13)
mtb14b<-lm(RptTr~IDHS_EIrc_within+IDHS_EIrc_between,data=zt14)
mtb15b<-lm(RptTr~IDHS_EIrc_within+IDHS_EIrc_between,data=zt15)
mtb16b<-lm(RptTr~IDHS_EIrc_within+IDHS_EIrc_between,data=zt16)
mtb17b<-lm(RptTr~IDHS_EIrc_within+IDHS_EIrc_between,data=zt17)
mtb18b<-lm(RptTr~IDHS_EIrc_within+IDHS_EIrc_between,data=zt18)
mtb11c<-lm(RptTr~MHV_C5kc_within +MHV_C5kc_between ,data=zt11)
mtb12c<-lm(RptTr~MHV_C5kc_within +MHV_C5kc_between ,data=zt12)
mtb13c<-lm(RptTr~MHV_C5kc_within +MHV_C5kc_between ,data=zt13)
mtb14c<-lm(RptTr~MHV_C5kc_within +MHV_C5kc_between ,data=zt14)
mtb15c<-lm(RptTr~MHV_C5kc_within +MHV_C5kc_between ,data=zt15)
mtb16c<-lm(RptTr~MHV_C5kc_within +MHV_C5kc_between ,data=zt16)
mtb17c<-lm(RptTr~MHV_C5kc_within +MHV_C5kc_between ,data=zt17)
mtb18c<-lm(RptTr~MHV_C5kc_within +MHV_C5kc_between ,data=zt18)
mtc11a<-lm(RptTr~DHS_HVPrc_within+DHS_HVPrc_between+USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc,data=zt11)
mtc12a<-lm(RptTr~DHS_HVPrc_within+DHS_HVPrc_between+USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc,data=zt12)
mtc13a<-lm(RptTr~DHS_HVPrc_within+DHS_HVPrc_between+USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc,data=zt13)
mtc14a<-lm(RptTr~DHS_HVPrc_within+DHS_HVPrc_between+USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc,data=zt14)
mtc15a<-lm(RptTr~DHS_HVPrc_within+DHS_HVPrc_between+USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc,data=zt15)
mtc16a<-lm(RptTr~DHS_HVPrc_within+DHS_HVPrc_between+USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc,data=zt16)
mtc17a<-lm(RptTr~DHS_HVPrc_within+DHS_HVPrc_between+USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc,data=zt17)
mtc18a<-lm(RptTr~DHS_HVPrc_within+DHS_HVPrc_between+USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc,data=zt18)
mtc11b<-lm(RptTr~IDHS_EIrc_within+IDHS_EIrc_between+USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc,data=zt11)
mtc12b<-lm(RptTr~IDHS_EIrc_within+IDHS_EIrc_between+USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc,data=zt12)
mtc13b<-lm(RptTr~IDHS_EIrc_within+IDHS_EIrc_between+USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc,data=zt13)
mtc14b<-lm(RptTr~IDHS_EIrc_within+IDHS_EIrc_between+USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc,data=zt14)
mtc15b<-lm(RptTr~IDHS_EIrc_within+IDHS_EIrc_between+USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc,data=zt15)
mtc16b<-lm(RptTr~IDHS_EIrc_within+IDHS_EIrc_between+USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc,data=zt16)
mtc17b<-lm(RptTr~IDHS_EIrc_within+IDHS_EIrc_between+USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc,data=zt17)
mtc18b<-lm(RptTr~IDHS_EIrc_within+IDHS_EIrc_between+USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc,data=zt18)
mtc11c<-lm(RptTr~MHV_C5kc_within +MHV_C5kc_between +USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc,data=zt11)
mtc12c<-lm(RptTr~MHV_C5kc_within +MHV_C5kc_between +USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc,data=zt12)
mtc13c<-lm(RptTr~MHV_C5kc_within +MHV_C5kc_between +USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc,data=zt13)
mtc14c<-lm(RptTr~MHV_C5kc_within +MHV_C5kc_between +USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc,data=zt14)
mtc15c<-lm(RptTr~MHV_C5kc_within +MHV_C5kc_between +USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc,data=zt15)
mtc16c<-lm(RptTr~MHV_C5kc_within +MHV_C5kc_between +USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc,data=zt16)
mtc17c<-lm(RptTr~MHV_C5kc_within +MHV_C5kc_between +USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc,data=zt17)
mtc18c<-lm(RptTr~MHV_C5kc_within +MHV_C5kc_between +USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc,data=zt18)

sta11 <-simulateResiduals(mta11 )
sta12 <-simulateResiduals(mta12 )
sta13 <-simulateResiduals(mta13 )
sta14 <-simulateResiduals(mta14 )
sta15 <-simulateResiduals(mta15 )
sta16 <-simulateResiduals(mta16 )
sta17 <-simulateResiduals(mta17 )
sta18 <-simulateResiduals(mta18 )
stb11a<-simulateResiduals(mtb11a)
stb12a<-simulateResiduals(mtb12a)
stb13a<-simulateResiduals(mtb13a)
stb14a<-simulateResiduals(mtb14a)
stb15a<-simulateResiduals(mtb15a)
stb16a<-simulateResiduals(mtb16a)
stb17a<-simulateResiduals(mtb17a)
stb18a<-simulateResiduals(mtb18a)
stb11b<-simulateResiduals(mtb11b)
stb12b<-simulateResiduals(mtb12b)
stb13b<-simulateResiduals(mtb13b)
stb14b<-simulateResiduals(mtb14b)
stb15b<-simulateResiduals(mtb15b)
stb16b<-simulateResiduals(mtb16b)
stb17b<-simulateResiduals(mtb17b)
stb18b<-simulateResiduals(mtb18b)
stb11c<-simulateResiduals(mtb11c)
stb12c<-simulateResiduals(mtb12c)
stb13c<-simulateResiduals(mtb13c)
stb14c<-simulateResiduals(mtb14c)
stb15c<-simulateResiduals(mtb15c)
stb16c<-simulateResiduals(mtb16c)
stb17c<-simulateResiduals(mtb17c)
stb18c<-simulateResiduals(mtb18c)
stc11a<-simulateResiduals(mtc11a)
stc12a<-simulateResiduals(mtc12a)
stc13a<-simulateResiduals(mtc13a)
stc14a<-simulateResiduals(mtc14a)
stc15a<-simulateResiduals(mtc15a)
stc16a<-simulateResiduals(mtc16a)
stc17a<-simulateResiduals(mtc17a)
stc18a<-simulateResiduals(mtc18a)
stc11b<-simulateResiduals(mtc11b)
stc12b<-simulateResiduals(mtc12b)
stc13b<-simulateResiduals(mtc13b)
stc14b<-simulateResiduals(mtc14b)
stc15b<-simulateResiduals(mtc15b)
stc16b<-simulateResiduals(mtc16b)
stc17b<-simulateResiduals(mtc17b)
stc18b<-simulateResiduals(mtc18b)
stc11c<-simulateResiduals(mtc11c)
stc12c<-simulateResiduals(mtc12c)
stc13c<-simulateResiduals(mtc13c)
stc14c<-simulateResiduals(mtc14c)
stc15c<-simulateResiduals(mtc15c)
stc16c<-simulateResiduals(mtc16c)
stc17c<-simulateResiduals(mtc17c)
stc18c<-simulateResiduals(mtc18c)

tta11 <-testSpatialAutocorrelation(sta11 ,x=zt11$Longitude,y=zt11$Latitude,plot=FALSE)
tta12 <-testSpatialAutocorrelation(sta12 ,x=zt12$Longitude,y=zt12$Latitude,plot=FALSE)
tta13 <-testSpatialAutocorrelation(sta13 ,x=zt13$Longitude,y=zt13$Latitude,plot=FALSE)
tta14 <-testSpatialAutocorrelation(sta14 ,x=zt14$Longitude,y=zt14$Latitude,plot=FALSE)
tta15 <-testSpatialAutocorrelation(sta15 ,x=zt15$Longitude,y=zt15$Latitude,plot=FALSE)
tta16 <-testSpatialAutocorrelation(sta16 ,x=zt16$Longitude,y=zt16$Latitude,plot=FALSE)
tta17 <-testSpatialAutocorrelation(sta17 ,x=zt17$Longitude,y=zt17$Latitude,plot=FALSE)
tta18 <-testSpatialAutocorrelation(sta18 ,x=zt18$Longitude,y=zt18$Latitude,plot=FALSE)
ttb11a<-testSpatialAutocorrelation(stb11a,x=zt11$Longitude,y=zt11$Latitude,plot=FALSE)
ttb12a<-testSpatialAutocorrelation(stb12a,x=zt12$Longitude,y=zt12$Latitude,plot=FALSE)
ttb13a<-testSpatialAutocorrelation(stb13a,x=zt13$Longitude,y=zt13$Latitude,plot=FALSE)
ttb14a<-testSpatialAutocorrelation(stb14a,x=zt14$Longitude,y=zt14$Latitude,plot=FALSE)
ttb15a<-testSpatialAutocorrelation(stb15a,x=zt15$Longitude,y=zt15$Latitude,plot=FALSE)
ttb16a<-testSpatialAutocorrelation(stb16a,x=zt16$Longitude,y=zt16$Latitude,plot=FALSE)
ttb17a<-testSpatialAutocorrelation(stb17a,x=zt17$Longitude,y=zt17$Latitude,plot=FALSE)
ttb18a<-testSpatialAutocorrelation(stb18a,x=zt18$Longitude,y=zt18$Latitude,plot=FALSE)
ttb11b<-testSpatialAutocorrelation(stb11b,x=zt11$Longitude,y=zt11$Latitude,plot=FALSE)
ttb12b<-testSpatialAutocorrelation(stb12b,x=zt12$Longitude,y=zt12$Latitude,plot=FALSE)
ttb13b<-testSpatialAutocorrelation(stb13b,x=zt13$Longitude,y=zt13$Latitude,plot=FALSE)
ttb14b<-testSpatialAutocorrelation(stb14b,x=zt14$Longitude,y=zt14$Latitude,plot=FALSE)
ttb15b<-testSpatialAutocorrelation(stb15b,x=zt15$Longitude,y=zt15$Latitude,plot=FALSE)
ttb16b<-testSpatialAutocorrelation(stb16b,x=zt16$Longitude,y=zt16$Latitude,plot=FALSE)
ttb17b<-testSpatialAutocorrelation(stb17b,x=zt17$Longitude,y=zt17$Latitude,plot=FALSE)
ttb18b<-testSpatialAutocorrelation(stb18b,x=zt18$Longitude,y=zt18$Latitude,plot=FALSE)
ttb11c<-testSpatialAutocorrelation(stb11c,x=zt11$Longitude,y=zt11$Latitude,plot=FALSE)
ttb12c<-testSpatialAutocorrelation(stb12c,x=zt12$Longitude,y=zt12$Latitude,plot=FALSE)
ttb13c<-testSpatialAutocorrelation(stb13c,x=zt13$Longitude,y=zt13$Latitude,plot=FALSE)
ttb14c<-testSpatialAutocorrelation(stb14c,x=zt14$Longitude,y=zt14$Latitude,plot=FALSE)
ttb15c<-testSpatialAutocorrelation(stb15c,x=zt15$Longitude,y=zt15$Latitude,plot=FALSE)
ttb16c<-testSpatialAutocorrelation(stb16c,x=zt16$Longitude,y=zt16$Latitude,plot=FALSE)
ttb17c<-testSpatialAutocorrelation(stb17c,x=zt17$Longitude,y=zt17$Latitude,plot=FALSE)
ttb18c<-testSpatialAutocorrelation(stb18c,x=zt18$Longitude,y=zt18$Latitude,plot=FALSE)
ttc11a<-testSpatialAutocorrelation(stc11a,x=zt11$Longitude,y=zt11$Latitude,plot=FALSE)
ttc12a<-testSpatialAutocorrelation(stc12a,x=zt12$Longitude,y=zt12$Latitude,plot=FALSE)
ttc13a<-testSpatialAutocorrelation(stc13a,x=zt13$Longitude,y=zt13$Latitude,plot=FALSE)
ttc14a<-testSpatialAutocorrelation(stc14a,x=zt14$Longitude,y=zt14$Latitude,plot=FALSE)
ttc15a<-testSpatialAutocorrelation(stc15a,x=zt15$Longitude,y=zt15$Latitude,plot=FALSE)
ttc16a<-testSpatialAutocorrelation(stc16a,x=zt16$Longitude,y=zt16$Latitude,plot=FALSE)
ttc17a<-testSpatialAutocorrelation(stc17a,x=zt17$Longitude,y=zt17$Latitude,plot=FALSE)
ttc18a<-testSpatialAutocorrelation(stc18a,x=zt18$Longitude,y=zt18$Latitude,plot=FALSE)
ttc11b<-testSpatialAutocorrelation(stc11b,x=zt11$Longitude,y=zt11$Latitude,plot=FALSE)
ttc12b<-testSpatialAutocorrelation(stc12b,x=zt12$Longitude,y=zt12$Latitude,plot=FALSE)
ttc13b<-testSpatialAutocorrelation(stc13b,x=zt13$Longitude,y=zt13$Latitude,plot=FALSE)
ttc14b<-testSpatialAutocorrelation(stc14b,x=zt14$Longitude,y=zt14$Latitude,plot=FALSE)
ttc15b<-testSpatialAutocorrelation(stc15b,x=zt15$Longitude,y=zt15$Latitude,plot=FALSE)
ttc16b<-testSpatialAutocorrelation(stc16b,x=zt16$Longitude,y=zt16$Latitude,plot=FALSE)
ttc17b<-testSpatialAutocorrelation(stc17b,x=zt17$Longitude,y=zt17$Latitude,plot=FALSE)
ttc18b<-testSpatialAutocorrelation(stc18b,x=zt18$Longitude,y=zt18$Latitude,plot=FALSE)
ttc11c<-testSpatialAutocorrelation(stc11c,x=zt11$Longitude,y=zt11$Latitude,plot=FALSE)
ttc12c<-testSpatialAutocorrelation(stc12c,x=zt12$Longitude,y=zt12$Latitude,plot=FALSE)
ttc13c<-testSpatialAutocorrelation(stc13c,x=zt13$Longitude,y=zt13$Latitude,plot=FALSE)
ttc14c<-testSpatialAutocorrelation(stc14c,x=zt14$Longitude,y=zt14$Latitude,plot=FALSE)
ttc15c<-testSpatialAutocorrelation(stc15c,x=zt15$Longitude,y=zt15$Latitude,plot=FALSE)
ttc16c<-testSpatialAutocorrelation(stc16c,x=zt16$Longitude,y=zt16$Latitude,plot=FALSE)
ttc17c<-testSpatialAutocorrelation(stc17c,x=zt17$Longitude,y=zt17$Latitude,plot=FALSE)
ttc18c<-testSpatialAutocorrelation(stc18c,x=zt18$Longitude,y=zt18$Latitude,plot=FALSE)

zt11$resida <-resid(mta11 )
zt12$resida <-resid(mta12 )
zt13$resida <-resid(mta13 )
zt14$resida <-resid(mta14 )
zt15$resida <-resid(mta15 )
zt16$resida <-resid(mta16 )
zt17$resida <-resid(mta17 )
zt18$resida <-resid(mta18 )
zt11$residba<-resid(mtb11a)
zt12$residba<-resid(mtb12a)
zt13$residba<-resid(mtb13a)
zt14$residba<-resid(mtb14a)
zt15$residba<-resid(mtb15a)
zt16$residba<-resid(mtb16a)
zt17$residba<-resid(mtb17a)
zt18$residba<-resid(mtb18a)
zt11$residbb<-resid(mtb11b)
zt12$residbb<-resid(mtb12b)
zt13$residbb<-resid(mtb13b)
zt14$residbb<-resid(mtb14b)
zt15$residbb<-resid(mtb15b)
zt16$residbb<-resid(mtb16b)
zt17$residbb<-resid(mtb17b)
zt18$residbb<-resid(mtb18b)
zt11$residbc<-resid(mtb11c)
zt12$residbc<-resid(mtb12c)
zt13$residbc<-resid(mtb13c)
zt14$residbc<-resid(mtb14c)
zt15$residbc<-resid(mtb15c)
zt16$residbc<-resid(mtb16c)
zt17$residbc<-resid(mtb17c)
zt18$residbc<-resid(mtb18c)
zt11$residca<-resid(mtc11a)
zt12$residca<-resid(mtc12a)
zt13$residca<-resid(mtc13a)
zt14$residca<-resid(mtc14a)
zt15$residca<-resid(mtc15a)
zt16$residca<-resid(mtc16a)
zt17$residca<-resid(mtc17a)
zt18$residca<-resid(mtc18a)
zt11$residcb<-resid(mtc11b)
zt12$residcb<-resid(mtc12b)
zt13$residcb<-resid(mtc13b)
zt14$residcb<-resid(mtc14b)
zt15$residcb<-resid(mtc15b)
zt16$residcb<-resid(mtc16b)
zt17$residcb<-resid(mtc17b)
zt18$residcb<-resid(mtc18b)
zt11$residcc<-resid(mtc11c)
zt12$residcc<-resid(mtc12c)
zt13$residcc<-resid(mtc13c)
zt14$residcc<-resid(mtc14c)
zt15$residcc<-resid(mtc15c)
zt16$residcc<-resid(mtc16c)
zt17$residcc<-resid(mtc17c)
zt18$residcc<-resid(mtc18c)

# ggplot(zt11,aes(x=Longitude,y=Latitude,size=resida))+geom_point()+scale_size_continuous(range=c(0.1,7))
# ggplot(zt12,aes(x=Longitude,y=Latitude,size=resida))+geom_point()+scale_size_continuous(range=c(0.1,7))
# ggplot(zt13,aes(x=Longitude,y=Latitude,size=resida))+geom_point()+scale_size_continuous(range=c(0.1,7))
# ggplot(zt14,aes(x=Longitude,y=Latitude,size=resida))+geom_point()+scale_size_continuous(range=c(0.1,7))
# ggplot(zt15,aes(x=Longitude,y=Latitude,size=resida))+geom_point()+scale_size_continuous(range=c(0.1,7))
# ggplot(zt16,aes(x=Longitude,y=Latitude,size=resida))+geom_point()+scale_size_continuous(range=c(0.1,7))
# ggplot(zt17,aes(x=Longitude,y=Latitude,size=resida))+geom_point()+scale_size_continuous(range=c(0.1,7))
# ggplot(zt18,aes(x=Longitude,y=Latitude,size=resida))+geom_point()+scale_size_continuous(range=c(0.1,7))
# ggplot(zt11,aes(x=Longitude,y=Latitude,size=residb))+geom_point()+scale_size_continuous(range=c(0.1,7))
# ggplot(zt12,aes(x=Longitude,y=Latitude,size=residb))+geom_point()+scale_size_continuous(range=c(0.1,7))
# ggplot(zt13,aes(x=Longitude,y=Latitude,size=residb))+geom_point()+scale_size_continuous(range=c(0.1,7))
# ggplot(zt14,aes(x=Longitude,y=Latitude,size=residb))+geom_point()+scale_size_continuous(range=c(0.1,7))
# ggplot(zt15,aes(x=Longitude,y=Latitude,size=residb))+geom_point()+scale_size_continuous(range=c(0.1,7))
# ggplot(zt16,aes(x=Longitude,y=Latitude,size=residb))+geom_point()+scale_size_continuous(range=c(0.1,7))
# ggplot(zt17,aes(x=Longitude,y=Latitude,size=residb))+geom_point()+scale_size_continuous(range=c(0.1,7))
# ggplot(zt18,aes(x=Longitude,y=Latitude,size=residb))+geom_point()+scale_size_continuous(range=c(0.1,7))
# ggplot(zt11,aes(x=Longitude,y=Latitude,size=residc))+geom_point()+scale_size_continuous(range=c(0.1,7))
# ggplot(zt12,aes(x=Longitude,y=Latitude,size=residc))+geom_point()+scale_size_continuous(range=c(0.1,7))
# ggplot(zt13,aes(x=Longitude,y=Latitude,size=residc))+geom_point()+scale_size_continuous(range=c(0.1,7))
# ggplot(zt14,aes(x=Longitude,y=Latitude,size=residc))+geom_point()+scale_size_continuous(range=c(0.1,7))
# ggplot(zt15,aes(x=Longitude,y=Latitude,size=residc))+geom_point()+scale_size_continuous(range=c(0.1,7))
# ggplot(zt16,aes(x=Longitude,y=Latitude,size=residc))+geom_point()+scale_size_continuous(range=c(0.1,7))
# ggplot(zt17,aes(x=Longitude,y=Latitude,size=residc))+geom_point()+scale_size_continuous(range=c(0.1,7))
# ggplot(zt18,aes(x=Longitude,y=Latitude,size=residc))+geom_point()+scale_size_continuous(range=c(0.1,7))
# ggplot(zt11,aes(x=Longitude,y=Latitude,size=residd))+geom_point()+scale_size_continuous(range=c(0.1,7))
# ggplot(zt12,aes(x=Longitude,y=Latitude,size=residd))+geom_point()+scale_size_continuous(range=c(0.1,7))
# ggplot(zt13,aes(x=Longitude,y=Latitude,size=residd))+geom_point()+scale_size_continuous(range=c(0.1,7))
# ggplot(zt14,aes(x=Longitude,y=Latitude,size=residd))+geom_point()+scale_size_continuous(range=c(0.1,7))
# ggplot(zt15,aes(x=Longitude,y=Latitude,size=residd))+geom_point()+scale_size_continuous(range=c(0.1,7))
# ggplot(zt16,aes(x=Longitude,y=Latitude,size=residd))+geom_point()+scale_size_continuous(range=c(0.1,7))
# ggplot(zt17,aes(x=Longitude,y=Latitude,size=residd))+geom_point()+scale_size_continuous(range=c(0.1,7))
# ggplot(zt18,aes(x=Longitude,y=Latitude,size=residd))+geom_point()+scale_size_continuous(range=c(0.1,7))

# plot(sta11)
# plot(sta12)
# plot(sta13)
# plot(sta14)
# plot(sta15)
# plot(sta16)
# plot(sta17)
# plot(sta18)
# plot(stb11)
# plot(stb12)
# plot(stb13)
# plot(stb14)
# plot(stb15)
# plot(stb16)
# plot(stb17)
# plot(stb18)
# plot(stc11)
# plot(stc12)
# plot(stc13)
# plot(stc14)
# plot(stc15)
# plot(stc16)
# plot(stc17)
# plot(stc18)
# plot(std11)
# plot(std12)
# plot(std13)
# plot(std14)
# plot(std15)
# plot(std16)
# plot(std17)
# plot(std18)

TestSA<-data.table(Year=c(2011:2018),
                   ObservedA =c(tta11[[1]][1],tta12[[1]][1],tta13[[1]][1],tta14[[1]][1],tta15[[1]][1],tta16[[1]][1],tta17[[1]][1],tta18[[1]][1]),
                   ExpectedA =c(tta11[[1]][2],tta12[[1]][2],tta13[[1]][2],tta14[[1]][2],tta15[[1]][2],tta16[[1]][2],tta17[[1]][2],tta18[[1]][2]),
                   SDA       =c(tta11[[1]][3],tta12[[1]][3],tta13[[1]][3],tta14[[1]][3],tta15[[1]][3],tta16[[1]][3],tta17[[1]][3],tta18[[1]][3]),
                   P_valueA  =c(tta11[[4]]   ,tta12[[4]]   ,tta13[[4]]   ,tta14[[4]]   ,tta15[[4]]   ,tta16[[4]]   ,tta17[[4]]   ,tta18[[4]]   ),
                   ObservedBa=c(ttb11a[[1]][1],ttb12a[[1]][1],ttb13a[[1]][1],ttb14a[[1]][1],ttb15a[[1]][1],ttb16a[[1]][1],ttb17a[[1]][1],ttb18a[[1]][1]),
                   ExpectedBa=c(ttb11a[[1]][2],ttb12a[[1]][2],ttb13a[[1]][2],ttb14a[[1]][2],ttb15a[[1]][2],ttb16a[[1]][2],ttb17a[[1]][2],ttb18a[[1]][2]),
                   SDBa      =c(ttb11a[[1]][3],ttb12a[[1]][3],ttb13a[[1]][3],ttb14a[[1]][3],ttb15a[[1]][3],ttb16a[[1]][3],ttb17a[[1]][3],ttb18a[[1]][3]),
                   P_valueBa =c(ttb11a[[4]]   ,ttb12a[[4]]   ,ttb13a[[4]]   ,ttb14a[[4]]   ,ttb15a[[4]]   ,ttb16a[[4]]   ,ttb17a[[4]]   ,ttb18a[[4]]   ),
                   ObservedBb=c(ttb11b[[1]][1],ttb12b[[1]][1],ttb13b[[1]][1],ttb14b[[1]][1],ttb15b[[1]][1],ttb16b[[1]][1],ttb17b[[1]][1],ttb18b[[1]][1]),
                   ExpectedBb=c(ttb11b[[1]][2],ttb12b[[1]][2],ttb13b[[1]][2],ttb14b[[1]][2],ttb15b[[1]][2],ttb16b[[1]][2],ttb17b[[1]][2],ttb18b[[1]][2]),
                   SDBb      =c(ttb11b[[1]][3],ttb12b[[1]][3],ttb13b[[1]][3],ttb14b[[1]][3],ttb15b[[1]][3],ttb16b[[1]][3],ttb17b[[1]][3],ttb18b[[1]][3]),
                   P_valueBb =c(ttb11b[[4]]   ,ttb12b[[4]]   ,ttb13b[[4]]   ,ttb14b[[4]]   ,ttb15b[[4]]   ,ttb16b[[4]]   ,ttb17b[[4]]   ,ttb18b[[4]]   ),
                   ObservedBc=c(ttb11c[[1]][1],ttb12c[[1]][1],ttb13c[[1]][1],ttb14c[[1]][1],ttb15c[[1]][1],ttb16c[[1]][1],ttb17c[[1]][1],ttb18c[[1]][1]),
                   ExpectedBc=c(ttb11c[[1]][2],ttb12c[[1]][2],ttb13c[[1]][2],ttb14c[[1]][2],ttb15c[[1]][2],ttb16c[[1]][2],ttb17c[[1]][2],ttb18c[[1]][2]),
                   SDBc      =c(ttb11c[[1]][3],ttb12c[[1]][3],ttb13c[[1]][3],ttb14c[[1]][3],ttb15c[[1]][3],ttb16c[[1]][3],ttb17c[[1]][3],ttb18c[[1]][3]),
                   P_valueBc =c(ttb11c[[4]]   ,ttb12c[[4]]   ,ttb13c[[4]]   ,ttb14c[[4]]   ,ttb15c[[4]]   ,ttb16c[[4]]   ,ttb17c[[4]]   ,ttb18c[[4]]   ),
                   ObservedCa=c(ttc11a[[1]][1],ttc12a[[1]][1],ttc13a[[1]][1],ttc14a[[1]][1],ttc15a[[1]][1],ttc16a[[1]][1],ttc17a[[1]][1],ttc18a[[1]][1]),
                   ExpectedCa=c(ttc11a[[1]][2],ttc12a[[1]][2],ttc13a[[1]][2],ttc14a[[1]][2],ttc15a[[1]][2],ttc16a[[1]][2],ttc17a[[1]][2],ttc18a[[1]][2]),
                   SDCa      =c(ttc11a[[1]][3],ttc12a[[1]][3],ttc13a[[1]][3],ttc14a[[1]][3],ttc15a[[1]][3],ttc16a[[1]][3],ttc17a[[1]][3],ttc18a[[1]][3]),
                   P_valueCa =c(ttc11a[[4]]   ,ttc12a[[4]]   ,ttc13a[[4]]   ,ttc14a[[4]]   ,ttc15a[[4]]   ,ttc16a[[4]]   ,ttc17a[[4]]   ,ttc18a[[4]]   ),
                   ObservedCb=c(ttc11b[[1]][1],ttc12b[[1]][1],ttc13b[[1]][1],ttc14b[[1]][1],ttc15b[[1]][1],ttc16b[[1]][1],ttc17b[[1]][1],ttc18b[[1]][1]),
                   ExpectedCb=c(ttc11b[[1]][2],ttc12b[[1]][2],ttc13b[[1]][2],ttc14b[[1]][2],ttc15b[[1]][2],ttc16b[[1]][2],ttc17b[[1]][2],ttc18b[[1]][2]),
                   SDCb      =c(ttc11b[[1]][3],ttc12b[[1]][3],ttc13b[[1]][3],ttc14b[[1]][3],ttc15b[[1]][3],ttc16b[[1]][3],ttc17b[[1]][3],ttc18b[[1]][3]),
                   P_valueCb =c(ttc11b[[4]]   ,ttc12b[[4]]   ,ttc13b[[4]]   ,ttc14b[[4]]   ,ttc15b[[4]]   ,ttc16b[[4]]   ,ttc17b[[4]]   ,ttc18b[[4]]   ),
                   ObservedCc=c(ttc11c[[1]][1],ttc12c[[1]][1],ttc13c[[1]][1],ttc14c[[1]][1],ttc15c[[1]][1],ttc16c[[1]][1],ttc17c[[1]][1],ttc18c[[1]][1]),
                   ExpectedCc=c(ttc11c[[1]][2],ttc12c[[1]][2],ttc13c[[1]][2],ttc14c[[1]][2],ttc15c[[1]][2],ttc16c[[1]][2],ttc17c[[1]][2],ttc18c[[1]][2]),
                   SDCc      =c(ttc11c[[1]][3],ttc12c[[1]][3],ttc13c[[1]][3],ttc14c[[1]][3],ttc15c[[1]][3],ttc16c[[1]][3],ttc17c[[1]][3],ttc18c[[1]][3]),
                   P_valueCc =c(ttc11c[[4]]   ,ttc12c[[4]]   ,ttc13c[[4]]   ,ttc14c[[4]]   ,ttc15c[[4]]   ,ttc16c[[4]]   ,ttc17c[[4]]   ,ttc18c[[4]]   ))
TestSA





###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
# Modeling
# Modeling
# Modeling
# Modeling
# Modeling
# Modeling
# Modeling
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################





# library(PerformanceAnalytics) # for correlation matrix
# zt.cor<-zt[,c("IncomeT1k","RPovT","CPovT","PovT")]
# chart.Correlation(zt.cor,histogram=TRUE,pch=19)





# Total
mta0a<-   lm(RptTr~Yearf                                                                                                                                                                               ,data=zt[,c("RptTr","Yearf"                                                                                                                                                                                            )])
mta1a<-   lm(RptTr~Yearf+DHS_HVPrc_within         +DHS_HVPrc_between                                                                                                                                   ,data=zt[,c("RptTr","Yearf","DHS_HVPrc_within","DHS_HVPrc_between"                                                                                                                                                     )])
mta2a<-   lm(RptTr~Yearf+DHS_HVPrc_within         +DHS_HVPrc_between+USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc                             ,data=zt[,c("RptTr","Yearf","DHS_HVPrc_within","DHS_HVPrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc"                       )])
mta3a<-   lm(RptTr~Yearf+DHS_HVPrc_within*USDA_RUC+DHS_HVPrc_between*USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc                             ,data=zt[,c("RptTr","Yearf","DHS_HVPrc_within","DHS_HVPrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc"                       )])

mta0c<-   lm(RptTr~Yearf                                                                                                                                                                               ,data=zt2[,c("RptTr","Yearf"                                                                                                                                                                                            )])
mta1c<-   lm(RptTr~Yearf+MHV_C5kc_within          +MHV_C5kc_between                                                                                                                                    ,data=zt2[,c("RptTr","Yearf","MHV_C5kc_within" ,"MHV_C5kc_between"                                                                                                                                                      )])
mta2c<-   lm(RptTr~Yearf+MHV_C5kc_within          +MHV_C5kc_between +USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc                             ,data=zt2[,c("RptTr","Yearf","MHV_C5kc_within" ,"MHV_C5kc_between" ,"USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc"                       )])
mta3c<-   lm(RptTr~Yearf+MHV_C5kc_within *USDA_RUC+MHV_C5kc_between *USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc                             ,data=zt2[,c("RptTr","Yearf","MHV_C5kc_within" ,"MHV_C5kc_between" ,"USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc"                       )])

# mta0b<-   lm(RptTr~Yearf                                                                                                                                                                               ,data=zt[!is.na(IDHS_EIrc),c("RptTr","Yearf"                                                                                                                                                                           )])
# mta1b<-   lm(RptTr~Yearf+IDHS_EIrc_within         +IDHS_EIrc_between                                                                                                                                   ,data=zt[,c("RptTr","Yearf","IDHS_EIrc_within","IDHS_EIrc_between"                                                                                                                                                     )])
# mta2b<-   lm(RptTr~Yearf+IDHS_EIrc_within         +IDHS_EIrc_between+USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc                             ,data=zt[,c("RptTr","Yearf","IDHS_EIrc_within","IDHS_EIrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc"                       )])
# mta3b<-   lm(RptTr~Yearf+IDHS_EIrc_within*USDA_RUC+IDHS_EIrc_between*USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc                             ,data=zt[,c("RptTr","Yearf","IDHS_EIrc_within","IDHS_EIrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc"                       )])

mtb0a<-fitme(RptTr~Yearf                                                                                                                                                  +Matern(1|Longitude+Latitude),data=zt[,c("RptTr","Yearf"                                                                                                                                                                     ,"Longitude","Latitude")])
mtb1a<-fitme(RptTr~Yearf+DHS_HVPrc_within         +DHS_HVPrc_between                                                                                                      +Matern(1|Longitude+Latitude),data=zt[,c("RptTr","Yearf","DHS_HVPrc_within","DHS_HVPrc_between"                                                                                                                              ,"Longitude","Latitude")])
mtb2a<-fitme(RptTr~Yearf+DHS_HVPrc_within         +DHS_HVPrc_between+USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=zt[,c("RptTr","Yearf","DHS_HVPrc_within","DHS_HVPrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])
mtb3a<-fitme(RptTr~Yearf+DHS_HVPrc_within*USDA_RUC+DHS_HVPrc_between*USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=zt[,c("RptTr","Yearf","DHS_HVPrc_within","DHS_HVPrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])
mtb4a<-fitme(RptTr~Yearf+DHS_HVPrc_within*USDA_RUC+DHS_HVPrc_between+USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=zt[,c("RptTr","Yearf","DHS_HVPrc_within","DHS_HVPrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])
mtb5a<-fitme(RptTr~Yearf+DHS_HVPrc_within+USDA_RUC+DHS_HVPrc_between*USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=zt[,c("RptTr","Yearf","DHS_HVPrc_within","DHS_HVPrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])

mtb0c<-fitme(RptTr~Yearf                                                                                                                                                  +Matern(1|Longitude+Latitude),data=zt2[,c("RptTr","Yearf"                                                                                                                                                                     ,"Longitude","Latitude")])
mtb1c<-fitme(RptTr~Yearf+MHV_C5kc_within          +MHV_C5kc_between                                                                                                       +Matern(1|Longitude+Latitude),data=zt2[,c("RptTr","Yearf","MHV_C5kc_within" ,"MHV_C5kc_between"                                                                                                                               ,"Longitude","Latitude")])
mtb2c<-fitme(RptTr~Yearf+MHV_C5kc_within          +MHV_C5kc_between +USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=zt2[,c("RptTr","Yearf","MHV_C5kc_within" ,"MHV_C5kc_between" ,"USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])
mtb3c<-fitme(RptTr~Yearf+MHV_C5kc_within *USDA_RUC+MHV_C5kc_between *USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=zt2[,c("RptTr","Yearf","MHV_C5kc_within" ,"MHV_C5kc_between" ,"USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])
mtb4c<-fitme(RptTr~Yearf+MHV_C5kc_within *USDA_RUC+MHV_C5kc_between +USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=zt2[,c("RptTr","Yearf","MHV_C5kc_within" ,"MHV_C5kc_between" ,"USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])
mtb5c<-fitme(RptTr~Yearf+MHV_C5kc_within +USDA_RUC+MHV_C5kc_between *USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=zt2[,c("RptTr","Yearf","MHV_C5kc_within" ,"MHV_C5kc_between" ,"USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])

# mtb0b<-fitme(RptTr~Yearf                                                                                                                                                  +Matern(1|Longitude+Latitude),data=zt[!is.na(IDHS_EIrc),c("RptTr","Yearf"                                                                                                                                                    ,"Longitude","Latitude")])
# mtb1b<-fitme(RptTr~Yearf+IDHS_EIrc_within         +IDHS_EIrc_between                                                                                                      +Matern(1|Longitude+Latitude),data=zt[,c("RptTr","Yearf","IDHS_EIrc_within","IDHS_EIrc_between"                                                                                                                              ,"Longitude","Latitude")])
# mtb2b<-fitme(RptTr~Yearf+IDHS_EIrc_within         +IDHS_EIrc_between+USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=zt[,c("RptTr","Yearf","IDHS_EIrc_within","IDHS_EIrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])
# mtb3b<-fitme(RptTr~Yearf+IDHS_EIrc_within*USDA_RUC+IDHS_EIrc_between*USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=zt[,c("RptTr","Yearf","IDHS_EIrc_within","IDHS_EIrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])
# mtb4b<-fitme(RptTr~Yearf+IDHS_EIrc_within*USDA_RUC+IDHS_EIrc_between+USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=zt[,c("RptTr","Yearf","IDHS_EIrc_within","IDHS_EIrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])
# mtb5b<-fitme(RptTr~Yearf+IDHS_EIrc_within+USDA_RUC+IDHS_EIrc_between*USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=zt[,c("RptTr","Yearf","IDHS_EIrc_within","IDHS_EIrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])

save.image("Z:/CDCK01/Analysis/ZipCode/HomeVisit/HomeVisit02_Model1_2.RData")

summary(mtb1a)
summary(mtb2a)
summary(mtb4a)
summary(mtb5a)
summary(mtb1c)
summary(mtb2c)
summary(mtb4c)
summary(mtb5c)

extractAIC(mtb1a)[2]
extractAIC(mtb2a)[2]
extractAIC(mtb4a)[2]
extractAIC(mtb5a)[2]

anova(mtb1a,mtb2a)
anova(mtb2a,mtb4a)
anova(mtb2a,mtb5a)
anova(mtb2a,mtb3a)
anova(mtb3a,mtb4a)

anova(mtb1a,mtb2a)$basicLRT[[3]]
anova(mtb2a,mtb4a)$basicLRT[[3]]
anova(mtb2a,mtb5a)$basicLRT[[3]]

extractAIC(mtb1c)[2]
extractAIC(mtb2c)[2]
extractAIC(mtb4c)[2]
extractAIC(mtb5c)[2]

anova(mtb1c,mtb2c)
anova(mtb2c,mtb4c)
anova(mtb2c,mtb5c)

anova(mtb1c,mtb2c)$basicLRT[[3]]
anova(mtb2c,mtb4c)$basicLRT[[3]]
anova(mtb2c,mtb5c)$basicLRT[[3]]

mtb2a<-fitme(RptTr~Yearf+DHS_HVPrc_within         +DHS_HVPrc_between+USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=zt[,c("RptTr","Yearf","DHS_HVPrc_within","DHS_HVPrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])
mtb3a<-fitme(RptTr~Yearf+DHS_HVPrc_within*USDA_RUC+DHS_HVPrc_between*USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=zt[,c("RptTr","Yearf","DHS_HVPrc_within","DHS_HVPrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])
mtb4a<-fitme(RptTr~Yearf+DHS_HVPrc_within*USDA_RUC+DHS_HVPrc_between+USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=zt[,c("RptTr","Yearf","DHS_HVPrc_within","DHS_HVPrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])


# glmmTMB

zt$pos<-numFactor(scale(zt$Longitude), scale(zt$Latitude))
zt$ID <-factor(rep(1,nrow(zt)))

mtb2aTBM<-glmmTMB(RptTr~Yearf+DHS_HVPrc_within         +DHS_HVPrc_between+USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+mat(pos+0|ID),zt)
mtb4aTBM<-glmmTMB(RptTr~Yearf+DHS_HVPrc_within*USDA_RUC+DHS_HVPrc_between+USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+mat(pos+0|ID),zt)




# Age 0-5

m1a0a<-   lm(Rpt1r~Yearf                                                                                                                                                                               ,data=z1[!is.na(DHS_HVPrc),c("Rpt1r","Yearf"                                                                                                                                                                           )])
m1a1a<-   lm(Rpt1r~Yearf+DHS_HVPrc_within         +DHS_HVPrc_between                                                                                                                                   ,data=z1[,c("Rpt1r","Yearf","DHS_HVPrc_within","DHS_HVPrc_between"                                                                                                                                                     )])
m1a2a<-   lm(Rpt1r~Yearf+DHS_HVPrc_within         +DHS_HVPrc_between+USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc                             ,data=z1[,c("Rpt1r","Yearf","DHS_HVPrc_within","DHS_HVPrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc"                       )])
m1a3a<-   lm(Rpt1r~Yearf+DHS_HVPrc_within*USDA_RUC+DHS_HVPrc_between*USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc                             ,data=z1[,c("Rpt1r","Yearf","DHS_HVPrc_within","DHS_HVPrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc"                       )])

m1a0c<-   lm(Rpt1r~Yearf                                                                                                                                                                               ,data=z12[!is.na(MHV_C5kc) ,c("Rpt1r","Yearf"                                                                                                                                                                           )])
m1a1c<-   lm(Rpt1r~Yearf+MHV_C5kc_within          +MHV_C5kc_between                                                                                                                                    ,data=z12[,c("Rpt1r","Yearf","MHV_C5kc_within" ,"MHV_C5kc_between"                                                                                                                                                      )])
m1a2c<-   lm(Rpt1r~Yearf+MHV_C5kc_within          +MHV_C5kc_between +USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc                             ,data=z12[,c("Rpt1r","Yearf","MHV_C5kc_within" ,"MHV_C5kc_between" ,"USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc"                       )])
m1a3c<-   lm(Rpt1r~Yearf+MHV_C5kc_within *USDA_RUC+MHV_C5kc_between *USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc                             ,data=z12[,c("Rpt1r","Yearf","MHV_C5kc_within" ,"MHV_C5kc_between" ,"USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc"                       )])

# m1a0b<-   lm(Rpt1r~Yearf                                                                                                                                                                               ,data=z1[!is.na(IDHS_EIrc),c("Rpt1r","Yearf"                                                                                                                                                                           )])
# m1a1b<-   lm(Rpt1r~Yearf+IDHS_EIrc_within         +IDHS_EIrc_between                                                                                                                                   ,data=z1[,c("Rpt1r","Yearf","IDHS_EIrc_within","IDHS_EIrc_between"                                                                                                                                                     )])
# m1a2b<-   lm(Rpt1r~Yearf+IDHS_EIrc_within         +IDHS_EIrc_between+USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc                             ,data=z1[,c("Rpt1r","Yearf","IDHS_EIrc_within","IDHS_EIrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc"                       )])
# m1a3b<-   lm(Rpt1r~Yearf+IDHS_EIrc_within*USDA_RUC+IDHS_EIrc_between*USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc                             ,data=z1[,c("Rpt1r","Yearf","IDHS_EIrc_within","IDHS_EIrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc"                       )])

m1b0a<-fitme(Rpt1r~Yearf                                                                                                                                                  +Matern(1|Longitude+Latitude),data=z1[!is.na(DHS_HVPrc),c("Rpt1r","Yearf"                                                                                                                                                    ,"Longitude","Latitude")])
m1b1a<-fitme(Rpt1r~Yearf+DHS_HVPrc_within         +DHS_HVPrc_between                                                                                                      +Matern(1|Longitude+Latitude),data=z1[,c("Rpt1r","Yearf","DHS_HVPrc_within","DHS_HVPrc_between"                                                                                                                              ,"Longitude","Latitude")])
m1b2a<-fitme(Rpt1r~Yearf+DHS_HVPrc_within         +DHS_HVPrc_between+USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=z1[,c("Rpt1r","Yearf","DHS_HVPrc_within","DHS_HVPrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])
m1b3a<-fitme(Rpt1r~Yearf+DHS_HVPrc_within*USDA_RUC+DHS_HVPrc_between*USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=z1[,c("Rpt1r","Yearf","DHS_HVPrc_within","DHS_HVPrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])
m1b4a<-fitme(Rpt1r~Yearf+DHS_HVPrc_within*USDA_RUC+DHS_HVPrc_between+USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=z1[,c("Rpt1r","Yearf","DHS_HVPrc_within","DHS_HVPrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])
m1b5a<-fitme(Rpt1r~Yearf+DHS_HVPrc_within+USDA_RUC+DHS_HVPrc_between*USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=z1[,c("Rpt1r","Yearf","DHS_HVPrc_within","DHS_HVPrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])

m1b0c<-fitme(Rpt1r~Yearf                                                                                                                                                  +Matern(1|Longitude+Latitude),data=z12[!is.na(MHV_C5kc) ,c("Rpt1r","Yearf"                                                                                                                                                    ,"Longitude","Latitude")])
m1b1c<-fitme(Rpt1r~Yearf+MHV_C5kc_within          +MHV_C5kc_between                                                                                                       +Matern(1|Longitude+Latitude),data=z12[,c("Rpt1r","Yearf","MHV_C5kc_within" ,"MHV_C5kc_between"                                                                                                                               ,"Longitude","Latitude")])
m1b2c<-fitme(Rpt1r~Yearf+MHV_C5kc_within          +MHV_C5kc_between +USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=z12[,c("Rpt1r","Yearf","MHV_C5kc_within" ,"MHV_C5kc_between" ,"USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])
m1b3c<-fitme(Rpt1r~Yearf+MHV_C5kc_within *USDA_RUC+MHV_C5kc_between *USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=z12[,c("Rpt1r","Yearf","MHV_C5kc_within" ,"MHV_C5kc_between" ,"USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])
m1b4c<-fitme(Rpt1r~Yearf+MHV_C5kc_within *USDA_RUC+MHV_C5kc_between +USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=z12[,c("Rpt1r","Yearf","MHV_C5kc_within" ,"MHV_C5kc_between" ,"USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])
m1b5c<-fitme(Rpt1r~Yearf+MHV_C5kc_within +USDA_RUC+MHV_C5kc_between *USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=z12[,c("Rpt1r","Yearf","MHV_C5kc_within" ,"MHV_C5kc_between" ,"USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])

# m1b0b<-fitme(Rpt1r~Yearf                                                                                                                                                  +Matern(1|Longitude+Latitude),data=z1[!is.na(IDHS_EIrc),c("Rpt1r","Yearf"                                                                                                                                                    ,"Longitude","Latitude")])
# m1b1b<-fitme(Rpt1r~Yearf+IDHS_EIrc_within         +IDHS_EIrc_between                                                                                                      +Matern(1|Longitude+Latitude),data=z1[,c("Rpt1r","Yearf","IDHS_EIrc_within","IDHS_EIrc_between"                                                                                                                              ,"Longitude","Latitude")])
# m1b2b<-fitme(Rpt1r~Yearf+IDHS_EIrc_within         +IDHS_EIrc_between+USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=z1[,c("Rpt1r","Yearf","IDHS_EIrc_within","IDHS_EIrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])
# m1b3b<-fitme(Rpt1r~Yearf+IDHS_EIrc_within*USDA_RUC+IDHS_EIrc_between*USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=z1[,c("Rpt1r","Yearf","IDHS_EIrc_within","IDHS_EIrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])
# m1b4b<-fitme(Rpt1r~Yearf+IDHS_EIrc_within*USDA_RUC+IDHS_EIrc_between+USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=z1[,c("Rpt1r","Yearf","IDHS_EIrc_within","IDHS_EIrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])
# m1b5b<-fitme(Rpt1r~Yearf+IDHS_EIrc_within+USDA_RUC+IDHS_EIrc_between*USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=z1[,c("Rpt1r","Yearf","IDHS_EIrc_within","IDHS_EIrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])

save.image("Z:/CDCK01/Analysis/ZipCode/HomeVisit/HomeVisit02_Model2_2.RData")

anova(m1b1a,m1b2a)
anova(m1b2a,m1b4a)
anova(m1b2a,m1b5a)
anova(m1b1c,m1b2c)
anova(m1b2c,m1b4c)
anova(m1b2c,m1b5c)



# Age 6-11
m2a0a<-   lm(Rpt2r~Yearf                                                                                                                                                                               ,data=z2[!is.na(DHS_HVPrc),c("Rpt2r","Yearf"                                                                                                                                                                           )])
m2a1a<-   lm(Rpt2r~Yearf+DHS_HVPrc_within         +DHS_HVPrc_between                                                                                                                                   ,data=z2[,c("Rpt2r","Yearf","DHS_HVPrc_within","DHS_HVPrc_between"                                                                                                                                                     )])
m2a2a<-   lm(Rpt2r~Yearf+DHS_HVPrc_within         +DHS_HVPrc_between+USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc                             ,data=z2[,c("Rpt2r","Yearf","DHS_HVPrc_within","DHS_HVPrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc"                       )])
m2a3a<-   lm(Rpt2r~Yearf+DHS_HVPrc_within*USDA_RUC+DHS_HVPrc_between*USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc                             ,data=z2[,c("Rpt2r","Yearf","DHS_HVPrc_within","DHS_HVPrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc"                       )])

m2a0c<-   lm(Rpt2r~Yearf                                                                                                                                                                               ,data=z22[!is.na(MHV_C5kc) ,c("Rpt2r","Yearf"                                                                                                                                                                           )])
m2a1c<-   lm(Rpt2r~Yearf+MHV_C5kc_within          +MHV_C5kc_between                                                                                                                                    ,data=z22[,c("Rpt2r","Yearf","MHV_C5kc_within" ,"MHV_C5kc_between"                                                                                                                                                      )])
m2a2c<-   lm(Rpt2r~Yearf+MHV_C5kc_within          +MHV_C5kc_between +USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc                             ,data=z22[,c("Rpt2r","Yearf","MHV_C5kc_within" ,"MHV_C5kc_between" ,"USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc"                       )])
m2a3c<-   lm(Rpt2r~Yearf+MHV_C5kc_within *USDA_RUC+MHV_C5kc_between *USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc                             ,data=z22[,c("Rpt2r","Yearf","MHV_C5kc_within" ,"MHV_C5kc_between" ,"USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc"                       )])

# m2a0b<-   lm(Rpt2r~Yearf                                                                                                                                                                               ,data=z2[!is.na(IDHS_EIrc),c("Rpt2r","Yearf"                                                                                                                                                                           )])
# m2a1b<-   lm(Rpt2r~Yearf+IDHS_EIrc_within         +IDHS_EIrc_between                                                                                                                                   ,data=z2[,c("Rpt2r","Yearf","IDHS_EIrc_within","IDHS_EIrc_between"                                                                                                                                                     )])
# m2a2b<-   lm(Rpt2r~Yearf+IDHS_EIrc_within         +IDHS_EIrc_between+USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc                             ,data=z2[,c("Rpt2r","Yearf","IDHS_EIrc_within","IDHS_EIrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc"                       )])
# m2a3b<-   lm(Rpt2r~Yearf+IDHS_EIrc_within*USDA_RUC+IDHS_EIrc_between*USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc                             ,data=z2[,c("Rpt2r","Yearf","IDHS_EIrc_within","IDHS_EIrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc"                       )])

m2b0a<-fitme(Rpt2r~Yearf                                                                                                                                                  +Matern(1|Longitude+Latitude),data=z2[!is.na(DHS_HVPrc),c("Rpt2r","Yearf"                                                                                                                                                    ,"Longitude","Latitude")])
m2b1a<-fitme(Rpt2r~Yearf+DHS_HVPrc_within         +DHS_HVPrc_between                                                                                                      +Matern(1|Longitude+Latitude),data=z2[,c("Rpt2r","Yearf","DHS_HVPrc_within","DHS_HVPrc_between"                                                                                                                              ,"Longitude","Latitude")])
m2b2a<-fitme(Rpt2r~Yearf+DHS_HVPrc_within         +DHS_HVPrc_between+USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=z2[,c("Rpt2r","Yearf","DHS_HVPrc_within","DHS_HVPrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])
m2b3a<-fitme(Rpt2r~Yearf+DHS_HVPrc_within*USDA_RUC+DHS_HVPrc_between*USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=z2[,c("Rpt2r","Yearf","DHS_HVPrc_within","DHS_HVPrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])
m2b4a<-fitme(Rpt2r~Yearf+DHS_HVPrc_within*USDA_RUC+DHS_HVPrc_between+USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=z2[,c("Rpt2r","Yearf","DHS_HVPrc_within","DHS_HVPrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])
m2b5a<-fitme(Rpt2r~Yearf+DHS_HVPrc_within+USDA_RUC+DHS_HVPrc_between*USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=z2[,c("Rpt2r","Yearf","DHS_HVPrc_within","DHS_HVPrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])

m2b0c<-fitme(Rpt2r~Yearf                                                                                                                                                  +Matern(1|Longitude+Latitude),data=z22[!is.na(MHV_C5kc) ,c("Rpt2r","Yearf"                                                                                                                                                    ,"Longitude","Latitude")])
m2b1c<-fitme(Rpt2r~Yearf+MHV_C5kc_within          +MHV_C5kc_between                                                                                                       +Matern(1|Longitude+Latitude),data=z22[,c("Rpt2r","Yearf","MHV_C5kc_within" ,"MHV_C5kc_between"                                                                                                                               ,"Longitude","Latitude")])
m2b2c<-fitme(Rpt2r~Yearf+MHV_C5kc_within          +MHV_C5kc_between +USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=z22[,c("Rpt2r","Yearf","MHV_C5kc_within" ,"MHV_C5kc_between" ,"USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])
m2b3c<-fitme(Rpt2r~Yearf+MHV_C5kc_within *USDA_RUC+MHV_C5kc_between *USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=z22[,c("Rpt2r","Yearf","MHV_C5kc_within" ,"MHV_C5kc_between" ,"USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])
m2b4c<-fitme(Rpt2r~Yearf+MHV_C5kc_within *USDA_RUC+MHV_C5kc_between +USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=z22[,c("Rpt2r","Yearf","MHV_C5kc_within" ,"MHV_C5kc_between" ,"USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])
m2b5c<-fitme(Rpt2r~Yearf+MHV_C5kc_within +USDA_RUC+MHV_C5kc_between *USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=z22[,c("Rpt2r","Yearf","MHV_C5kc_within" ,"MHV_C5kc_between" ,"USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])

# m2b0b<-fitme(Rpt2r~Yearf                                                                                                                                                  +Matern(1|Longitude+Latitude),data=z2[!is.na(IDHS_EIrc),c("Rpt2r","Yearf"                                                                                                                                                    ,"Longitude","Latitude")])
# m2b1b<-fitme(Rpt2r~Yearf+IDHS_EIrc_within         +IDHS_EIrc_between                                                                                                      +Matern(1|Longitude+Latitude),data=z2[,c("Rpt2r","Yearf","IDHS_EIrc_within","IDHS_EIrc_between"                                                                                                                              ,"Longitude","Latitude")])
# m2b2b<-fitme(Rpt2r~Yearf+IDHS_EIrc_within         +IDHS_EIrc_between+USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=z2[,c("Rpt2r","Yearf","IDHS_EIrc_within","IDHS_EIrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])
# m2b3b<-fitme(Rpt2r~Yearf+IDHS_EIrc_within*USDA_RUC+IDHS_EIrc_between*USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=z2[,c("Rpt2r","Yearf","IDHS_EIrc_within","IDHS_EIrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])
# m2b4b<-fitme(Rpt2r~Yearf+IDHS_EIrc_within*USDA_RUC+IDHS_EIrc_between+USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=z2[,c("Rpt2r","Yearf","IDHS_EIrc_within","IDHS_EIrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])
# m2b5b<-fitme(Rpt2r~Yearf+IDHS_EIrc_within+USDA_RUC+IDHS_EIrc_between*USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=z2[,c("Rpt2r","Yearf","IDHS_EIrc_within","IDHS_EIrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])

save.image("Z:/CDCK01/Analysis/ZipCode/HomeVisit/HomeVisit02_Model3_2.RData")





# Age 12-17

m3a0a<-   lm(Rpt3r~Yearf                                                                                                                                                                               ,data=z3[!is.na(DHS_HVPrc),c("Rpt3r","Yearf"                                                                                                                                                                           )])
m3a1a<-   lm(Rpt3r~Yearf+DHS_HVPrc_within         +DHS_HVPrc_between                                                                                                                                   ,data=z3[,c("Rpt3r","Yearf","DHS_HVPrc_within","DHS_HVPrc_between"                                                                                                                                                     )])
m3a2a<-   lm(Rpt3r~Yearf+DHS_HVPrc_within         +DHS_HVPrc_between+USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc                             ,data=z3[,c("Rpt3r","Yearf","DHS_HVPrc_within","DHS_HVPrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc"                       )])
m3a3a<-   lm(Rpt3r~Yearf+DHS_HVPrc_within*USDA_RUC+DHS_HVPrc_between*USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc                             ,data=z3[,c("Rpt3r","Yearf","DHS_HVPrc_within","DHS_HVPrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc"                       )])

m3a0c<-   lm(Rpt3r~Yearf                                                                                                                                                                               ,data=z32[!is.na(MHV_C5kc) ,c("Rpt3r","Yearf"                                                                                                                                                                           )])
m3a1c<-   lm(Rpt3r~Yearf+MHV_C5kc_within          +MHV_C5kc_between                                                                                                                                    ,data=z32[,c("Rpt3r","Yearf","MHV_C5kc_within" ,"MHV_C5kc_between"                                                                                                                                                      )])
m3a2c<-   lm(Rpt3r~Yearf+MHV_C5kc_within          +MHV_C5kc_between +USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc                             ,data=z32[,c("Rpt3r","Yearf","MHV_C5kc_within" ,"MHV_C5kc_between" ,"USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc"                       )])
m3a3c<-   lm(Rpt3r~Yearf+MHV_C5kc_within *USDA_RUC+MHV_C5kc_between *USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc                             ,data=z32[,c("Rpt3r","Yearf","MHV_C5kc_within" ,"MHV_C5kc_between" ,"USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc"                       )])

# m3a0b<-   lm(Rpt3r~Yearf                                                                                                                                                                               ,data=z3[!is.na(IDHS_EIrc),c("Rpt3r","Yearf"                                                                                                                                                                           )])
# m3a1b<-   lm(Rpt3r~Yearf+IDHS_EIrc_within         +IDHS_EIrc_between                                                                                                                                   ,data=z3[,c("Rpt3r","Yearf","IDHS_EIrc_within","IDHS_EIrc_between"                                                                                                                                                     )])
# m3a2b<-   lm(Rpt3r~Yearf+IDHS_EIrc_within         +IDHS_EIrc_between+USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc                             ,data=z3[,c("Rpt3r","Yearf","IDHS_EIrc_within","IDHS_EIrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc"                       )])
# m3a3b<-   lm(Rpt3r~Yearf+IDHS_EIrc_within*USDA_RUC+IDHS_EIrc_between*USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc                             ,data=z3[,c("Rpt3r","Yearf","IDHS_EIrc_within","IDHS_EIrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc"                       )])

m3b0a<-fitme(Rpt3r~Yearf                                                                                                                                                  +Matern(1|Longitude+Latitude),data=z3[!is.na(DHS_HVPrc),c("Rpt3r","Yearf"                                                                                                                                                    ,"Longitude","Latitude")])
m3b1a<-fitme(Rpt3r~Yearf+DHS_HVPrc_within         +DHS_HVPrc_between                                                                                                      +Matern(1|Longitude+Latitude),data=z3[,c("Rpt3r","Yearf","DHS_HVPrc_within","DHS_HVPrc_between"                                                                                                                              ,"Longitude","Latitude")])
m3b2a<-fitme(Rpt3r~Yearf+DHS_HVPrc_within         +DHS_HVPrc_between+USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=z3[,c("Rpt3r","Yearf","DHS_HVPrc_within","DHS_HVPrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])
m3b3a<-fitme(Rpt3r~Yearf+DHS_HVPrc_within*USDA_RUC+DHS_HVPrc_between*USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=z3[,c("Rpt3r","Yearf","DHS_HVPrc_within","DHS_HVPrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])
m3b4a<-fitme(Rpt3r~Yearf+DHS_HVPrc_within*USDA_RUC+DHS_HVPrc_between+USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=z3[,c("Rpt3r","Yearf","DHS_HVPrc_within","DHS_HVPrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])
m3b5a<-fitme(Rpt3r~Yearf+DHS_HVPrc_within+USDA_RUC+DHS_HVPrc_between*USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=z3[,c("Rpt3r","Yearf","DHS_HVPrc_within","DHS_HVPrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])

m3b0c<-fitme(Rpt3r~Yearf                                                                                                                                                  +Matern(1|Longitude+Latitude),data=z32[!is.na(MHV_C5kc) ,c("Rpt3r","Yearf"                                                                                                                                                    ,"Longitude","Latitude")])
m3b1c<-fitme(Rpt3r~Yearf+MHV_C5kc_within          +MHV_C5kc_between                                                                                                       +Matern(1|Longitude+Latitude),data=z32[,c("Rpt3r","Yearf","MHV_C5kc_within" ,"MHV_C5kc_between"                                                                                                                               ,"Longitude","Latitude")])
m3b2c<-fitme(Rpt3r~Yearf+MHV_C5kc_within          +MHV_C5kc_between +USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=z32[,c("Rpt3r","Yearf","MHV_C5kc_within" ,"MHV_C5kc_between" ,"USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])
m3b3c<-fitme(Rpt3r~Yearf+MHV_C5kc_within *USDA_RUC+MHV_C5kc_between *USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=z32[,c("Rpt3r","Yearf","MHV_C5kc_within" ,"MHV_C5kc_between" ,"USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])
m3b4c<-fitme(Rpt3r~Yearf+MHV_C5kc_within *USDA_RUC+MHV_C5kc_between +USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=z32[,c("Rpt3r","Yearf","MHV_C5kc_within" ,"MHV_C5kc_between" ,"USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])
m3b5c<-fitme(Rpt3r~Yearf+MHV_C5kc_within +USDA_RUC+MHV_C5kc_between *USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=z32[,c("Rpt3r","Yearf","MHV_C5kc_within" ,"MHV_C5kc_between" ,"USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])

# m3b0b<-fitme(Rpt3r~Yearf                                                                                                                                                  +Matern(1|Longitude+Latitude),data=z3[!is.na(IDHS_EIrc),c("Rpt3r","Yearf"                                                                                                                                                    ,"Longitude","Latitude")])
# m3b1b<-fitme(Rpt3r~Yearf+IDHS_EIrc_within         +IDHS_EIrc_between                                                                                                      +Matern(1|Longitude+Latitude),data=z3[,c("Rpt3r","Yearf","IDHS_EIrc_within","IDHS_EIrc_between"                                                                                                                              ,"Longitude","Latitude")])
# m3b2b<-fitme(Rpt3r~Yearf+IDHS_EIrc_within         +IDHS_EIrc_between+USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=z3[,c("Rpt3r","Yearf","IDHS_EIrc_within","IDHS_EIrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])
# m3b3b<-fitme(Rpt3r~Yearf+IDHS_EIrc_within*USDA_RUC+IDHS_EIrc_between*USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=z3[,c("Rpt3r","Yearf","IDHS_EIrc_within","IDHS_EIrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])
# m3b4b<-fitme(Rpt3r~Yearf+IDHS_EIrc_within*USDA_RUC+IDHS_EIrc_between+USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=z3[,c("Rpt3r","Yearf","IDHS_EIrc_within","IDHS_EIrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])
# m3b5b<-fitme(Rpt3r~Yearf+IDHS_EIrc_within+USDA_RUC+IDHS_EIrc_between*USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=z3[,c("Rpt3r","Yearf","IDHS_EIrc_within","IDHS_EIrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])

save.image("Z:/CDCK01/Analysis/ZipCode/HomeVisit/HomeVisit02_Model1_2.RData")





# Male

mma0a<-   lm(RptMr~Yearf                                                                                                                                                                               ,data=zm[!is.na(DHS_HVPrc),c("RptMr","Yearf"                                                                                                                                                                           )])
mma1a<-   lm(RptMr~Yearf+DHS_HVPrc_within         +DHS_HVPrc_between                                                                                                                                   ,data=zm[,c("RptMr","Yearf","DHS_HVPrc_within","DHS_HVPrc_between"                                                                                                                                                     )])
mma2a<-   lm(RptMr~Yearf+DHS_HVPrc_within         +DHS_HVPrc_between+USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc                             ,data=zm[,c("RptMr","Yearf","DHS_HVPrc_within","DHS_HVPrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc"                       )])
mma3a<-   lm(RptMr~Yearf+DHS_HVPrc_within*USDA_RUC+DHS_HVPrc_between*USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc                             ,data=zm[,c("RptMr","Yearf","DHS_HVPrc_within","DHS_HVPrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc"                       )])

mma0c<-   lm(RptMr~Yearf                                                                                                                                                                               ,data=zm2[!is.na(MHV_C5kc) ,c("RptMr","Yearf"                                                                                                                                                                           )])
mma1c<-   lm(RptMr~Yearf+MHV_C5kc_within          +MHV_C5kc_between                                                                                                                                    ,data=zm2[,c("RptMr","Yearf","MHV_C5kc_within" ,"MHV_C5kc_between"                                                                                                                                                      )])
mma2c<-   lm(RptMr~Yearf+MHV_C5kc_within          +MHV_C5kc_between +USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc                             ,data=zm2[,c("RptMr","Yearf","MHV_C5kc_within" ,"MHV_C5kc_between" ,"USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc"                       )])
mma3c<-   lm(RptMr~Yearf+MHV_C5kc_within *USDA_RUC+MHV_C5kc_between *USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc                             ,data=zm2[,c("RptMr","Yearf","MHV_C5kc_within" ,"MHV_C5kc_between" ,"USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc"                       )])

# mma0b<-   lm(RptMr~Yearf                                                                                                                                                                               ,data=zm[!is.na(IDHS_EIrc),c("RptMr","Yearf"                                                                                                                                                                           )])
# mma1b<-   lm(RptMr~Yearf+IDHS_EIrc_within         +IDHS_EIrc_between                                                                                                                                   ,data=zm[,c("RptMr","Yearf","IDHS_EIrc_within","IDHS_EIrc_between"                                                                                                                                                     )])
# mma2b<-   lm(RptMr~Yearf+IDHS_EIrc_within         +IDHS_EIrc_between+USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc                             ,data=zm[,c("RptMr","Yearf","IDHS_EIrc_within","IDHS_EIrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc"                       )])
# mma3b<-   lm(RptMr~Yearf+IDHS_EIrc_within*USDA_RUC+IDHS_EIrc_between*USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc                             ,data=zm[,c("RptMr","Yearf","IDHS_EIrc_within","IDHS_EIrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc"                       )])

mmb0a<-fitme(RptMr~Yearf                                                                                                                                                  +Matern(1|Longitude+Latitude),data=zm[!is.na(DHS_HVPrc),c("RptMr","Yearf"                                                                                                                                                    ,"Longitude","Latitude")])
mmb1a<-fitme(RptMr~Yearf+DHS_HVPrc_within         +DHS_HVPrc_between                                                                                                      +Matern(1|Longitude+Latitude),data=zm[,c("RptMr","Yearf","DHS_HVPrc_within","DHS_HVPrc_between"                                                                                                                              ,"Longitude","Latitude")])
mmb2a<-fitme(RptMr~Yearf+DHS_HVPrc_within         +DHS_HVPrc_between+USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=zm[,c("RptMr","Yearf","DHS_HVPrc_within","DHS_HVPrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])
mmb3a<-fitme(RptMr~Yearf+DHS_HVPrc_within*USDA_RUC+DHS_HVPrc_between*USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=zm[,c("RptMr","Yearf","DHS_HVPrc_within","DHS_HVPrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])
mmb4a<-fitme(RptMr~Yearf+DHS_HVPrc_within*USDA_RUC+DHS_HVPrc_between+USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=zm[,c("RptMr","Yearf","DHS_HVPrc_within","DHS_HVPrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])
mmb5a<-fitme(RptMr~Yearf+DHS_HVPrc_within+USDA_RUC+DHS_HVPrc_between*USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=zm[,c("RptMr","Yearf","DHS_HVPrc_within","DHS_HVPrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])

mmb0c<-fitme(RptMr~Yearf                                                                                                                                                  +Matern(1|Longitude+Latitude),data=zm2[!is.na(MHV_C5kc) ,c("RptMr","Yearf"                                                                                                                                                    ,"Longitude","Latitude")])
mmb1c<-fitme(RptMr~Yearf+MHV_C5kc_within          +MHV_C5kc_between                                                                                                       +Matern(1|Longitude+Latitude),data=zm2[,c("RptMr","Yearf","MHV_C5kc_within" ,"MHV_C5kc_between"                                                                                                                               ,"Longitude","Latitude")])
mmb2c<-fitme(RptMr~Yearf+MHV_C5kc_within          +MHV_C5kc_between +USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=zm2[,c("RptMr","Yearf","MHV_C5kc_within" ,"MHV_C5kc_between" ,"USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])
mmb3c<-fitme(RptMr~Yearf+MHV_C5kc_within *USDA_RUC+MHV_C5kc_between *USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=zm2[,c("RptMr","Yearf","MHV_C5kc_within" ,"MHV_C5kc_between" ,"USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])
mmb4c<-fitme(RptMr~Yearf+MHV_C5kc_within *USDA_RUC+MHV_C5kc_between +USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=zm2[,c("RptMr","Yearf","MHV_C5kc_within" ,"MHV_C5kc_between" ,"USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])
mmb5c<-fitme(RptMr~Yearf+MHV_C5kc_within +USDA_RUC+MHV_C5kc_between *USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=zm2[,c("RptMr","Yearf","MHV_C5kc_within" ,"MHV_C5kc_between" ,"USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])

# mmb0b<-fitme(RptMr~Yearf                                                                                                                                                  +Matern(1|Longitude+Latitude),data=zm[!is.na(IDHS_EIrc),c("RptMr","Yearf"                                                                                                                                                    ,"Longitude","Latitude")])
# mmb1b<-fitme(RptMr~Yearf+IDHS_EIrc_within         +IDHS_EIrc_between                                                                                                      +Matern(1|Longitude+Latitude),data=zm[,c("RptMr","Yearf","IDHS_EIrc_within","IDHS_EIrc_between"                                                                                                                              ,"Longitude","Latitude")])
# mmb2b<-fitme(RptMr~Yearf+IDHS_EIrc_within         +IDHS_EIrc_between+USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=zm[,c("RptMr","Yearf","IDHS_EIrc_within","IDHS_EIrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])
# mmb3b<-fitme(RptMr~Yearf+IDHS_EIrc_within*USDA_RUC+IDHS_EIrc_between*USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=zm[,c("RptMr","Yearf","IDHS_EIrc_within","IDHS_EIrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])
# mmb4b<-fitme(RptMr~Yearf+IDHS_EIrc_within*USDA_RUC+IDHS_EIrc_between+USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=zm[,c("RptMr","Yearf","IDHS_EIrc_within","IDHS_EIrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])
# mmb5b<-fitme(RptMr~Yearf+IDHS_EIrc_within+USDA_RUC+IDHS_EIrc_between*USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=zm[,c("RptMr","Yearf","IDHS_EIrc_within","IDHS_EIrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])

save.image("Z:/CDCK01/Analysis/ZipCode/HomeVisit/HomeVisit02_Model2_2.RData")





# Female
mfa0a<-   lm(RptFr~Yearf                                                                                                                                                                               ,data=zf[!is.na(DHS_HVPrc),c("RptFr","Yearf"                                                                                                                                                                           )])
mfa1a<-   lm(RptFr~Yearf+DHS_HVPrc_within         +DHS_HVPrc_between                                                                                                                                   ,data=zf[,c("RptFr","Yearf","DHS_HVPrc_within","DHS_HVPrc_between"                                                                                                                                                     )])
mfa2a<-   lm(RptFr~Yearf+DHS_HVPrc_within         +DHS_HVPrc_between+USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc                             ,data=zf[,c("RptFr","Yearf","DHS_HVPrc_within","DHS_HVPrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc"                       )])
mfa3a<-   lm(RptFr~Yearf+DHS_HVPrc_within*USDA_RUC+DHS_HVPrc_between*USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc                             ,data=zf[,c("RptFr","Yearf","DHS_HVPrc_within","DHS_HVPrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc"                       )])

mfa0c<-   lm(RptFr~Yearf                                                                                                                                                                               ,data=zf2[!is.na(MHV_C5kc) ,c("RptFr","Yearf"                                                                                                                                                                           )])
mfa1c<-   lm(RptFr~Yearf+MHV_C5kc_within          +MHV_C5kc_between                                                                                                                                    ,data=zf2[,c("RptFr","Yearf","MHV_C5kc_within" ,"MHV_C5kc_between"                                                                                                                                                      )])
mfa2c<-   lm(RptFr~Yearf+MHV_C5kc_within          +MHV_C5kc_between +USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc                             ,data=zf2[,c("RptFr","Yearf","MHV_C5kc_within" ,"MHV_C5kc_between" ,"USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc"                       )])
mfa3c<-   lm(RptFr~Yearf+MHV_C5kc_within *USDA_RUC+MHV_C5kc_between *USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc                             ,data=zf2[,c("RptFr","Yearf","MHV_C5kc_within" ,"MHV_C5kc_between" ,"USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc"                       )])

# mfa0b<-   lm(RptFr~Yearf                                                                                                                                                                               ,data=zf[!is.na(IDHS_EIrc),c("RptFr","Yearf"                                                                                                                                                                           )])
# mfa1b<-   lm(RptFr~Yearf+IDHS_EIrc_within         +IDHS_EIrc_between                                                                                                                                   ,data=zf[,c("RptFr","Yearf","IDHS_EIrc_within","IDHS_EIrc_between"                                                                                                                                                     )])
# mfa2b<-   lm(RptFr~Yearf+IDHS_EIrc_within         +IDHS_EIrc_between+USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc                             ,data=zf[,c("RptFr","Yearf","IDHS_EIrc_within","IDHS_EIrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc"                       )])
# mfa3b<-   lm(RptFr~Yearf+IDHS_EIrc_within*USDA_RUC+IDHS_EIrc_between*USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc                             ,data=zf[,c("RptFr","Yearf","IDHS_EIrc_within","IDHS_EIrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc"                       )])

mfb0a<-fitme(RptFr~Yearf                                                                                                                                                  +Matern(1|Longitude+Latitude),data=zf[!is.na(DHS_HVPrc),c("RptFr","Yearf"                                                                                                                                                    ,"Longitude","Latitude")])
mfb1a<-fitme(RptFr~Yearf+DHS_HVPrc_within         +DHS_HVPrc_between                                                                                                      +Matern(1|Longitude+Latitude),data=zf[,c("RptFr","Yearf","DHS_HVPrc_within","DHS_HVPrc_between"                                                                                                                              ,"Longitude","Latitude")])
mfb2a<-fitme(RptFr~Yearf+DHS_HVPrc_within         +DHS_HVPrc_between+USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=zf[,c("RptFr","Yearf","DHS_HVPrc_within","DHS_HVPrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])
mfb3a<-fitme(RptFr~Yearf+DHS_HVPrc_within*USDA_RUC+DHS_HVPrc_between*USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=zf[,c("RptFr","Yearf","DHS_HVPrc_within","DHS_HVPrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])
mfb4a<-fitme(RptFr~Yearf+DHS_HVPrc_within*USDA_RUC+DHS_HVPrc_between+USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=zf[,c("RptFr","Yearf","DHS_HVPrc_within","DHS_HVPrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])
mfb5a<-fitme(RptFr~Yearf+DHS_HVPrc_within+USDA_RUC+DHS_HVPrc_between*USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=zf[,c("RptFr","Yearf","DHS_HVPrc_within","DHS_HVPrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])

mfb0c<-fitme(RptFr~Yearf                                                                                                                                                  +Matern(1|Longitude+Latitude),data=zf2[!is.na(MHV_C5kc) ,c("RptFr","Yearf"                                                                                                                                                    ,"Longitude","Latitude")])
mfb1c<-fitme(RptFr~Yearf+MHV_C5kc_within          +MHV_C5kc_between                                                                                                       +Matern(1|Longitude+Latitude),data=zf2[,c("RptFr","Yearf","MHV_C5kc_within" ,"MHV_C5kc_between"                                                                                                                               ,"Longitude","Latitude")])
mfb2c<-fitme(RptFr~Yearf+MHV_C5kc_within          +MHV_C5kc_between +USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=zf2[,c("RptFr","Yearf","MHV_C5kc_within" ,"MHV_C5kc_between" ,"USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])
mfb3c<-fitme(RptFr~Yearf+MHV_C5kc_within *USDA_RUC+MHV_C5kc_between *USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=zf2[,c("RptFr","Yearf","MHV_C5kc_within" ,"MHV_C5kc_between" ,"USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])
mfb4c<-fitme(RptFr~Yearf+MHV_C5kc_within *USDA_RUC+MHV_C5kc_between +USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=zf2[,c("RptFr","Yearf","MHV_C5kc_within" ,"MHV_C5kc_between" ,"USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])
mfb5c<-fitme(RptFr~Yearf+MHV_C5kc_within +USDA_RUC+MHV_C5kc_between *USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=zf2[,c("RptFr","Yearf","MHV_C5kc_within" ,"MHV_C5kc_between" ,"USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])

# mfb0b<-fitme(RptFr~Yearf                                                                                                                                                  +Matern(1|Longitude+Latitude),data=zf[!is.na(IDHS_EIrc),c("RptFr","Yearf"                                                                                                                                                    ,"Longitude","Latitude")])
# mfb1b<-fitme(RptFr~Yearf+IDHS_EIrc_within         +IDHS_EIrc_between                                                                                                      +Matern(1|Longitude+Latitude),data=zf[,c("RptFr","Yearf","IDHS_EIrc_within","IDHS_EIrc_between"                                                                                                                              ,"Longitude","Latitude")])
# mfb2b<-fitme(RptFr~Yearf+IDHS_EIrc_within         +IDHS_EIrc_between+USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=zf[,c("RptFr","Yearf","IDHS_EIrc_within","IDHS_EIrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])
# mfb3b<-fitme(RptFr~Yearf+IDHS_EIrc_within*USDA_RUC+IDHS_EIrc_between*USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=zf[,c("RptFr","Yearf","IDHS_EIrc_within","IDHS_EIrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])
# mfb4b<-fitme(RptFr~Yearf+IDHS_EIrc_within*USDA_RUC+IDHS_EIrc_between+USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=zf[,c("RptFr","Yearf","IDHS_EIrc_within","IDHS_EIrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])
# mfb5b<-fitme(RptFr~Yearf+IDHS_EIrc_within+USDA_RUC+IDHS_EIrc_between*USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=zf[,c("RptFr","Yearf","IDHS_EIrc_within","IDHS_EIrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])

save.image("Z:/CDCK01/Analysis/ZipCode/HomeVisit/HomeVisit02_Model3_2.RData")





# Neglect
mna0a<-   lm(NegTr~Yearf                                                                                                                                                                               ,data=zn[!is.na(DHS_HVPrc),c("NegTr","Yearf"                                                                                                                                                                           )])
mna1a<-   lm(NegTr~Yearf+DHS_HVPrc_within         +DHS_HVPrc_between                                                                                                                                   ,data=zn[,c("NegTr","Yearf","DHS_HVPrc_within","DHS_HVPrc_between"                                                                                                                                                     )])
mna2a<-   lm(NegTr~Yearf+DHS_HVPrc_within         +DHS_HVPrc_between+USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc                             ,data=zn[,c("NegTr","Yearf","DHS_HVPrc_within","DHS_HVPrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc"                       )])
mna3a<-   lm(NegTr~Yearf+DHS_HVPrc_within*USDA_RUC+DHS_HVPrc_between*USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc                             ,data=zn[,c("NegTr","Yearf","DHS_HVPrc_within","DHS_HVPrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc"                       )])

mna0c<-   lm(NegTr~Yearf                                                                                                                                                                               ,data=zn2[!is.na(MHV_C5kc) ,c("NegTr","Yearf"                                                                                                                                                                           )])
mna1c<-   lm(NegTr~Yearf+MHV_C5kc_within          +MHV_C5kc_between                                                                                                                                    ,data=zn2[,c("NegTr","Yearf","MHV_C5kc_within" ,"MHV_C5kc_between"                                                                                                                                                      )])
mna2c<-   lm(NegTr~Yearf+MHV_C5kc_within          +MHV_C5kc_between +USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc                             ,data=zn2[,c("NegTr","Yearf","MHV_C5kc_within" ,"MHV_C5kc_between" ,"USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc"                       )])
mna3c<-   lm(NegTr~Yearf+MHV_C5kc_within *USDA_RUC+MHV_C5kc_between *USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc                             ,data=zn2[,c("NegTr","Yearf","MHV_C5kc_within" ,"MHV_C5kc_between" ,"USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc"                       )])

# mna0b<-   lm(NegTr~Yearf                                                                                                                                                                               ,data=zn[!is.na(IDHS_EIrc),c("NegTr","Yearf"                                                                                                                                                                           )])
# mna1b<-   lm(NegTr~Yearf+IDHS_EIrc_within         +IDHS_EIrc_between                                                                                                                                   ,data=zn[,c("NegTr","Yearf","IDHS_EIrc_within","IDHS_EIrc_between"                                                                                                                                                     )])
# mna2b<-   lm(NegTr~Yearf+IDHS_EIrc_within         +IDHS_EIrc_between+USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc                             ,data=zn[,c("NegTr","Yearf","IDHS_EIrc_within","IDHS_EIrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc"                       )])
# mna3b<-   lm(NegTr~Yearf+IDHS_EIrc_within*USDA_RUC+IDHS_EIrc_between*USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc                             ,data=zn[,c("NegTr","Yearf","IDHS_EIrc_within","IDHS_EIrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc"                       )])

mnb0a<-fitme(NegTr~Yearf                                                                                                                                                  +Matern(1|Longitude+Latitude),data=zn[!is.na(DHS_HVPrc),c("NegTr","Yearf"                                                                                                                                                    ,"Longitude","Latitude")])
mnb1a<-fitme(NegTr~Yearf+DHS_HVPrc_within         +DHS_HVPrc_between                                                                                                      +Matern(1|Longitude+Latitude),data=zn[,c("NegTr","Yearf","DHS_HVPrc_within","DHS_HVPrc_between"                                                                                                                              ,"Longitude","Latitude")])
mnb2a<-fitme(NegTr~Yearf+DHS_HVPrc_within         +DHS_HVPrc_between+USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=zn[,c("NegTr","Yearf","DHS_HVPrc_within","DHS_HVPrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])
mnb3a<-fitme(NegTr~Yearf+DHS_HVPrc_within*USDA_RUC+DHS_HVPrc_between*USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=zn[,c("NegTr","Yearf","DHS_HVPrc_within","DHS_HVPrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])
mnb4a<-fitme(NegTr~Yearf+DHS_HVPrc_within*USDA_RUC+DHS_HVPrc_between+USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=zn[,c("NegTr","Yearf","DHS_HVPrc_within","DHS_HVPrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])
mnb5a<-fitme(NegTr~Yearf+DHS_HVPrc_within+USDA_RUC+DHS_HVPrc_between*USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=zn[,c("NegTr","Yearf","DHS_HVPrc_within","DHS_HVPrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])

mnb0c<-fitme(NegTr~Yearf                                                                                                                                                  +Matern(1|Longitude+Latitude),data=zn2[!is.na(MHV_C5kc) ,c("NegTr","Yearf"                                                                                                                                                    ,"Longitude","Latitude")])
mnb1c<-fitme(NegTr~Yearf+MHV_C5kc_within          +MHV_C5kc_between                                                                                                       +Matern(1|Longitude+Latitude),data=zn2[,c("NegTr","Yearf","MHV_C5kc_within" ,"MHV_C5kc_between"                                                                                                                               ,"Longitude","Latitude")])
mnb2c<-fitme(NegTr~Yearf+MHV_C5kc_within          +MHV_C5kc_between +USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=zn2[,c("NegTr","Yearf","MHV_C5kc_within" ,"MHV_C5kc_between" ,"USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])
mnb3c<-fitme(NegTr~Yearf+MHV_C5kc_within *USDA_RUC+MHV_C5kc_between *USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=zn2[,c("NegTr","Yearf","MHV_C5kc_within" ,"MHV_C5kc_between" ,"USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])
mnb4c<-fitme(NegTr~Yearf+MHV_C5kc_within *USDA_RUC+MHV_C5kc_between +USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=zn2[,c("NegTr","Yearf","MHV_C5kc_within" ,"MHV_C5kc_between" ,"USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])
mnb5c<-fitme(NegTr~Yearf+MHV_C5kc_within +USDA_RUC+MHV_C5kc_between *USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=zn2[,c("NegTr","Yearf","MHV_C5kc_within" ,"MHV_C5kc_between" ,"USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])

# mnb0b<-fitme(NegTr~Yearf                                                                                                                                                  +Matern(1|Longitude+Latitude),data=zn[!is.na(IDHS_EIrc),c("NegTr","Yearf"                                                                                                                                                    ,"Longitude","Latitude")])
# mnb1b<-fitme(NegTr~Yearf+IDHS_EIrc_within         +IDHS_EIrc_between                                                                                                      +Matern(1|Longitude+Latitude),data=zn[,c("NegTr","Yearf","IDHS_EIrc_within","IDHS_EIrc_between"                                                                                                                              ,"Longitude","Latitude")])
# mnb2b<-fitme(NegTr~Yearf+IDHS_EIrc_within         +IDHS_EIrc_between+USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=zn[,c("NegTr","Yearf","IDHS_EIrc_within","IDHS_EIrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])
# mnb3b<-fitme(NegTr~Yearf+IDHS_EIrc_within*USDA_RUC+IDHS_EIrc_between*USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=zn[,c("NegTr","Yearf","IDHS_EIrc_within","IDHS_EIrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])
# mnb4b<-fitme(NegTr~Yearf+IDHS_EIrc_within*USDA_RUC+IDHS_EIrc_between+USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=zn[,c("NegTr","Yearf","IDHS_EIrc_within","IDHS_EIrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])
# mnb5b<-fitme(NegTr~Yearf+IDHS_EIrc_within+USDA_RUC+IDHS_EIrc_between*USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=zn[,c("NegTr","Yearf","IDHS_EIrc_within","IDHS_EIrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])

save.image("Z:/CDCK01/Analysis/ZipCode/HomeVisit/HomeVisit02_Model1_2.RData")





# Physical Abuse
mpa0a<-   lm(PhyTr~Yearf                                                                                                                                                                               ,data=zp[!is.na(DHS_HVPrc),c("PhyTr","Yearf"                                                                                                                                                                           )])
mpa1a<-   lm(PhyTr~Yearf+DHS_HVPrc_within         +DHS_HVPrc_between                                                                                                                                   ,data=zp[,c("PhyTr","Yearf","DHS_HVPrc_within","DHS_HVPrc_between"                                                                                                                                                     )])
mpa2a<-   lm(PhyTr~Yearf+DHS_HVPrc_within         +DHS_HVPrc_between+USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc                             ,data=zp[,c("PhyTr","Yearf","DHS_HVPrc_within","DHS_HVPrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc"                       )])
mpa3a<-   lm(PhyTr~Yearf+DHS_HVPrc_within*USDA_RUC+DHS_HVPrc_between*USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc                             ,data=zp[,c("PhyTr","Yearf","DHS_HVPrc_within","DHS_HVPrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc"                       )])

mpa0c<-   lm(PhyTr~Yearf                                                                                                                                                                               ,data=zp2[!is.na(MHV_C5kc) ,c("PhyTr","Yearf"                                                                                                                                                                           )])
mpa1c<-   lm(PhyTr~Yearf+MHV_C5kc_within          +MHV_C5kc_between                                                                                                                                    ,data=zp2[,c("PhyTr","Yearf","MHV_C5kc_within" ,"MHV_C5kc_between"                                                                                                                                                      )])
mpa2c<-   lm(PhyTr~Yearf+MHV_C5kc_within          +MHV_C5kc_between +USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc                             ,data=zp2[,c("PhyTr","Yearf","MHV_C5kc_within" ,"MHV_C5kc_between" ,"USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc"                       )])
mpa3c<-   lm(PhyTr~Yearf+MHV_C5kc_within *USDA_RUC+MHV_C5kc_between *USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc                             ,data=zp2[,c("PhyTr","Yearf","MHV_C5kc_within" ,"MHV_C5kc_between" ,"USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc"                       )])

# mpa0b<-   lm(PhyTr~Yearf                                                                                                                                                                               ,data=zp[!is.na(IDHS_EIrc),c("PhyTr","Yearf"                                                                                                                                                                           )])
# mpa1b<-   lm(PhyTr~Yearf+IDHS_EIrc_within         +IDHS_EIrc_between                                                                                                                                   ,data=zp[,c("PhyTr","Yearf","IDHS_EIrc_within","IDHS_EIrc_between"                                                                                                                                                     )])
# mpa2b<-   lm(PhyTr~Yearf+IDHS_EIrc_within         +IDHS_EIrc_between+USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc                             ,data=zp[,c("PhyTr","Yearf","IDHS_EIrc_within","IDHS_EIrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc"                       )])
# mpa3b<-   lm(PhyTr~Yearf+IDHS_EIrc_within*USDA_RUC+IDHS_EIrc_between*USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc                             ,data=zp[,c("PhyTr","Yearf","IDHS_EIrc_within","IDHS_EIrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc"                       )])

mpb0a<-fitme(PhyTr~Yearf                                                                                                                                                  +Matern(1|Longitude+Latitude),data=zp[!is.na(DHS_HVPrc),c("PhyTr","Yearf"                                                                                                                                                    ,"Longitude","Latitude")])
mpb1a<-fitme(PhyTr~Yearf+DHS_HVPrc_within         +DHS_HVPrc_between                                                                                                      +Matern(1|Longitude+Latitude),data=zp[,c("PhyTr","Yearf","DHS_HVPrc_within","DHS_HVPrc_between"                                                                                                                              ,"Longitude","Latitude")])
mpb2a<-fitme(PhyTr~Yearf+DHS_HVPrc_within         +DHS_HVPrc_between+USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=zp[,c("PhyTr","Yearf","DHS_HVPrc_within","DHS_HVPrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])
mpb3a<-fitme(PhyTr~Yearf+DHS_HVPrc_within*USDA_RUC+DHS_HVPrc_between*USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=zp[,c("PhyTr","Yearf","DHS_HVPrc_within","DHS_HVPrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])
mpb4a<-fitme(PhyTr~Yearf+DHS_HVPrc_within*USDA_RUC+DHS_HVPrc_between+USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=zp[,c("PhyTr","Yearf","DHS_HVPrc_within","DHS_HVPrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])
mpb5a<-fitme(PhyTr~Yearf+DHS_HVPrc_within+USDA_RUC+DHS_HVPrc_between*USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=zp[,c("PhyTr","Yearf","DHS_HVPrc_within","DHS_HVPrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])

mpb0c<-fitme(PhyTr~Yearf                                                                                                                                                  +Matern(1|Longitude+Latitude),data=zp2[!is.na(MHV_C5kc) ,c("PhyTr","Yearf"                                                                                                                                                    ,"Longitude","Latitude")])
mpb1c<-fitme(PhyTr~Yearf+MHV_C5kc_within          +MHV_C5kc_between                                                                                                       +Matern(1|Longitude+Latitude),data=zp2[,c("PhyTr","Yearf","MHV_C5kc_within" ,"MHV_C5kc_between"                                                                                                                               ,"Longitude","Latitude")])
mpb2c<-fitme(PhyTr~Yearf+MHV_C5kc_within          +MHV_C5kc_between +USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=zp2[,c("PhyTr","Yearf","MHV_C5kc_within" ,"MHV_C5kc_between" ,"USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])
mpb3c<-fitme(PhyTr~Yearf+MHV_C5kc_within *USDA_RUC+MHV_C5kc_between *USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=zp2[,c("PhyTr","Yearf","MHV_C5kc_within" ,"MHV_C5kc_between" ,"USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])
mpb4c<-fitme(PhyTr~Yearf+MHV_C5kc_within *USDA_RUC+MHV_C5kc_between +USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=zp2[,c("PhyTr","Yearf","MHV_C5kc_within" ,"MHV_C5kc_between" ,"USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])
mpb5c<-fitme(PhyTr~Yearf+MHV_C5kc_within +USDA_RUC+MHV_C5kc_between *USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=zp2[,c("PhyTr","Yearf","MHV_C5kc_within" ,"MHV_C5kc_between" ,"USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])

# mpb0b<-fitme(PhyTr~Yearf                                                                                                                                                  +Matern(1|Longitude+Latitude),data=zp[!is.na(IDHS_EIrc),c("PhyTr","Yearf"                                                                                                                                                    ,"Longitude","Latitude")])
# mpb1b<-fitme(PhyTr~Yearf+IDHS_EIrc_within         +IDHS_EIrc_between                                                                                                      +Matern(1|Longitude+Latitude),data=zp[,c("PhyTr","Yearf","IDHS_EIrc_within","IDHS_EIrc_between"                                                                                                                              ,"Longitude","Latitude")])
# mpb2b<-fitme(PhyTr~Yearf+IDHS_EIrc_within         +IDHS_EIrc_between+USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=zp[,c("PhyTr","Yearf","IDHS_EIrc_within","IDHS_EIrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])
# mpb3b<-fitme(PhyTr~Yearf+IDHS_EIrc_within*USDA_RUC+IDHS_EIrc_between*USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=zp[,c("PhyTr","Yearf","IDHS_EIrc_within","IDHS_EIrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])
# mpb4b<-fitme(PhyTr~Yearf+IDHS_EIrc_within*USDA_RUC+IDHS_EIrc_between+USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=zp[,c("PhyTr","Yearf","IDHS_EIrc_within","IDHS_EIrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])
# mpb5b<-fitme(PhyTr~Yearf+IDHS_EIrc_within+USDA_RUC+IDHS_EIrc_between*USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=zp[,c("PhyTr","Yearf","IDHS_EIrc_within","IDHS_EIrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])

save.image("Z:/CDCK01/Analysis/ZipCode/HomeVisit/HomeVisit02_Model2_2.RData")





# Sexual Abuse
msa0a<-   lm(SexTr~Yearf                                                                                                                                                                               ,data=zs[!is.na(DHS_HVPrc),c("SexTr","Yearf"                                                                                                                                                                           )])
msa1a<-   lm(SexTr~Yearf+DHS_HVPrc_within         +DHS_HVPrc_between                                                                                                                                   ,data=zs[,c("SexTr","Yearf","DHS_HVPrc_within","DHS_HVPrc_between"                                                                                                                                                     )])
msa2a<-   lm(SexTr~Yearf+DHS_HVPrc_within         +DHS_HVPrc_between+USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc                             ,data=zs[,c("SexTr","Yearf","DHS_HVPrc_within","DHS_HVPrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc"                       )])
msa3a<-   lm(SexTr~Yearf+DHS_HVPrc_within*USDA_RUC+DHS_HVPrc_between*USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc                             ,data=zs[,c("SexTr","Yearf","DHS_HVPrc_within","DHS_HVPrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc"                       )])

msa0c<-   lm(SexTr~Yearf                                                                                                                                                                               ,data=zs2[!is.na(MHV_C5kc) ,c("SexTr","Yearf"                                                                                                                                                                           )])
msa1c<-   lm(SexTr~Yearf+MHV_C5kc_within          +MHV_C5kc_between                                                                                                                                    ,data=zs2[,c("SexTr","Yearf","MHV_C5kc_within" ,"MHV_C5kc_between"                                                                                                                                                      )])
msa2c<-   lm(SexTr~Yearf+MHV_C5kc_within          +MHV_C5kc_between +USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc                             ,data=zs2[,c("SexTr","Yearf","MHV_C5kc_within" ,"MHV_C5kc_between" ,"USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc"                       )])
msa3c<-   lm(SexTr~Yearf+MHV_C5kc_within *USDA_RUC+MHV_C5kc_between *USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc                             ,data=zs2[,c("SexTr","Yearf","MHV_C5kc_within" ,"MHV_C5kc_between" ,"USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc"                       )])

# msa0b<-   lm(SexTr~Yearf                                                                                                                                                                               ,data=zs[!is.na(IDHS_EIrc),c("SexTr","Yearf"                                                                                                                                                                           )])
# msa1b<-   lm(SexTr~Yearf+IDHS_EIrc_within         +IDHS_EIrc_between                                                                                                                                   ,data=zs[,c("SexTr","Yearf","IDHS_EIrc_within","IDHS_EIrc_between"                                                                                                                                                     )])
# msa2b<-   lm(SexTr~Yearf+IDHS_EIrc_within         +IDHS_EIrc_between+USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc                             ,data=zs[,c("SexTr","Yearf","IDHS_EIrc_within","IDHS_EIrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc"                       )])
# msa3b<-   lm(SexTr~Yearf+IDHS_EIrc_within*USDA_RUC+IDHS_EIrc_between*USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc                             ,data=zs[,c("SexTr","Yearf","IDHS_EIrc_within","IDHS_EIrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc"                       )])

msb0a<-fitme(SexTr~Yearf                                                                                                                                                  +Matern(1|Longitude+Latitude),data=zs[!is.na(DHS_HVPrc),c("SexTr","Yearf"                                                                                                                                                    ,"Longitude","Latitude")])
msb1a<-fitme(SexTr~Yearf+DHS_HVPrc_within         +DHS_HVPrc_between                                                                                                      +Matern(1|Longitude+Latitude),data=zs[,c("SexTr","Yearf","DHS_HVPrc_within","DHS_HVPrc_between"                                                                                                                              ,"Longitude","Latitude")])
msb2a<-fitme(SexTr~Yearf+DHS_HVPrc_within         +DHS_HVPrc_between+USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=zs[,c("SexTr","Yearf","DHS_HVPrc_within","DHS_HVPrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])
msb3a<-fitme(SexTr~Yearf+DHS_HVPrc_within*USDA_RUC+DHS_HVPrc_between*USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=zs[,c("SexTr","Yearf","DHS_HVPrc_within","DHS_HVPrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])
msb4a<-fitme(SexTr~Yearf+DHS_HVPrc_within*USDA_RUC+DHS_HVPrc_between+USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=zs[,c("SexTr","Yearf","DHS_HVPrc_within","DHS_HVPrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])
msb5a<-fitme(SexTr~Yearf+DHS_HVPrc_within+USDA_RUC+DHS_HVPrc_between*USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=zs[,c("SexTr","Yearf","DHS_HVPrc_within","DHS_HVPrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])

msb0c<-fitme(SexTr~Yearf                                                                                                                                                  +Matern(1|Longitude+Latitude),data=zs2[!is.na(MHV_C5kc) ,c("SexTr","Yearf"                                                                                                                                                    ,"Longitude","Latitude")])
msb1c<-fitme(SexTr~Yearf+MHV_C5kc_within          +MHV_C5kc_between                                                                                                       +Matern(1|Longitude+Latitude),data=zs2[,c("SexTr","Yearf","MHV_C5kc_within" ,"MHV_C5kc_between"                                                                                                                               ,"Longitude","Latitude")])
msb2c<-fitme(SexTr~Yearf+MHV_C5kc_within          +MHV_C5kc_between +USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=zs2[,c("SexTr","Yearf","MHV_C5kc_within" ,"MHV_C5kc_between" ,"USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])
msb3c<-fitme(SexTr~Yearf+MHV_C5kc_within *USDA_RUC+MHV_C5kc_between *USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=zs2[,c("SexTr","Yearf","MHV_C5kc_within" ,"MHV_C5kc_between" ,"USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])
msb4c<-fitme(SexTr~Yearf+MHV_C5kc_within *USDA_RUC+MHV_C5kc_between +USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=zs2[,c("SexTr","Yearf","MHV_C5kc_within" ,"MHV_C5kc_between" ,"USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])
msb5c<-fitme(SexTr~Yearf+MHV_C5kc_within +USDA_RUC+MHV_C5kc_between *USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=zs2[,c("SexTr","Yearf","MHV_C5kc_within" ,"MHV_C5kc_between" ,"USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])

# msb0b<-fitme(SexTr~Yearf                                                                                                                                                  +Matern(1|Longitude+Latitude),data=zs[!is.na(IDHS_EIrc),c("SexTr","Yearf"                                                                                                                                                    ,"Longitude","Latitude")])
# msb1b<-fitme(SexTr~Yearf+IDHS_EIrc_within         +IDHS_EIrc_between                                                                                                      +Matern(1|Longitude+Latitude),data=zs[,c("SexTr","Yearf","IDHS_EIrc_within","IDHS_EIrc_between"                                                                                                                              ,"Longitude","Latitude")])
# msb2b<-fitme(SexTr~Yearf+IDHS_EIrc_within         +IDHS_EIrc_between+USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=zs[,c("SexTr","Yearf","IDHS_EIrc_within","IDHS_EIrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])
# msb3b<-fitme(SexTr~Yearf+IDHS_EIrc_within*USDA_RUC+IDHS_EIrc_between*USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=zs[,c("SexTr","Yearf","IDHS_EIrc_within","IDHS_EIrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])
# msb4b<-fitme(SexTr~Yearf+IDHS_EIrc_within*USDA_RUC+IDHS_EIrc_between+USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=zs[,c("SexTr","Yearf","IDHS_EIrc_within","IDHS_EIrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])
# msb5b<-fitme(SexTr~Yearf+IDHS_EIrc_within+USDA_RUC+IDHS_EIrc_between*USDA_RUC+RPovTc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornTc+ChildPTc+ElderTc+MalePTc+DisablTc+MoveTc+Matern(1|Longitude+Latitude),data=zs[,c("SexTr","Yearf","IDHS_EIrc_within","IDHS_EIrc_between","USDA_RUC","RPovTc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornTc","ChildPTc","ElderTc","MalePTc","DisablTc","MoveTc","Longitude","Latitude")])

save.image("Z:/CDCK01/Analysis/ZipCode/HomeVisit/HomeVisit02_Model3_2.RData")





# White
mwa0a<-   lm(RptWr~Yearf                                                                                                                                                                               ,data=zw[!is.na(DHS_HVPrc),c("RptWr","Yearf"                                                                                                                                                                           )])
mwa1a<-   lm(RptWr~Yearf+DHS_HVPrc_within         +DHS_HVPrc_between                                                                                                                                   ,data=zw[,c("RptWr","Yearf","DHS_HVPrc_within","DHS_HVPrc_between"                                                                                                                                                     )])
mwa2a<-   lm(RptWr~Yearf+DHS_HVPrc_within         +DHS_HVPrc_between+USDA_RUC+RPovWc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornWc+ChildPWc+ElderWc+MalePWc+DisablWc+MoveWc                             ,data=zw[,c("RptWr","Yearf","DHS_HVPrc_within","DHS_HVPrc_between","USDA_RUC","RPovWc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornWc","ChildPWc","ElderWc","MalePWc","DisablWc","MoveWc"                       )])
mwa3a<-   lm(RptWr~Yearf+DHS_HVPrc_within*USDA_RUC+DHS_HVPrc_between*USDA_RUC+RPovWc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornWc+ChildPWc+ElderWc+MalePWc+DisablWc+MoveWc                             ,data=zw[,c("RptWr","Yearf","DHS_HVPrc_within","DHS_HVPrc_between","USDA_RUC","RPovWc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornWc","ChildPWc","ElderWc","MalePWc","DisablWc","MoveWc"                       )])

mwa0c<-   lm(RptWr~Yearf                                                                                                                                                                               ,data=zw2[!is.na(MHV_C5kc) ,c("RptWr","Yearf"                                                                                                                                                                           )])
mwa1c<-   lm(RptWr~Yearf+MHV_C5kc_within          +MHV_C5kc_between                                                                                                                                    ,data=zw2[,c("RptWr","Yearf","MHV_C5kc_within" ,"MHV_C5kc_between"                                                                                                                                                      )])
mwa2c<-   lm(RptWr~Yearf+MHV_C5kc_within          +MHV_C5kc_between +USDA_RUC+RPovWc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornWc+ChildPWc+ElderWc+MalePWc+DisablWc+MoveWc                             ,data=zw2[,c("RptWr","Yearf","MHV_C5kc_within" ,"MHV_C5kc_between" ,"USDA_RUC","RPovWc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornWc","ChildPWc","ElderWc","MalePWc","DisablWc","MoveWc"                       )])
mwa3c<-   lm(RptWr~Yearf+MHV_C5kc_within *USDA_RUC+MHV_C5kc_between *USDA_RUC+RPovWc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornWc+ChildPWc+ElderWc+MalePWc+DisablWc+MoveWc                             ,data=zw2[,c("RptWr","Yearf","MHV_C5kc_within" ,"MHV_C5kc_between" ,"USDA_RUC","RPovWc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornWc","ChildPWc","ElderWc","MalePWc","DisablWc","MoveWc"                       )])

# mwa0b<-   lm(RptWr~Yearf                                                                                                                                                                               ,data=zw[!is.na(IDHS_EIrc),c("RptWr","Yearf"                                                                                                                                                                           )])
# mwa1b<-   lm(RptWr~Yearf+IDHS_EIrc_within         +IDHS_EIrc_between                                                                                                                                   ,data=zw[,c("RptWr","Yearf","IDHS_EIrc_within","IDHS_EIrc_between"                                                                                                                                                     )])
# mwa2b<-   lm(RptWr~Yearf+IDHS_EIrc_within         +IDHS_EIrc_between+USDA_RUC+RPovWc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornWc+ChildPWc+ElderWc+MalePWc+DisablWc+MoveWc                             ,data=zw[,c("RptWr","Yearf","IDHS_EIrc_within","IDHS_EIrc_between","USDA_RUC","RPovWc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornWc","ChildPWc","ElderWc","MalePWc","DisablWc","MoveWc"                       )])
# mwa3b<-   lm(RptWr~Yearf+IDHS_EIrc_within*USDA_RUC+IDHS_EIrc_between*USDA_RUC+RPovWc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornWc+ChildPWc+ElderWc+MalePWc+DisablWc+MoveWc                             ,data=zw[,c("RptWr","Yearf","IDHS_EIrc_within","IDHS_EIrc_between","USDA_RUC","RPovWc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornWc","ChildPWc","ElderWc","MalePWc","DisablWc","MoveWc"                       )])

mwb0a<-fitme(RptWr~Yearf                                                                                                                                                  +Matern(1|Longitude+Latitude),data=zw[!is.na(DHS_HVPrc),c("RptWr","Yearf"                                                                                                                                                    ,"Longitude","Latitude")])
mwb1a<-fitme(RptWr~Yearf+DHS_HVPrc_within         +DHS_HVPrc_between                                                                                                      +Matern(1|Longitude+Latitude),data=zw[,c("RptWr","Yearf","DHS_HVPrc_within","DHS_HVPrc_between"                                                                                                                              ,"Longitude","Latitude")])
mwb2a<-fitme(RptWr~Yearf+DHS_HVPrc_within         +DHS_HVPrc_between+USDA_RUC+RPovWc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornWc+ChildPWc+ElderWc+MalePWc+DisablWc+MoveWc+Matern(1|Longitude+Latitude),data=zw[,c("RptWr","Yearf","DHS_HVPrc_within","DHS_HVPrc_between","USDA_RUC","RPovWc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornWc","ChildPWc","ElderWc","MalePWc","DisablWc","MoveWc","Longitude","Latitude")])
mwb3a<-fitme(RptWr~Yearf+DHS_HVPrc_within*USDA_RUC+DHS_HVPrc_between*USDA_RUC+RPovWc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornWc+ChildPWc+ElderWc+MalePWc+DisablWc+MoveWc+Matern(1|Longitude+Latitude),data=zw[,c("RptWr","Yearf","DHS_HVPrc_within","DHS_HVPrc_between","USDA_RUC","RPovWc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornWc","ChildPWc","ElderWc","MalePWc","DisablWc","MoveWc","Longitude","Latitude")])
mwb4a<-fitme(RptWr~Yearf+DHS_HVPrc_within*USDA_RUC+DHS_HVPrc_between+USDA_RUC+RPovWc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornWc+ChildPWc+ElderWc+MalePWc+DisablWc+MoveWc+Matern(1|Longitude+Latitude),data=zw[,c("RptWr","Yearf","DHS_HVPrc_within","DHS_HVPrc_between","USDA_RUC","RPovWc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornWc","ChildPWc","ElderWc","MalePWc","DisablWc","MoveWc","Longitude","Latitude")])
mwb5a<-fitme(RptWr~Yearf+DHS_HVPrc_within+USDA_RUC+DHS_HVPrc_between*USDA_RUC+RPovWc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornWc+ChildPWc+ElderWc+MalePWc+DisablWc+MoveWc+Matern(1|Longitude+Latitude),data=zw[,c("RptWr","Yearf","DHS_HVPrc_within","DHS_HVPrc_between","USDA_RUC","RPovWc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornWc","ChildPWc","ElderWc","MalePWc","DisablWc","MoveWc","Longitude","Latitude")])

mwb0c<-fitme(RptWr~Yearf                                                                                                                                                  +Matern(1|Longitude+Latitude),data=zw2[!is.na(MHV_C5kc) ,c("RptWr","Yearf"                                                                                                                                                    ,"Longitude","Latitude")])
mwb1c<-fitme(RptWr~Yearf+MHV_C5kc_within          +MHV_C5kc_between                                                                                                       +Matern(1|Longitude+Latitude),data=zw2[,c("RptWr","Yearf","MHV_C5kc_within" ,"MHV_C5kc_between"                                                                                                                               ,"Longitude","Latitude")])
mwb2c<-fitme(RptWr~Yearf+MHV_C5kc_within          +MHV_C5kc_between +USDA_RUC+RPovWc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornWc+ChildPWc+ElderWc+MalePWc+DisablWc+MoveWc+Matern(1|Longitude+Latitude),data=zw2[,c("RptWr","Yearf","MHV_C5kc_within" ,"MHV_C5kc_between" ,"USDA_RUC","RPovWc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornWc","ChildPWc","ElderWc","MalePWc","DisablWc","MoveWc","Longitude","Latitude")])
mwb3c<-fitme(RptWr~Yearf+MHV_C5kc_within *USDA_RUC+MHV_C5kc_between *USDA_RUC+RPovWc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornWc+ChildPWc+ElderWc+MalePWc+DisablWc+MoveWc+Matern(1|Longitude+Latitude),data=zw2[,c("RptWr","Yearf","MHV_C5kc_within" ,"MHV_C5kc_between" ,"USDA_RUC","RPovWc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornWc","ChildPWc","ElderWc","MalePWc","DisablWc","MoveWc","Longitude","Latitude")])
mwb4c<-fitme(RptWr~Yearf+MHV_C5kc_within *USDA_RUC+MHV_C5kc_between +USDA_RUC+RPovWc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornWc+ChildPWc+ElderWc+MalePWc+DisablWc+MoveWc+Matern(1|Longitude+Latitude),data=zw2[,c("RptWr","Yearf","MHV_C5kc_within" ,"MHV_C5kc_between" ,"USDA_RUC","RPovWc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornWc","ChildPWc","ElderWc","MalePWc","DisablWc","MoveWc","Longitude","Latitude")])
mwb5c<-fitme(RptWr~Yearf+MHV_C5kc_within +USDA_RUC+MHV_C5kc_between *USDA_RUC+RPovWc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornWc+ChildPWc+ElderWc+MalePWc+DisablWc+MoveWc+Matern(1|Longitude+Latitude),data=zw2[,c("RptWr","Yearf","MHV_C5kc_within" ,"MHV_C5kc_between" ,"USDA_RUC","RPovWc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornWc","ChildPWc","ElderWc","MalePWc","DisablWc","MoveWc","Longitude","Latitude")])

# mwb0b<-fitme(RptWr~Yearf                                                                                                                                                  +Matern(1|Longitude+Latitude),data=zw[!is.na(IDHS_EIrc),c("RptWr","Yearf"                                                                                                                                                    ,"Longitude","Latitude")])
# mwb1b<-fitme(RptWr~Yearf+IDHS_EIrc_within         +IDHS_EIrc_between                                                                                                      +Matern(1|Longitude+Latitude),data=zw[,c("RptWr","Yearf","IDHS_EIrc_within","IDHS_EIrc_between"                                                                                                                              ,"Longitude","Latitude")])
# mwb2b<-fitme(RptWr~Yearf+IDHS_EIrc_within         +IDHS_EIrc_between+USDA_RUC+RPovWc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornWc+ChildPWc+ElderWc+MalePWc+DisablWc+MoveWc+Matern(1|Longitude+Latitude),data=zw[,c("RptWr","Yearf","IDHS_EIrc_within","IDHS_EIrc_between","USDA_RUC","RPovWc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornWc","ChildPWc","ElderWc","MalePWc","DisablWc","MoveWc","Longitude","Latitude")])
# mwb3b<-fitme(RptWr~Yearf+IDHS_EIrc_within*USDA_RUC+IDHS_EIrc_between*USDA_RUC+RPovWc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornWc+ChildPWc+ElderWc+MalePWc+DisablWc+MoveWc+Matern(1|Longitude+Latitude),data=zw[,c("RptWr","Yearf","IDHS_EIrc_within","IDHS_EIrc_between","USDA_RUC","RPovWc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornWc","ChildPWc","ElderWc","MalePWc","DisablWc","MoveWc","Longitude","Latitude")])
# mwb4b<-fitme(RptWr~Yearf+IDHS_EIrc_within*USDA_RUC+IDHS_EIrc_between+USDA_RUC+RPovWc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornWc+ChildPWc+ElderWc+MalePWc+DisablWc+MoveWc+Matern(1|Longitude+Latitude),data=zw[,c("RptWr","Yearf","IDHS_EIrc_within","IDHS_EIrc_between","USDA_RUC","RPovWc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornWc","ChildPWc","ElderWc","MalePWc","DisablWc","MoveWc","Longitude","Latitude")])
# mwb5b<-fitme(RptWr~Yearf+IDHS_EIrc_within+USDA_RUC+IDHS_EIrc_between*USDA_RUC+RPovWc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornWc+ChildPWc+ElderWc+MalePWc+DisablWc+MoveWc+Matern(1|Longitude+Latitude),data=zw[,c("RptWr","Yearf","IDHS_EIrc_within","IDHS_EIrc_between","USDA_RUC","RPovWc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornWc","ChildPWc","ElderWc","MalePWc","DisablWc","MoveWc","Longitude","Latitude")])

save.image("Z:/CDCK01/Analysis/ZipCode/HomeVisit/HomeVisit02_Model1_2.RData")





# Black
mba0a<-   lm(RptBr~Yearf                                                                                                                                                                               ,data=zb[!is.na(DHS_HVPrc),c("RptBr","Yearf"                                                                                                                                                                           )])
mba1a<-   lm(RptBr~Yearf+DHS_HVPrc_within         +DHS_HVPrc_between                                                                                                                                   ,data=zb[,c("RptBr","Yearf","DHS_HVPrc_within","DHS_HVPrc_between"                                                                                                                                                     )])
mba2a<-   lm(RptBr~Yearf+DHS_HVPrc_within         +DHS_HVPrc_between+USDA_RUC+RPovBc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornBc+ChildPBc+ElderBc+MalePBc+DisablBc+MoveBc                             ,data=zb[,c("RptBr","Yearf","DHS_HVPrc_within","DHS_HVPrc_between","USDA_RUC","RPovBc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornBc","ChildPBc","ElderBc","MalePBc","DisablBc","MoveBc"                       )])
mba3a<-   lm(RptBr~Yearf+DHS_HVPrc_within*USDA_RUC+DHS_HVPrc_between*USDA_RUC+RPovBc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornBc+ChildPBc+ElderBc+MalePBc+DisablBc+MoveBc                             ,data=zb[,c("RptBr","Yearf","DHS_HVPrc_within","DHS_HVPrc_between","USDA_RUC","RPovBc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornBc","ChildPBc","ElderBc","MalePBc","DisablBc","MoveBc"                       )])

mba0c<-   lm(RptBr~Yearf                                                                                                                                                                               ,data=zb2[!is.na(MHV_C5kc) ,c("RptBr","Yearf"                                                                                                                                                                           )])
mba1c<-   lm(RptBr~Yearf+MHV_C5kc_within          +MHV_C5kc_between                                                                                                                                    ,data=zb2[,c("RptBr","Yearf","MHV_C5kc_within" ,"MHV_C5kc_between"                                                                                                                                                      )])
mba2c<-   lm(RptBr~Yearf+MHV_C5kc_within          +MHV_C5kc_between +USDA_RUC+RPovBc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornBc+ChildPBc+ElderBc+MalePBc+DisablBc+MoveBc                             ,data=zb2[,c("RptBr","Yearf","MHV_C5kc_within" ,"MHV_C5kc_between" ,"USDA_RUC","RPovBc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornBc","ChildPBc","ElderBc","MalePBc","DisablBc","MoveBc"                       )])
mba3c<-   lm(RptBr~Yearf+MHV_C5kc_within *USDA_RUC+MHV_C5kc_between *USDA_RUC+RPovBc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornBc+ChildPBc+ElderBc+MalePBc+DisablBc+MoveBc                             ,data=zb2[,c("RptBr","Yearf","MHV_C5kc_within" ,"MHV_C5kc_between" ,"USDA_RUC","RPovBc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornBc","ChildPBc","ElderBc","MalePBc","DisablBc","MoveBc"                       )])

# mba0b<-   lm(RptBr~Yearf                                                                                                                                                                               ,data=zb[!is.na(IDHS_EIrc),c("RptBr","Yearf"                                                                                                                                                                           )])
# mba1b<-   lm(RptBr~Yearf+IDHS_EIrc_within         +IDHS_EIrc_between                                                                                                                                   ,data=zb[,c("RptBr","Yearf","IDHS_EIrc_within","IDHS_EIrc_between"                                                                                                                                                     )])
# mba2b<-   lm(RptBr~Yearf+IDHS_EIrc_within         +IDHS_EIrc_between+USDA_RUC+RPovBc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornBc+ChildPBc+ElderBc+MalePBc+DisablBc+MoveBc                             ,data=zb[,c("RptBr","Yearf","IDHS_EIrc_within","IDHS_EIrc_between","USDA_RUC","RPovBc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornBc","ChildPBc","ElderBc","MalePBc","DisablBc","MoveBc"                       )])
# mba3b<-   lm(RptBr~Yearf+IDHS_EIrc_within*USDA_RUC+IDHS_EIrc_between*USDA_RUC+RPovBc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornBc+ChildPBc+ElderBc+MalePBc+DisablBc+MoveBc                             ,data=zb[,c("RptBr","Yearf","IDHS_EIrc_within","IDHS_EIrc_between","USDA_RUC","RPovBc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornBc","ChildPBc","ElderBc","MalePBc","DisablBc","MoveBc"                       )])

mbb0a<-fitme(RptBr~Yearf                                                                                                                                                  +Matern(1|Longitude+Latitude),data=zb[!is.na(DHS_HVPrc),c("RptBr","Yearf"                                                                                                                                                    ,"Longitude","Latitude")])
mbb1a<-fitme(RptBr~Yearf+DHS_HVPrc_within         +DHS_HVPrc_between                                                                                                      +Matern(1|Longitude+Latitude),data=zb[,c("RptBr","Yearf","DHS_HVPrc_within","DHS_HVPrc_between"                                                                                                                              ,"Longitude","Latitude")])
mbb2a<-fitme(RptBr~Yearf+DHS_HVPrc_within         +DHS_HVPrc_between+USDA_RUC+RPovBc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornBc+ChildPBc+ElderBc+MalePBc+DisablBc+MoveBc+Matern(1|Longitude+Latitude),data=zb[,c("RptBr","Yearf","DHS_HVPrc_within","DHS_HVPrc_between","USDA_RUC","RPovBc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornBc","ChildPBc","ElderBc","MalePBc","DisablBc","MoveBc","Longitude","Latitude")])
mbb3a<-fitme(RptBr~Yearf+DHS_HVPrc_within*USDA_RUC+DHS_HVPrc_between*USDA_RUC+RPovBc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornBc+ChildPBc+ElderBc+MalePBc+DisablBc+MoveBc+Matern(1|Longitude+Latitude),data=zb[,c("RptBr","Yearf","DHS_HVPrc_within","DHS_HVPrc_between","USDA_RUC","RPovBc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornBc","ChildPBc","ElderBc","MalePBc","DisablBc","MoveBc","Longitude","Latitude")])
mbb4a<-fitme(RptBr~Yearf+DHS_HVPrc_within*USDA_RUC+DHS_HVPrc_between+USDA_RUC+RPovBc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornBc+ChildPBc+ElderBc+MalePBc+DisablBc+MoveBc+Matern(1|Longitude+Latitude),data=zb[,c("RptBr","Yearf","DHS_HVPrc_within","DHS_HVPrc_between","USDA_RUC","RPovBc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornBc","ChildPBc","ElderBc","MalePBc","DisablBc","MoveBc","Longitude","Latitude")])
mbb5a<-fitme(RptBr~Yearf+DHS_HVPrc_within+USDA_RUC+DHS_HVPrc_between*USDA_RUC+RPovBc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornBc+ChildPBc+ElderBc+MalePBc+DisablBc+MoveBc+Matern(1|Longitude+Latitude),data=zb[,c("RptBr","Yearf","DHS_HVPrc_within","DHS_HVPrc_between","USDA_RUC","RPovBc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornBc","ChildPBc","ElderBc","MalePBc","DisablBc","MoveBc","Longitude","Latitude")])

mbb0c<-fitme(RptBr~Yearf                                                                                                                                                  +Matern(1|Longitude+Latitude),data=zb2[!is.na(MHV_C5kc) ,c("RptBr","Yearf"                                                                                                                                                    ,"Longitude","Latitude")])
mbb1c<-fitme(RptBr~Yearf+MHV_C5kc_within          +MHV_C5kc_between                                                                                                       +Matern(1|Longitude+Latitude),data=zb2[,c("RptBr","Yearf","MHV_C5kc_within" ,"MHV_C5kc_between"                                                                                                                               ,"Longitude","Latitude")])
mbb2c<-fitme(RptBr~Yearf+MHV_C5kc_within          +MHV_C5kc_between +USDA_RUC+RPovBc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornBc+ChildPBc+ElderBc+MalePBc+DisablBc+MoveBc+Matern(1|Longitude+Latitude),data=zb2[,c("RptBr","Yearf","MHV_C5kc_within" ,"MHV_C5kc_between" ,"USDA_RUC","RPovBc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornBc","ChildPBc","ElderBc","MalePBc","DisablBc","MoveBc","Longitude","Latitude")])
mbb3c<-fitme(RptBr~Yearf+MHV_C5kc_within *USDA_RUC+MHV_C5kc_between *USDA_RUC+RPovBc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornBc+ChildPBc+ElderBc+MalePBc+DisablBc+MoveBc+Matern(1|Longitude+Latitude),data=zb2[,c("RptBr","Yearf","MHV_C5kc_within" ,"MHV_C5kc_between" ,"USDA_RUC","RPovBc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornBc","ChildPBc","ElderBc","MalePBc","DisablBc","MoveBc","Longitude","Latitude")])
mbb4c<-fitme(RptBr~Yearf+MHV_C5kc_within *USDA_RUC+MHV_C5kc_between +USDA_RUC+RPovBc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornBc+ChildPBc+ElderBc+MalePBc+DisablBc+MoveBc+Matern(1|Longitude+Latitude),data=zb2[,c("RptBr","Yearf","MHV_C5kc_within" ,"MHV_C5kc_between" ,"USDA_RUC","RPovBc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornBc","ChildPBc","ElderBc","MalePBc","DisablBc","MoveBc","Longitude","Latitude")])
mbb5c<-fitme(RptBr~Yearf+MHV_C5kc_within +USDA_RUC+MHV_C5kc_between *USDA_RUC+RPovBc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornBc+ChildPBc+ElderBc+MalePBc+DisablBc+MoveBc+Matern(1|Longitude+Latitude),data=zb2[,c("RptBr","Yearf","MHV_C5kc_within" ,"MHV_C5kc_between" ,"USDA_RUC","RPovBc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornBc","ChildPBc","ElderBc","MalePBc","DisablBc","MoveBc","Longitude","Latitude")])

# mbb0b<-fitme(RptBr~Yearf                                                                                                                                                  +Matern(1|Longitude+Latitude),data=zb[!is.na(IDHS_EIrc),c("RptBr","Yearf"                                                                                                                                                    ,"Longitude","Latitude")])
# mbb1b<-fitme(RptBr~Yearf+IDHS_EIrc_within         +IDHS_EIrc_between                                                                                                      +Matern(1|Longitude+Latitude),data=zb[,c("RptBr","Yearf","IDHS_EIrc_within","IDHS_EIrc_between"                                                                                                                              ,"Longitude","Latitude")])
# mbb2b<-fitme(RptBr~Yearf+IDHS_EIrc_within         +IDHS_EIrc_between+USDA_RUC+RPovBc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornBc+ChildPBc+ElderBc+MalePBc+DisablBc+MoveBc+Matern(1|Longitude+Latitude),data=zb[,c("RptBr","Yearf","IDHS_EIrc_within","IDHS_EIrc_between","USDA_RUC","RPovBc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornBc","ChildPBc","ElderBc","MalePBc","DisablBc","MoveBc","Longitude","Latitude")])
# mbb3b<-fitme(RptBr~Yearf+IDHS_EIrc_within*USDA_RUC+IDHS_EIrc_between*USDA_RUC+RPovBc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornBc+ChildPBc+ElderBc+MalePBc+DisablBc+MoveBc+Matern(1|Longitude+Latitude),data=zb[,c("RptBr","Yearf","IDHS_EIrc_within","IDHS_EIrc_between","USDA_RUC","RPovBc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornBc","ChildPBc","ElderBc","MalePBc","DisablBc","MoveBc","Longitude","Latitude")])
# mbb4b<-fitme(RptBr~Yearf+IDHS_EIrc_within*USDA_RUC+IDHS_EIrc_between+USDA_RUC+RPovBc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornBc+ChildPBc+ElderBc+MalePBc+DisablBc+MoveBc+Matern(1|Longitude+Latitude),data=zb[,c("RptBr","Yearf","IDHS_EIrc_within","IDHS_EIrc_between","USDA_RUC","RPovBc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornBc","ChildPBc","ElderBc","MalePBc","DisablBc","MoveBc","Longitude","Latitude")])
# mbb5b<-fitme(RptBr~Yearf+IDHS_EIrc_within+USDA_RUC+IDHS_EIrc_between*USDA_RUC+RPovBc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornBc+ChildPBc+ElderBc+MalePBc+DisablBc+MoveBc+Matern(1|Longitude+Latitude),data=zb[,c("RptBr","Yearf","IDHS_EIrc_within","IDHS_EIrc_between","USDA_RUC","RPovBc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornBc","ChildPBc","ElderBc","MalePBc","DisablBc","MoveBc","Longitude","Latitude")])

save.image("Z:/CDCK01/Analysis/ZipCode/HomeVisit/HomeVisit02_Model2_2.RData")





# Hispanic
mha0a<-   lm(RptHr~Yearf                                                                                                                                                                               ,data=zh[!is.na(DHS_HVPrc),c("RptHr","Yearf"                                                                                                                                                                           )])
mha1a<-   lm(RptHr~Yearf+DHS_HVPrc_within         +DHS_HVPrc_between                                                                                                                                   ,data=zh[,c("RptHr","Yearf","DHS_HVPrc_within","DHS_HVPrc_between"                                                                                                                                                     )])
mha2a<-   lm(RptHr~Yearf+DHS_HVPrc_within         +DHS_HVPrc_between+USDA_RUC+RPovHc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornHc+ChildPHc+ElderHc+MalePHc+DisablHc+MoveHc                             ,data=zh[,c("RptHr","Yearf","DHS_HVPrc_within","DHS_HVPrc_between","USDA_RUC","RPovHc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornHc","ChildPHc","ElderHc","MalePHc","DisablHc","MoveHc"                       )])
mha3a<-   lm(RptHr~Yearf+DHS_HVPrc_within*USDA_RUC+DHS_HVPrc_between*USDA_RUC+RPovHc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornHc+ChildPHc+ElderHc+MalePHc+DisablHc+MoveHc                             ,data=zh[,c("RptHr","Yearf","DHS_HVPrc_within","DHS_HVPrc_between","USDA_RUC","RPovHc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornHc","ChildPHc","ElderHc","MalePHc","DisablHc","MoveHc"                       )])

mha0c<-   lm(RptHr~Yearf                                                                                                                                                                               ,data=zh2[!is.na(MHV_C5kc) ,c("RptHr","Yearf"                                                                                                                                                                           )])
mha1c<-   lm(RptHr~Yearf+MHV_C5kc_within          +MHV_C5kc_between                                                                                                                                    ,data=zh2[,c("RptHr","Yearf","MHV_C5kc_within" ,"MHV_C5kc_between"                                                                                                                                                      )])
mha2c<-   lm(RptHr~Yearf+MHV_C5kc_within          +MHV_C5kc_between +USDA_RUC+RPovHc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornHc+ChildPHc+ElderHc+MalePHc+DisablHc+MoveHc                             ,data=zh2[,c("RptHr","Yearf","MHV_C5kc_within" ,"MHV_C5kc_between" ,"USDA_RUC","RPovHc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornHc","ChildPHc","ElderHc","MalePHc","DisablHc","MoveHc"                       )])
mha3c<-   lm(RptHr~Yearf+MHV_C5kc_within *USDA_RUC+MHV_C5kc_between *USDA_RUC+RPovHc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornHc+ChildPHc+ElderHc+MalePHc+DisablHc+MoveHc                             ,data=zh2[,c("RptHr","Yearf","MHV_C5kc_within" ,"MHV_C5kc_between" ,"USDA_RUC","RPovHc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornHc","ChildPHc","ElderHc","MalePHc","DisablHc","MoveHc"                       )])

# mha0b<-   lm(RptHr~Yearf                                                                                                                                                                               ,data=zh[!is.na(IDHS_EIrc),c("RptHr","Yearf"                                                                                                                                                                           )])
# mha1b<-   lm(RptHr~Yearf+IDHS_EIrc_within         +IDHS_EIrc_between                                                                                                                                   ,data=zh[,c("RptHr","Yearf","IDHS_EIrc_within","IDHS_EIrc_between"                                                                                                                                                     )])
# mha2b<-   lm(RptHr~Yearf+IDHS_EIrc_within         +IDHS_EIrc_between+USDA_RUC+RPovHc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornHc+ChildPHc+ElderHc+MalePHc+DisablHc+MoveHc                             ,data=zh[,c("RptHr","Yearf","IDHS_EIrc_within","IDHS_EIrc_between","USDA_RUC","RPovHc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornHc","ChildPHc","ElderHc","MalePHc","DisablHc","MoveHc"                       )])
# mha3b<-   lm(RptHr~Yearf+IDHS_EIrc_within*USDA_RUC+IDHS_EIrc_between*USDA_RUC+RPovHc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornHc+ChildPHc+ElderHc+MalePHc+DisablHc+MoveHc                             ,data=zh[,c("RptHr","Yearf","IDHS_EIrc_within","IDHS_EIrc_between","USDA_RUC","RPovHc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornHc","ChildPHc","ElderHc","MalePHc","DisablHc","MoveHc"                       )])

mhb0a<-fitme(RptHr~Yearf                                                                                                                                                  +Matern(1|Longitude+Latitude),data=zh[!is.na(DHS_HVPrc),c("RptHr","Yearf"                                                                                                                                                    ,"Longitude","Latitude")])
mhb1a<-fitme(RptHr~Yearf+DHS_HVPrc_within         +DHS_HVPrc_between                                                                                                      +Matern(1|Longitude+Latitude),data=zh[,c("RptHr","Yearf","DHS_HVPrc_within","DHS_HVPrc_between"                                                                                                                              ,"Longitude","Latitude")])
mhb2a<-fitme(RptHr~Yearf+DHS_HVPrc_within         +DHS_HVPrc_between+USDA_RUC+RPovHc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornHc+ChildPHc+ElderHc+MalePHc+DisablHc+MoveHc+Matern(1|Longitude+Latitude),data=zh[,c("RptHr","Yearf","DHS_HVPrc_within","DHS_HVPrc_between","USDA_RUC","RPovHc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornHc","ChildPHc","ElderHc","MalePHc","DisablHc","MoveHc","Longitude","Latitude")])
mhb3a<-fitme(RptHr~Yearf+DHS_HVPrc_within*USDA_RUC+DHS_HVPrc_between*USDA_RUC+RPovHc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornHc+ChildPHc+ElderHc+MalePHc+DisablHc+MoveHc+Matern(1|Longitude+Latitude),data=zh[,c("RptHr","Yearf","DHS_HVPrc_within","DHS_HVPrc_between","USDA_RUC","RPovHc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornHc","ChildPHc","ElderHc","MalePHc","DisablHc","MoveHc","Longitude","Latitude")])
mhb4a<-fitme(RptHr~Yearf+DHS_HVPrc_within*USDA_RUC+DHS_HVPrc_between+USDA_RUC+RPovHc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornHc+ChildPHc+ElderHc+MalePHc+DisablHc+MoveHc+Matern(1|Longitude+Latitude),data=zh[,c("RptHr","Yearf","DHS_HVPrc_within","DHS_HVPrc_between","USDA_RUC","RPovHc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornHc","ChildPHc","ElderHc","MalePHc","DisablHc","MoveHc","Longitude","Latitude")])
mhb5a<-fitme(RptHr~Yearf+DHS_HVPrc_within+USDA_RUC+DHS_HVPrc_between*USDA_RUC+RPovHc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornHc+ChildPHc+ElderHc+MalePHc+DisablHc+MoveHc+Matern(1|Longitude+Latitude),data=zh[,c("RptHr","Yearf","DHS_HVPrc_within","DHS_HVPrc_between","USDA_RUC","RPovHc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornHc","ChildPHc","ElderHc","MalePHc","DisablHc","MoveHc","Longitude","Latitude")])

mhb0c<-fitme(RptHr~Yearf                                                                                                                                                  +Matern(1|Longitude+Latitude),data=zh2[!is.na(MHV_C5kc) ,c("RptHr","Yearf"                                                                                                                                                    ,"Longitude","Latitude")])
mhb1c<-fitme(RptHr~Yearf+MHV_C5kc_within          +MHV_C5kc_between                                                                                                       +Matern(1|Longitude+Latitude),data=zh2[,c("RptHr","Yearf","MHV_C5kc_within" ,"MHV_C5kc_between"                                                                                                                               ,"Longitude","Latitude")])
mhb2c<-fitme(RptHr~Yearf+MHV_C5kc_within          +MHV_C5kc_between +USDA_RUC+RPovHc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornHc+ChildPHc+ElderHc+MalePHc+DisablHc+MoveHc+Matern(1|Longitude+Latitude),data=zh2[,c("RptHr","Yearf","MHV_C5kc_within" ,"MHV_C5kc_between" ,"USDA_RUC","RPovHc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornHc","ChildPHc","ElderHc","MalePHc","DisablHc","MoveHc","Longitude","Latitude")])
mhb3c<-fitme(RptHr~Yearf+MHV_C5kc_within *USDA_RUC+MHV_C5kc_between *USDA_RUC+RPovHc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornHc+ChildPHc+ElderHc+MalePHc+DisablHc+MoveHc+Matern(1|Longitude+Latitude),data=zh2[,c("RptHr","Yearf","MHV_C5kc_within" ,"MHV_C5kc_between" ,"USDA_RUC","RPovHc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornHc","ChildPHc","ElderHc","MalePHc","DisablHc","MoveHc","Longitude","Latitude")])
mhb4c<-fitme(RptHr~Yearf+MHV_C5kc_within *USDA_RUC+MHV_C5kc_between +USDA_RUC+RPovHc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornHc+ChildPHc+ElderHc+MalePHc+DisablHc+MoveHc+Matern(1|Longitude+Latitude),data=zh2[,c("RptHr","Yearf","MHV_C5kc_within" ,"MHV_C5kc_between" ,"USDA_RUC","RPovHc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornHc","ChildPHc","ElderHc","MalePHc","DisablHc","MoveHc","Longitude","Latitude")])
mhb5c<-fitme(RptHr~Yearf+MHV_C5kc_within +USDA_RUC+MHV_C5kc_between *USDA_RUC+RPovHc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornHc+ChildPHc+ElderHc+MalePHc+DisablHc+MoveHc+Matern(1|Longitude+Latitude),data=zh2[,c("RptHr","Yearf","MHV_C5kc_within" ,"MHV_C5kc_between" ,"USDA_RUC","RPovHc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornHc","ChildPHc","ElderHc","MalePHc","DisablHc","MoveHc","Longitude","Latitude")])

# mhb0b<-fitme(RptHr~Yearf                                                                                                                                                  +Matern(1|Longitude+Latitude),data=zh[!is.na(IDHS_EIrc),c("RptHr","Yearf"                                                                                                                                                    ,"Longitude","Latitude")])
# mhb1b<-fitme(RptHr~Yearf+IDHS_EIrc_within         +IDHS_EIrc_between                                                                                                      +Matern(1|Longitude+Latitude),data=zh[,c("RptHr","Yearf","IDHS_EIrc_within","IDHS_EIrc_between"                                                                                                                              ,"Longitude","Latitude")])
# mhb2b<-fitme(RptHr~Yearf+IDHS_EIrc_within         +IDHS_EIrc_between+USDA_RUC+RPovHc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornHc+ChildPHc+ElderHc+MalePHc+DisablHc+MoveHc+Matern(1|Longitude+Latitude),data=zh[,c("RptHr","Yearf","IDHS_EIrc_within","IDHS_EIrc_between","USDA_RUC","RPovHc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornHc","ChildPHc","ElderHc","MalePHc","DisablHc","MoveHc","Longitude","Latitude")])
# mhb3b<-fitme(RptHr~Yearf+IDHS_EIrc_within*USDA_RUC+IDHS_EIrc_between*USDA_RUC+RPovHc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornHc+ChildPHc+ElderHc+MalePHc+DisablHc+MoveHc+Matern(1|Longitude+Latitude),data=zh[,c("RptHr","Yearf","IDHS_EIrc_within","IDHS_EIrc_between","USDA_RUC","RPovHc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornHc","ChildPHc","ElderHc","MalePHc","DisablHc","MoveHc","Longitude","Latitude")])
# mhb4b<-fitme(RptHr~Yearf+IDHS_EIrc_within*USDA_RUC+IDHS_EIrc_between+USDA_RUC+RPovHc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornHc+ChildPHc+ElderHc+MalePHc+DisablHc+MoveHc+Matern(1|Longitude+Latitude),data=zh[,c("RptHr","Yearf","IDHS_EIrc_within","IDHS_EIrc_between","USDA_RUC","RPovHc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornHc","ChildPHc","ElderHc","MalePHc","DisablHc","MoveHc","Longitude","Latitude")])
# mhb5b<-fitme(RptHr~Yearf+IDHS_EIrc_within+USDA_RUC+IDHS_EIrc_between*USDA_RUC+RPovHc+HValueT10kc+VacantTc+CPopBPc+CPopHPc+FBornHc+ChildPHc+ElderHc+MalePHc+DisablHc+MoveHc+Matern(1|Longitude+Latitude),data=zh[,c("RptHr","Yearf","IDHS_EIrc_within","IDHS_EIrc_between","USDA_RUC","RPovHc","HValueT10kc","VacantTc","CPopBPc","CPopHPc","FBornHc","ChildPHc","ElderHc","MalePHc","DisablHc","MoveHc","Longitude","Latitude")])

save.image("Z:/CDCK01/Analysis/ZipCode/HomeVisit/HomeVisit02_Model3_2.RData")





# Tables





table1<-data.table(
	variable=c("Total CM","Young","Middle","Adolescent","Male","Female","White","Black","Latino","Neglect","Physical Abuse","Sexual Abuse","DHS_HVPr","MHV_C5k","Relative poverty","Median House Value","% Vacant","% Black child","% Hispanic child","% Foreign-Born","% Child","% Elderly","% Male","% Disabled","% Moved","Large Urban","Small Urban","Rural","2011","2012","2013","2014","2015","2016","2017","2018"),
	N1=c(nrow(zt),nrow(z1),nrow(z2),nrow(z3),nrow(zm),nrow(zf),nrow(zw),nrow(zb),nrow(zh),nrow(zn),nrow(zp),nrow(zs),NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA),
	N2=c(nrow(zt2),nrow(z12),nrow(z22),nrow(z32),nrow(zm2),nrow(zf2),nrow(zw2),nrow(zb2),nrow(zh2),nrow(zn2),nrow(zp2),nrow(zs2),NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA),
	Mean1=c(mean(zt$RptTr),mean(z1$Rpt1r),mean(z2$Rpt2r),mean(z3$Rpt3r),mean(zm$RptMr),mean(zf$RptFr),mean(zw$RptWr),mean(zb$RptBr),mean(zh$RptHr),mean(zn$NegTr),mean(zp$PhyTr),mean(zs$SexTr),mean(zt$DHS_HVPr),mean(zt$MHV_C5k),mean(zt$RPovT),mean(zt$HValueT10k),mean(zt$VacantT),mean(zt$CPopBP),mean(zt$CPopHP),mean(zt$FBornT),mean(zt$ChildPT),mean(zt$ElderT),mean(zt$MalePT),mean(zt$DisablT),mean(zt$MoveT),prop.table(table(zt$USDA_RUC))*100,prop.table(table(zt$Yearf))*100),
	SD1=c(sd(zt$RptTr),sd(z1$Rpt1r),sd(z2$Rpt2r),sd(z3$Rpt3r),sd(zm$RptMr),sd(zf$RptFr),sd(zw$RptWr),sd(zb$RptBr),sd(zh$RptHr),sd(zn$NegTr),sd(zp$PhyTr),sd(zs$SexTr),sd(zt$DHS_HVPr),sd(zt$MHV_C5k),sd(zt$RPovT),sd(zt$HValueT10k),sd(zt$VacantT),sd(zt$CPopBP),sd(zt$CPopHP),sd(zt$FBornT),sd(zt$ChildPT),sd(zt$ElderT),sd(zt$MalePT),sd(zt$DisablT),sd(zt$MoveT),NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA),
	Mean2=c(mean(zt2$RptTr),mean(z12$Rpt1r),mean(z22$Rpt2r),mean(z32$Rpt3r),mean(zm2$RptMr),mean(zf2$RptFr),mean(zw2$RptWr),mean(zb2$RptBr),mean(zh2$RptHr),mean(zn2$NegTr),mean(zp2$PhyTr),mean(zs2$SexTr),mean(zt2$DHS_HVPr),mean(zt2$MHV_C5k),mean(zt2$RPovT),mean(zt2$HValueT10k),mean(zt2$VacantT),mean(zt2$CPopBP),mean(zt2$CPopHP),mean(zt2$FBornT),mean(zt2$ChildPT),mean(zt2$ElderT),mean(zt2$MalePT),mean(zt2$DisablT),mean(zt2$MoveT),prop.table(table(zt2$USDA_RUC))*100,prop.table(table(zt2$Yearf))*100),
	SD2=c(sd(zt2$RptTr),sd(z12$Rpt1r),sd(z22$Rpt2r),sd(z32$Rpt3r),sd(zm2$RptMr),sd(zf2$RptFr),sd(zw2$RptWr),sd(zb2$RptBr),sd(zh2$RptHr),sd(zn2$NegTr),sd(zp2$PhyTr),sd(zs2$SexTr),sd(zt2$DHS_HVPr),sd(zt2$MHV_C5k),sd(zt2$RPovT),sd(zt2$HValueT10k),sd(zt2$VacantT),sd(zt2$CPopBP),sd(zt2$CPopHP),sd(zt2$FBornT),sd(zt2$ChildPT),sd(zt2$ElderT),sd(zt2$MalePT),sd(zt2$DisablT),sd(zt2$MoveT),NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA)
)
table1





# Total
table2.1<-data.table(
	name=c("DHS_HVPrc_within","DHS_HVPrc_between","DHS_HVPrc_withinxSU","DHS_HVPrc_withinxR","DHS_HVPrc_betweenxSU","DHS_HVPrc_betweenxR","AIC","LRT"),
	Model1C=c(fixef(mtb1a)["DHS_HVPrc_within"]                                                     ,fixef(mtb1a)["DHS_HVPrc_between"]                                                      ,NA                                                                                                       ,NA                                                                                                       ,NA                                                                                                         ,NA                                                                                                         ,extractAIC(mtb1a)[2],NA                              ),
	Model1L=c(fixef(mtb1a)["DHS_HVPrc_within"]-1.96*summary(mtb1a)$beta_table["DHS_HVPrc_within",2],fixef(mtb1a)["DHS_HVPrc_between"]-1.96*summary(mtb1a)$beta_table["DHS_HVPrc_between",2],NA                                                                                                       ,NA                                                                                                       ,NA                                                                                                         ,NA                                                                                                         ,NA                  ,NA                              ),
	Model1U=c(fixef(mtb1a)["DHS_HVPrc_within"]+1.96*summary(mtb1a)$beta_table["DHS_HVPrc_within",2],fixef(mtb1a)["DHS_HVPrc_between"]+1.96*summary(mtb1a)$beta_table["DHS_HVPrc_between",2],NA                                                                                                       ,NA                                                                                                       ,NA                                                                                                         ,NA                                                                                                         ,NA                  ,NA                              ),
	Model2C=c(fixef(mtb2a)["DHS_HVPrc_within"]                                                     ,fixef(mtb2a)["DHS_HVPrc_between"]                                                      ,NA                                                                                                       ,NA                                                                                                       ,NA                                                                                                         ,NA                                                                                                         ,extractAIC(mtb2a)[2],anova(mtb1a,mtb2a)$basicLRT[[3]]),
	Model2L=c(fixef(mtb2a)["DHS_HVPrc_within"]-1.96*summary(mtb2a)$beta_table["DHS_HVPrc_within",2],fixef(mtb2a)["DHS_HVPrc_between"]-1.96*summary(mtb2a)$beta_table["DHS_HVPrc_between",2],NA                                                                                                       ,NA                                                                                                       ,NA                                                                                                         ,NA                                                                                                         ,NA                  ,NA                              ),
	Model2U=c(fixef(mtb2a)["DHS_HVPrc_within"]+1.96*summary(mtb2a)$beta_table["DHS_HVPrc_within",2],fixef(mtb2a)["DHS_HVPrc_between"]+1.96*summary(mtb2a)$beta_table["DHS_HVPrc_between",2],NA                                                                                                       ,NA                                                                                                       ,NA                                                                                                         ,NA                                                                                                         ,NA                  ,NA                              ),
	Model4C=c(fixef(mtb4a)["DHS_HVPrc_within"]                                                     ,fixef(mtb4a)["DHS_HVPrc_between"]                                                      ,fixef(mtb4a)["DHS_HVPrc_within:USDA_RUC2"]                                                               ,fixef(mtb4a)["DHS_HVPrc_within:USDA_RUC3"]                                                               ,NA                                                                                                         ,NA                                                                                                         ,extractAIC(mtb4a)[2],anova(mtb2a,mtb4a)$basicLRT[[3]]),
	Model4L=c(fixef(mtb4a)["DHS_HVPrc_within"]-1.96*summary(mtb4a)$beta_table["DHS_HVPrc_within",2],fixef(mtb4a)["DHS_HVPrc_between"]-1.96*summary(mtb4a)$beta_table["DHS_HVPrc_between",2],fixef(mtb4a)["DHS_HVPrc_within:USDA_RUC2"]-1.96*summary(mtb4a)$beta_table["DHS_HVPrc_within:USDA_RUC2",2],fixef(mtb4a)["DHS_HVPrc_within:USDA_RUC3"]-1.96*summary(mtb4a)$beta_table["DHS_HVPrc_within:USDA_RUC3",2],NA                                                                                                         ,NA                                                                                                         ,NA                  ,NA                              ),
	Model4U=c(fixef(mtb4a)["DHS_HVPrc_within"]+1.96*summary(mtb4a)$beta_table["DHS_HVPrc_within",2],fixef(mtb4a)["DHS_HVPrc_between"]+1.96*summary(mtb4a)$beta_table["DHS_HVPrc_between",2],fixef(mtb4a)["DHS_HVPrc_within:USDA_RUC2"]+1.96*summary(mtb4a)$beta_table["DHS_HVPrc_within:USDA_RUC2",2],fixef(mtb4a)["DHS_HVPrc_within:USDA_RUC3"]+1.96*summary(mtb4a)$beta_table["DHS_HVPrc_within:USDA_RUC3",2],NA                                                                                                         ,NA                                                                                                         ,NA                  ,NA                              ),
	Model5C=c(fixef(mtb5a)["DHS_HVPrc_within"]                                                     ,fixef(mtb5a)["DHS_HVPrc_between"]                                                      ,NA                                                                                                       ,NA                                                                                                       ,fixef(mtb5a)["USDA_RUC2:DHS_HVPrc_between"]                                                                ,fixef(mtb5a)["USDA_RUC3:DHS_HVPrc_between"]                                                                ,extractAIC(mtb5a)[2],anova(mtb2a,mtb5a)$basicLRT[[3]]),
	Model5L=c(fixef(mtb5a)["DHS_HVPrc_within"]-1.96*summary(mtb5a)$beta_table["DHS_HVPrc_within",2],fixef(mtb5a)["DHS_HVPrc_between"]-1.96*summary(mtb5a)$beta_table["DHS_HVPrc_between",2],NA                                                                                                       ,NA                                                                                                       ,fixef(mtb5a)["USDA_RUC2:DHS_HVPrc_between"]-1.96*summary(mtb5a)$beta_table["USDA_RUC2:DHS_HVPrc_between",2],fixef(mtb5a)["USDA_RUC3:DHS_HVPrc_between"]-1.96*summary(mtb5a)$beta_table["USDA_RUC3:DHS_HVPrc_between",2],NA                  ,NA                              ),
	Model5U=c(fixef(mtb5a)["DHS_HVPrc_within"]+1.96*summary(mtb5a)$beta_table["DHS_HVPrc_within",2],fixef(mtb5a)["DHS_HVPrc_between"]+1.96*summary(mtb5a)$beta_table["DHS_HVPrc_between",2],NA                                                                                                       ,NA                                                                                                       ,fixef(mtb5a)["USDA_RUC2:DHS_HVPrc_between"]+1.96*summary(mtb5a)$beta_table["USDA_RUC2:DHS_HVPrc_between",2],fixef(mtb5a)["USDA_RUC3:DHS_HVPrc_between"]+1.96*summary(mtb5a)$beta_table["USDA_RUC3:DHS_HVPrc_between",2],NA                  ,NA                              ))
table2.1





table2.2<-data.table(
	name=c("MHV_C5kc_within","MHV_C5kc_between","MHV_C5kc_withinxSU","MHV_C5kc_withinxR","MHV_C5kc_betweenxSU","MHV_C5kc_betweenxR","AIC","LRT"),
	Model1C=c(fixef(mtb1c)["MHV_C5kc_within"]                                                    ,fixef(mtb1c)["MHV_C5kc_between"]                                                     ,NA                                                                                                     ,NA                                                                                                     ,NA                                                                                                       ,NA                                                                                                       ,extractAIC(mtb1c)[2],NA                              ),
	Model1L=c(fixef(mtb1c)["MHV_C5kc_within"]-1.96*summary(mtb1c)$beta_table["MHV_C5kc_within",2],fixef(mtb1c)["MHV_C5kc_between"]-1.96*summary(mtb1c)$beta_table["MHV_C5kc_between",2],NA                                                                                                     ,NA                                                                                                     ,NA                                                                                                       ,NA                                                                                                       ,NA                  ,NA                              ),
	Model1U=c(fixef(mtb1c)["MHV_C5kc_within"]+1.96*summary(mtb1c)$beta_table["MHV_C5kc_within",2],fixef(mtb1c)["MHV_C5kc_between"]+1.96*summary(mtb1c)$beta_table["MHV_C5kc_between",2],NA                                                                                                     ,NA                                                                                                     ,NA                                                                                                       ,NA                                                                                                       ,NA                  ,NA                              ),
	Model2C=c(fixef(mtb2c)["MHV_C5kc_within"]                                                    ,fixef(mtb2c)["MHV_C5kc_between"]                                                     ,NA                                                                                                     ,NA                                                                                                     ,NA                                                                                                       ,NA                                                                                                       ,extractAIC(mtb2c)[2],anova(mtb1c,mtb2c)$basicLRT[[3]]),
	Model2L=c(fixef(mtb2c)["MHV_C5kc_within"]-1.96*summary(mtb2c)$beta_table["MHV_C5kc_within",2],fixef(mtb2c)["MHV_C5kc_between"]-1.96*summary(mtb2c)$beta_table["MHV_C5kc_between",2],NA                                                                                                     ,NA                                                                                                     ,NA                                                                                                       ,NA                                                                                                       ,NA                  ,NA                              ),
	Model2U=c(fixef(mtb2c)["MHV_C5kc_within"]+1.96*summary(mtb2c)$beta_table["MHV_C5kc_within",2],fixef(mtb2c)["MHV_C5kc_between"]+1.96*summary(mtb2c)$beta_table["MHV_C5kc_between",2],NA                                                                                                     ,NA                                                                                                     ,NA                                                                                                       ,NA                                                                                                       ,NA                  ,NA                              ),
	Model4C=c(fixef(mtb4c)["MHV_C5kc_within"]                                                    ,fixef(mtb4c)["MHV_C5kc_between"]                                                     ,fixef(mtb4c)["MHV_C5kc_within:USDA_RUC2"]                                                              ,fixef(mtb4c)["MHV_C5kc_within:USDA_RUC3"]                                                              ,NA                                                                                                       ,NA                                                                                                       ,extractAIC(mtb4c)[2],anova(mtb2c,mtb4c)$basicLRT[[3]]),
	Model4L=c(fixef(mtb4c)["MHV_C5kc_within"]-1.96*summary(mtb4c)$beta_table["MHV_C5kc_within",2],fixef(mtb4c)["MHV_C5kc_between"]-1.96*summary(mtb4c)$beta_table["MHV_C5kc_between",2],fixef(mtb4c)["MHV_C5kc_within:USDA_RUC2"]-1.96*summary(mtb4c)$beta_table["MHV_C5kc_within:USDA_RUC2",2],fixef(mtb4c)["MHV_C5kc_within:USDA_RUC3"]-1.96*summary(mtb4c)$beta_table["MHV_C5kc_within:USDA_RUC3",2],NA                                                                                                       ,NA                                                                                                       ,NA                  ,NA                              ),
	Model4U=c(fixef(mtb4c)["MHV_C5kc_within"]+1.96*summary(mtb4c)$beta_table["MHV_C5kc_within",2],fixef(mtb4c)["MHV_C5kc_between"]+1.96*summary(mtb4c)$beta_table["MHV_C5kc_between",2],fixef(mtb4c)["MHV_C5kc_within:USDA_RUC2"]+1.96*summary(mtb4c)$beta_table["MHV_C5kc_within:USDA_RUC2",2],fixef(mtb4c)["MHV_C5kc_within:USDA_RUC3"]+1.96*summary(mtb4c)$beta_table["MHV_C5kc_within:USDA_RUC3",2],NA                                                                                                       ,NA                                                                                                       ,NA                  ,NA                              ),
	Model5C=c(fixef(mtb5c)["MHV_C5kc_within"]                                                    ,fixef(mtb5c)["MHV_C5kc_between"]                                                     ,NA                                                                                                     ,NA                                                                                                     ,fixef(mtb5c)["USDA_RUC2:MHV_C5kc_between"]                                                               ,fixef(mtb5c)["USDA_RUC3:MHV_C5kc_between"]                                                               ,extractAIC(mtb5c)[2],anova(mtb2c,mtb5c)$basicLRT[[3]]),
	Model5L=c(fixef(mtb5c)["MHV_C5kc_within"]-1.96*summary(mtb5c)$beta_table["MHV_C5kc_within",2],fixef(mtb5c)["MHV_C5kc_between"]-1.96*summary(mtb5c)$beta_table["MHV_C5kc_between",2],NA                                                                                                     ,NA                                                                                                     ,fixef(mtb5c)["USDA_RUC2:MHV_C5kc_between"]-1.96*summary(mtb5c)$beta_table["USDA_RUC2:MHV_C5kc_between",2],fixef(mtb5c)["USDA_RUC3:MHV_C5kc_between"]-1.96*summary(mtb5c)$beta_table["USDA_RUC3:MHV_C5kc_between",2],NA                  ,NA                              ),
	Model5U=c(fixef(mtb5c)["MHV_C5kc_within"]+1.96*summary(mtb5c)$beta_table["MHV_C5kc_within",2],fixef(mtb5c)["MHV_C5kc_between"]+1.96*summary(mtb5c)$beta_table["MHV_C5kc_between",2],NA                                                                                                     ,NA                                                                                                     ,fixef(mtb5c)["USDA_RUC2:MHV_C5kc_between"]+1.96*summary(mtb5c)$beta_table["USDA_RUC2:MHV_C5kc_between",2],fixef(mtb5c)["USDA_RUC3:MHV_C5kc_between"]+1.96*summary(mtb5c)$beta_table["USDA_RUC3:MHV_C5kc_between",2],NA                  ,NA                              ))
table2.2





table2.1a<-data.table(
	name=c(names(fixef(mtb2a)),"AIC","LRT"),
	Model0C=c(fixef(mtb0a)                                   ,rep(NA,15),extractAIC(mtb0a)[2],NA                              ),
	Model0L=c(fixef(mtb0a)-1.96*summary(mtb0a)$beta_table[,2],rep(NA,15),NA                  ,NA                              ),
	Model0U=c(fixef(mtb0a)+1.96*summary(mtb0a)$beta_table[,2],rep(NA,15),NA                  ,NA                              ),
	Model1C=c(fixef(mtb1a)                                   ,rep(NA,13),extractAIC(mtb1a)[2],anova(mtb0a,mtb1a)$basicLRT[[3]]),
	Model1L=c(fixef(mtb1a)-1.96*summary(mtb1a)$beta_table[,2],rep(NA,13),NA                  ,NA                              ),
	Model1U=c(fixef(mtb1a)+1.96*summary(mtb1a)$beta_table[,2],rep(NA,13),NA                  ,NA                              ),
	Model2C=c(fixef(mtb2a)                                              ,extractAIC(mtb2a)[2],anova(mtb1a,mtb2a)$basicLRT[[3]]),
	Model2L=c(fixef(mtb2a)-1.96*summary(mtb2a)$beta_table[,2]           ,NA                  ,NA                              ),
	Model2U=c(fixef(mtb2a)+1.96*summary(mtb2a)$beta_table[,2]           ,NA                  ,NA                              ))
table2.1a





table2.2a<-data.table(
	name=c(names(fixef(mtb2c)),"AIC","LRT"),
	Model0C=c(fixef(mtb0c)                                   ,rep(NA,15),extractAIC(mtb0c)[2],NA                              ),
	Model0L=c(fixef(mtb0c)-1.96*summary(mtb0c)$beta_table[,2],rep(NA,15),NA                  ,NA                              ),
	Model0U=c(fixef(mtb0c)+1.96*summary(mtb0c)$beta_table[,2],rep(NA,15),NA                  ,NA                              ),
	Model1C=c(fixef(mtb1c)                                   ,rep(NA,13),extractAIC(mtb1c)[2],anova(mtb0c,mtb1c)$basicLRT[[3]]),
	Model1L=c(fixef(mtb1c)-1.96*summary(mtb1c)$beta_table[,2],rep(NA,13),NA                  ,NA                              ),
	Model1U=c(fixef(mtb1c)+1.96*summary(mtb1c)$beta_table[,2],rep(NA,13),NA                  ,NA                              ),
	Model2C=c(fixef(mtb2c)                                              ,extractAIC(mtb2c)[2],anova(mtb1c,mtb2c)$basicLRT[[3]]),
	Model2L=c(fixef(mtb2c)-1.96*summary(mtb2c)$beta_table[,2]           ,NA                  ,NA                              ),
	Model2U=c(fixef(mtb2c)+1.96*summary(mtb2c)$beta_table[,2]           ,NA                  ,NA                              ))
table2.2a





# Child Age: Young, Middle, Older (1=raw coefficients;2=coefficients relative to mean Y)
table3.11<-data.table(
	name=c("N1","N2 or MeanY","DHS_HVPrc_within","DHS_HVPrc_between"),
	Y1C=c(nrow(z1),length(unique(z1$ZipCode)), fixef(m1b2a)["DHS_HVPrc_within"]                                                                         , fixef(m1b2a)["DHS_HVPrc_between"]                                                                          ),
	Y1L=c(NA      ,NA                        , fixef(m1b2a)["DHS_HVPrc_within"]-1.96*summary(m1b2a)$beta_table["DHS_HVPrc_within",2]                    , fixef(m1b2a)["DHS_HVPrc_between"]-1.96*summary(m1b2a)$beta_table["DHS_HVPrc_between",2]                    ),
	Y1U=c(NA      ,NA                        , fixef(m1b2a)["DHS_HVPrc_within"]+1.96*summary(m1b2a)$beta_table["DHS_HVPrc_within",2]                    , fixef(m1b2a)["DHS_HVPrc_between"]+1.96*summary(m1b2a)$beta_table["DHS_HVPrc_between",2]                    ),
	M1C=c(nrow(z2),length(unique(z2$ZipCode)), fixef(m2b2a)["DHS_HVPrc_within"]                                                                         , fixef(m2b2a)["DHS_HVPrc_between"]                                                                          ),
	M1L=c(NA      ,NA                        , fixef(m2b2a)["DHS_HVPrc_within"]-1.96*summary(m2b2a)$beta_table["DHS_HVPrc_within",2]                    , fixef(m2b2a)["DHS_HVPrc_between"]-1.96*summary(m2b2a)$beta_table["DHS_HVPrc_between",2]                    ),
	M1U=c(NA      ,NA                        , fixef(m2b2a)["DHS_HVPrc_within"]+1.96*summary(m2b2a)$beta_table["DHS_HVPrc_within",2]                    , fixef(m2b2a)["DHS_HVPrc_between"]+1.96*summary(m2b2a)$beta_table["DHS_HVPrc_between",2]                    ),
	O1C=c(nrow(z3),length(unique(z3$ZipCode)), fixef(m3b2a)["DHS_HVPrc_within"]                                                                         , fixef(m3b2a)["DHS_HVPrc_between"]                                                                          ),
	O1L=c(NA      ,NA                        , fixef(m3b2a)["DHS_HVPrc_within"]-1.96*summary(m3b2a)$beta_table["DHS_HVPrc_within",2]                    , fixef(m3b2a)["DHS_HVPrc_between"]-1.96*summary(m3b2a)$beta_table["DHS_HVPrc_between",2]                    ),
	O1U=c(NA      ,NA                        , fixef(m3b2a)["DHS_HVPrc_within"]+1.96*summary(m3b2a)$beta_table["DHS_HVPrc_within",2]                    , fixef(m3b2a)["DHS_HVPrc_between"]+1.96*summary(m3b2a)$beta_table["DHS_HVPrc_between",2]                    ),
	Y2C=c(nrow(z1),mean(z1$Rpt1r)            ,(fixef(m1b2a)["DHS_HVPrc_within"]                                                     )/mean(z1$Rpt1r)*100,(fixef(m1b2a)["DHS_HVPrc_between"]                                                      )/mean(z1$Rpt1r)*100),
	Y2L=c(NA      ,NA                        ,(fixef(m1b2a)["DHS_HVPrc_within"]-1.96*summary(m1b2a)$beta_table["DHS_HVPrc_within",2])/mean(z1$Rpt1r)*100,(fixef(m1b2a)["DHS_HVPrc_between"]-1.96*summary(m1b2a)$beta_table["DHS_HVPrc_between",2])/mean(z1$Rpt1r)*100),
	Y2U=c(NA      ,NA                        ,(fixef(m1b2a)["DHS_HVPrc_within"]+1.96*summary(m1b2a)$beta_table["DHS_HVPrc_within",2])/mean(z1$Rpt1r)*100,(fixef(m1b2a)["DHS_HVPrc_between"]+1.96*summary(m1b2a)$beta_table["DHS_HVPrc_between",2])/mean(z1$Rpt1r)*100),
	M2C=c(nrow(z2),mean(z2$Rpt2r)            ,(fixef(m2b2a)["DHS_HVPrc_within"]                                                     )/mean(z2$Rpt2r)*100,(fixef(m2b2a)["DHS_HVPrc_between"]                                                      )/mean(z2$Rpt2r)*100),
	M2L=c(NA      ,NA                        ,(fixef(m2b2a)["DHS_HVPrc_within"]-1.96*summary(m2b2a)$beta_table["DHS_HVPrc_within",2])/mean(z2$Rpt2r)*100,(fixef(m2b2a)["DHS_HVPrc_between"]-1.96*summary(m2b2a)$beta_table["DHS_HVPrc_between",2])/mean(z2$Rpt2r)*100),
	M2U=c(NA      ,NA                        ,(fixef(m2b2a)["DHS_HVPrc_within"]+1.96*summary(m2b2a)$beta_table["DHS_HVPrc_within",2])/mean(z2$Rpt2r)*100,(fixef(m2b2a)["DHS_HVPrc_between"]+1.96*summary(m2b2a)$beta_table["DHS_HVPrc_between",2])/mean(z2$Rpt2r)*100),
	O2C=c(nrow(z3),mean(z3$Rpt3r)            ,(fixef(m3b2a)["DHS_HVPrc_within"]                                                     )/mean(z3$Rpt3r)*100,(fixef(m3b2a)["DHS_HVPrc_between"]                                                      )/mean(z3$Rpt3r)*100),
	O2L=c(NA      ,NA                        ,(fixef(m3b2a)["DHS_HVPrc_within"]-1.96*summary(m3b2a)$beta_table["DHS_HVPrc_within",2])/mean(z3$Rpt3r)*100,(fixef(m3b2a)["DHS_HVPrc_between"]-1.96*summary(m3b2a)$beta_table["DHS_HVPrc_between",2])/mean(z3$Rpt3r)*100),
	O2U=c(NA      ,NA                        ,(fixef(m3b2a)["DHS_HVPrc_within"]+1.96*summary(m3b2a)$beta_table["DHS_HVPrc_within",2])/mean(z3$Rpt3r)*100,(fixef(m3b2a)["DHS_HVPrc_between"]+1.96*summary(m3b2a)$beta_table["DHS_HVPrc_between",2])/mean(z3$Rpt3r)*100)
)
table3.11





# Child Age: Young, Middle, Older (1=raw coefficients;2=coefficients relative to mean Y)
table3.12<-data.table(
	name=c("N1","N2 or MeanY","MHV_C5kc_within","MHV_C5kc_between"),
	Y1C=c(nrow(z1),length(unique(z1$ZipCode)), fixef(m1b2c)["MHV_C5kc_within"]                                                                        , fixef(m1b2c)["MHV_C5kc_between"]                                                                         ),
	Y1L=c(NA      ,NA                        , fixef(m1b2c)["MHV_C5kc_within"]-1.96*summary(m1b2c)$beta_table["MHV_C5kc_within",2]                    , fixef(m1b2c)["MHV_C5kc_between"]-1.96*summary(m1b2c)$beta_table["MHV_C5kc_between",2]                    ),
	Y1U=c(NA      ,NA                        , fixef(m1b2c)["MHV_C5kc_within"]+1.96*summary(m1b2c)$beta_table["MHV_C5kc_within",2]                    , fixef(m1b2c)["MHV_C5kc_between"]+1.96*summary(m1b2c)$beta_table["MHV_C5kc_between",2]                    ),
	M1C=c(nrow(z2),length(unique(z2$ZipCode)), fixef(m2b2c)["MHV_C5kc_within"]                                                                        , fixef(m2b2c)["MHV_C5kc_between"]                                                                         ),
	M1L=c(NA      ,NA                        , fixef(m2b2c)["MHV_C5kc_within"]-1.96*summary(m2b2c)$beta_table["MHV_C5kc_within",2]                    , fixef(m2b2c)["MHV_C5kc_between"]-1.96*summary(m2b2c)$beta_table["MHV_C5kc_between",2]                    ),
	M1U=c(NA      ,NA                        , fixef(m2b2c)["MHV_C5kc_within"]+1.96*summary(m2b2c)$beta_table["MHV_C5kc_within",2]                    , fixef(m2b2c)["MHV_C5kc_between"]+1.96*summary(m2b2c)$beta_table["MHV_C5kc_between",2]                    ),
	O1C=c(nrow(z3),length(unique(z3$ZipCode)), fixef(m3b2c)["MHV_C5kc_within"]                                                                        , fixef(m3b2c)["MHV_C5kc_between"]                                                                         ),
	O1L=c(NA      ,NA                        , fixef(m3b2c)["MHV_C5kc_within"]-1.96*summary(m3b2c)$beta_table["MHV_C5kc_within",2]                    , fixef(m3b2c)["MHV_C5kc_between"]-1.96*summary(m3b2c)$beta_table["MHV_C5kc_between",2]                    ),
	O1U=c(NA      ,NA                        , fixef(m3b2c)["MHV_C5kc_within"]+1.96*summary(m3b2c)$beta_table["MHV_C5kc_within",2]                    , fixef(m3b2c)["MHV_C5kc_between"]+1.96*summary(m3b2c)$beta_table["MHV_C5kc_between",2]                    ),
	Y2C=c(nrow(z1),mean(z1$Rpt1r)            ,(fixef(m1b2c)["MHV_C5kc_within"]                                                    )/mean(z1$Rpt1r)*100,(fixef(m1b2c)["MHV_C5kc_between"]                                                     )/mean(z1$Rpt1r)*100),
	Y2L=c(NA      ,NA                        ,(fixef(m1b2c)["MHV_C5kc_within"]-1.96*summary(m1b2c)$beta_table["MHV_C5kc_within",2])/mean(z1$Rpt1r)*100,(fixef(m1b2c)["MHV_C5kc_between"]-1.96*summary(m1b2c)$beta_table["MHV_C5kc_between",2])/mean(z1$Rpt1r)*100),
	Y2U=c(NA      ,NA                        ,(fixef(m1b2c)["MHV_C5kc_within"]+1.96*summary(m1b2c)$beta_table["MHV_C5kc_within",2])/mean(z1$Rpt1r)*100,(fixef(m1b2c)["MHV_C5kc_between"]+1.96*summary(m1b2c)$beta_table["MHV_C5kc_between",2])/mean(z1$Rpt1r)*100),
	M2C=c(nrow(z2),mean(z2$Rpt2r)            ,(fixef(m2b2c)["MHV_C5kc_within"]                                                    )/mean(z2$Rpt2r)*100,(fixef(m2b2c)["MHV_C5kc_between"]                                                     )/mean(z2$Rpt2r)*100),
	M2L=c(NA      ,NA                        ,(fixef(m2b2c)["MHV_C5kc_within"]-1.96*summary(m2b2c)$beta_table["MHV_C5kc_within",2])/mean(z2$Rpt2r)*100,(fixef(m2b2c)["MHV_C5kc_between"]-1.96*summary(m2b2c)$beta_table["MHV_C5kc_between",2])/mean(z2$Rpt2r)*100),
	M2U=c(NA      ,NA                        ,(fixef(m2b2c)["MHV_C5kc_within"]+1.96*summary(m2b2c)$beta_table["MHV_C5kc_within",2])/mean(z2$Rpt2r)*100,(fixef(m2b2c)["MHV_C5kc_between"]+1.96*summary(m2b2c)$beta_table["MHV_C5kc_between",2])/mean(z2$Rpt2r)*100),
	O2C=c(nrow(z3),mean(z3$Rpt3r)            ,(fixef(m3b2c)["MHV_C5kc_within"]                                                    )/mean(z3$Rpt3r)*100,(fixef(m3b2c)["MHV_C5kc_between"]                                                     )/mean(z3$Rpt3r)*100),
	O2L=c(NA      ,NA                        ,(fixef(m3b2c)["MHV_C5kc_within"]-1.96*summary(m3b2c)$beta_table["MHV_C5kc_within",2])/mean(z3$Rpt3r)*100,(fixef(m3b2c)["MHV_C5kc_between"]-1.96*summary(m3b2c)$beta_table["MHV_C5kc_between",2])/mean(z3$Rpt3r)*100),
	O2U=c(NA      ,NA                        ,(fixef(m3b2c)["MHV_C5kc_within"]+1.96*summary(m3b2c)$beta_table["MHV_C5kc_within",2])/mean(z3$Rpt3r)*100,(fixef(m3b2c)["MHV_C5kc_between"]+1.96*summary(m3b2c)$beta_table["MHV_C5kc_between",2])/mean(z3$Rpt3r)*100)
)
table3.12





# Child Gender: Male, Female (1=raw coefficients;2=coefficients relative to mean Y)
table3.21<-data.table(
	name=c("N1","N2 or MeanY","DHS_HVPrc_within","DHS_HVPrc_between"),
	M1C=c(nrow(zm),length(unique(zm$ZipCode)), fixef(mmb2a)["DHS_HVPrc_within"]                                                                         , fixef(mmb2a)["DHS_HVPrc_between"]                                                                          ),
	M1L=c(NA      ,NA                        , fixef(mmb2a)["DHS_HVPrc_within"]-1.96*summary(mmb2a)$beta_table["DHS_HVPrc_within",2]                    , fixef(mmb2a)["DHS_HVPrc_between"]-1.96*summary(mmb2a)$beta_table["DHS_HVPrc_between",2]                    ),
	M1U=c(NA      ,NA                        , fixef(mmb2a)["DHS_HVPrc_within"]+1.96*summary(mmb2a)$beta_table["DHS_HVPrc_within",2]                    , fixef(mmb2a)["DHS_HVPrc_between"]+1.96*summary(mmb2a)$beta_table["DHS_HVPrc_between",2]                    ),
	F1C=c(nrow(zf),length(unique(zf$ZipCode)), fixef(mfb2a)["DHS_HVPrc_within"]                                                                         , fixef(mfb2a)["DHS_HVPrc_between"]                                                                          ),
	F1L=c(NA      ,NA                        , fixef(mfb2a)["DHS_HVPrc_within"]-1.96*summary(mfb2a)$beta_table["DHS_HVPrc_within",2]                    , fixef(mfb2a)["DHS_HVPrc_between"]-1.96*summary(mfb2a)$beta_table["DHS_HVPrc_between",2]                    ),
	F1U=c(NA      ,NA                        , fixef(mfb2a)["DHS_HVPrc_within"]+1.96*summary(mfb2a)$beta_table["DHS_HVPrc_within",2]                    , fixef(mfb2a)["DHS_HVPrc_between"]+1.96*summary(mfb2a)$beta_table["DHS_HVPrc_between",2]                    ),
	M2C=c(nrow(zm),mean(zm$RptMr)            ,(fixef(mmb2a)["DHS_HVPrc_within"]                                                     )/mean(zm$RptMr)*100,(fixef(mmb2a)["DHS_HVPrc_between"]                                                      )/mean(zm$RptMr)*100),
	M2L=c(NA      ,NA                        ,(fixef(mmb2a)["DHS_HVPrc_within"]-1.96*summary(mmb2a)$beta_table["DHS_HVPrc_within",2])/mean(zm$RptMr)*100,(fixef(mmb2a)["DHS_HVPrc_between"]-1.96*summary(mmb2a)$beta_table["DHS_HVPrc_between",2])/mean(zm$RptMr)*100),
	M2U=c(NA      ,NA                        ,(fixef(mmb2a)["DHS_HVPrc_within"]+1.96*summary(mmb2a)$beta_table["DHS_HVPrc_within",2])/mean(zm$RptMr)*100,(fixef(mmb2a)["DHS_HVPrc_between"]+1.96*summary(mmb2a)$beta_table["DHS_HVPrc_between",2])/mean(zm$RptMr)*100),
	F2C=c(nrow(zf),mean(zf$RptFr)            ,(fixef(mfb2a)["DHS_HVPrc_within"]                                                     )/mean(zf$RptFr)*100,(fixef(mfb2a)["DHS_HVPrc_between"]                                                      )/mean(zf$RptFr)*100),
	F2L=c(NA      ,NA                        ,(fixef(mfb2a)["DHS_HVPrc_within"]-1.96*summary(mfb2a)$beta_table["DHS_HVPrc_within",2])/mean(zf$RptFr)*100,(fixef(mfb2a)["DHS_HVPrc_between"]-1.96*summary(mfb2a)$beta_table["DHS_HVPrc_between",2])/mean(zf$RptFr)*100),
	F2U=c(NA      ,NA                        ,(fixef(mfb2a)["DHS_HVPrc_within"]+1.96*summary(mfb2a)$beta_table["DHS_HVPrc_within",2])/mean(zf$RptFr)*100,(fixef(mfb2a)["DHS_HVPrc_between"]+1.96*summary(mfb2a)$beta_table["DHS_HVPrc_between",2])/mean(zf$RptFr)*100)
)
table3.21





# Child Gender: Male, Female (1=raw coefficients;2=coefficients relative to mean Y)
table3.22<-data.table(
	name=c("N1","N2 or MeanY","MHV_C5kc_within","MHV_C5kc_between"),
	M1C=c(nrow(zm),length(unique(zm$ZipCode)), fixef(mmb2c)["MHV_C5kc_within"]                                                                        , fixef(mmb2c)["MHV_C5kc_between"]                                                                         ),
	M1L=c(NA      ,NA                        , fixef(mmb2c)["MHV_C5kc_within"]-1.96*summary(mmb2c)$beta_table["MHV_C5kc_within",2]                    , fixef(mmb2c)["MHV_C5kc_between"]-1.96*summary(mmb2c)$beta_table["MHV_C5kc_between",2]                    ),
	M1U=c(NA      ,NA                        , fixef(mmb2c)["MHV_C5kc_within"]+1.96*summary(mmb2c)$beta_table["MHV_C5kc_within",2]                    , fixef(mmb2c)["MHV_C5kc_between"]+1.96*summary(mmb2c)$beta_table["MHV_C5kc_between",2]                    ),
	F1C=c(nrow(zf),length(unique(zf$ZipCode)), fixef(mfb2c)["MHV_C5kc_within"]                                                                        , fixef(mfb2c)["MHV_C5kc_between"]                                                                         ),
	F1L=c(NA      ,NA                        , fixef(mfb2c)["MHV_C5kc_within"]-1.96*summary(mfb2c)$beta_table["MHV_C5kc_within",2]                    , fixef(mfb2c)["MHV_C5kc_between"]-1.96*summary(mfb2c)$beta_table["MHV_C5kc_between",2]                    ),
	F1U=c(NA      ,NA                        , fixef(mfb2c)["MHV_C5kc_within"]+1.96*summary(mfb2c)$beta_table["MHV_C5kc_within",2]                    , fixef(mfb2c)["MHV_C5kc_between"]+1.96*summary(mfb2c)$beta_table["MHV_C5kc_between",2]                    ),
	M2C=c(nrow(zm),mean(zm$RptMr)            ,(fixef(mmb2c)["MHV_C5kc_within"]                                                    )/mean(zm$RptMr)*100,(fixef(mmb2c)["MHV_C5kc_between"]                                                     )/mean(zm$RptMr)*100),
	M2L=c(NA      ,NA                        ,(fixef(mmb2c)["MHV_C5kc_within"]-1.96*summary(mmb2c)$beta_table["MHV_C5kc_within",2])/mean(zm$RptMr)*100,(fixef(mmb2c)["MHV_C5kc_between"]-1.96*summary(mmb2c)$beta_table["MHV_C5kc_between",2])/mean(zm$RptMr)*100),
	M2U=c(NA      ,NA                        ,(fixef(mmb2c)["MHV_C5kc_within"]+1.96*summary(mmb2c)$beta_table["MHV_C5kc_within",2])/mean(zm$RptMr)*100,(fixef(mmb2c)["MHV_C5kc_between"]+1.96*summary(mmb2c)$beta_table["MHV_C5kc_between",2])/mean(zm$RptMr)*100),
	F2C=c(nrow(zf),mean(zf$RptFr)            ,(fixef(mfb2c)["MHV_C5kc_within"]                                                    )/mean(zf$RptFr)*100,(fixef(mfb2c)["MHV_C5kc_between"]                                                     )/mean(zf$RptFr)*100),
	F2L=c(NA      ,NA                        ,(fixef(mfb2c)["MHV_C5kc_within"]-1.96*summary(mfb2c)$beta_table["MHV_C5kc_within",2])/mean(zf$RptFr)*100,(fixef(mfb2c)["MHV_C5kc_between"]-1.96*summary(mfb2c)$beta_table["MHV_C5kc_between",2])/mean(zf$RptFr)*100),
	F2U=c(NA      ,NA                        ,(fixef(mfb2c)["MHV_C5kc_within"]+1.96*summary(mfb2c)$beta_table["MHV_C5kc_within",2])/mean(zf$RptFr)*100,(fixef(mfb2c)["MHV_C5kc_between"]+1.96*summary(mfb2c)$beta_table["MHV_C5kc_between",2])/mean(zf$RptFr)*100)
)
table3.22





# Child Race/Ethnicity: White, Black, Latino (1=raw coefficients;2=coefficients relative to mean Y)
table3.31<-data.table(
	name=c("N1","N2 or MeanY","DHS_HVPrc_within","DHS_HVPrc_between"),
	W1C=c(nrow(zw),length(unique(zw$ZipCode)), fixef(mwb2a)["DHS_HVPrc_within"]                                                                         , fixef(mwb2a)["DHS_HVPrc_between"]                                                                          ),
	W1L=c(NA      ,NA                        , fixef(mwb2a)["DHS_HVPrc_within"]-1.96*summary(mwb2a)$beta_table["DHS_HVPrc_within",2]                    , fixef(mwb2a)["DHS_HVPrc_between"]-1.96*summary(mwb2a)$beta_table["DHS_HVPrc_between",2]                    ),
	W1U=c(NA      ,NA                        , fixef(mwb2a)["DHS_HVPrc_within"]+1.96*summary(mwb2a)$beta_table["DHS_HVPrc_within",2]                    , fixef(mwb2a)["DHS_HVPrc_between"]+1.96*summary(mwb2a)$beta_table["DHS_HVPrc_between",2]                    ),
	B1C=c(nrow(zb),length(unique(zb$ZipCode)), fixef(mbb2a)["DHS_HVPrc_within"]                                                                         , fixef(mbb2a)["DHS_HVPrc_between"]                                                                          ),
	B1L=c(NA      ,NA                        , fixef(mbb2a)["DHS_HVPrc_within"]-1.96*summary(mbb2a)$beta_table["DHS_HVPrc_within",2]                    , fixef(mbb2a)["DHS_HVPrc_between"]-1.96*summary(mbb2a)$beta_table["DHS_HVPrc_between",2]                    ),
	B1U=c(NA      ,NA                        , fixef(mbb2a)["DHS_HVPrc_within"]+1.96*summary(mbb2a)$beta_table["DHS_HVPrc_within",2]                    , fixef(mbb2a)["DHS_HVPrc_between"]+1.96*summary(mbb2a)$beta_table["DHS_HVPrc_between",2]                    ),
	H1C=c(nrow(zh),length(unique(zh$ZipCode)), fixef(mhb2a)["DHS_HVPrc_within"]                                                                         , fixef(mhb2a)["DHS_HVPrc_between"]                                                                          ),
	H1L=c(NA      ,NA                        , fixef(mhb2a)["DHS_HVPrc_within"]-1.96*summary(mhb2a)$beta_table["DHS_HVPrc_within",2]                    , fixef(mhb2a)["DHS_HVPrc_between"]-1.96*summary(mhb2a)$beta_table["DHS_HVPrc_between",2]                    ),
	H1U=c(NA      ,NA                        , fixef(mhb2a)["DHS_HVPrc_within"]+1.96*summary(mhb2a)$beta_table["DHS_HVPrc_within",2]                    , fixef(mhb2a)["DHS_HVPrc_between"]+1.96*summary(mhb2a)$beta_table["DHS_HVPrc_between",2]                    ),
	W2C=c(nrow(zw),mean(zw$RptWr)            ,(fixef(mwb2a)["DHS_HVPrc_within"]                                                     )/mean(zw$RptWr)*100,(fixef(mwb2a)["DHS_HVPrc_between"]                                                      )/mean(zw$RptWr)*100),
	W2L=c(NA      ,NA                        ,(fixef(mwb2a)["DHS_HVPrc_within"]-1.96*summary(mwb2a)$beta_table["DHS_HVPrc_within",2])/mean(zw$RptWr)*100,(fixef(mwb2a)["DHS_HVPrc_between"]-1.96*summary(mwb2a)$beta_table["DHS_HVPrc_between",2])/mean(zw$RptWr)*100),
	W2U=c(NA      ,NA                        ,(fixef(mwb2a)["DHS_HVPrc_within"]+1.96*summary(mwb2a)$beta_table["DHS_HVPrc_within",2])/mean(zw$RptWr)*100,(fixef(mwb2a)["DHS_HVPrc_between"]+1.96*summary(mwb2a)$beta_table["DHS_HVPrc_between",2])/mean(zw$RptWr)*100),
	B2C=c(nrow(zb),mean(zb$RptBr)            ,(fixef(mbb2a)["DHS_HVPrc_within"]                                                     )/mean(zb$RptBr)*100,(fixef(mbb2a)["DHS_HVPrc_between"]                                                      )/mean(zb$RptBr)*100),
	B2L=c(NA      ,NA                        ,(fixef(mbb2a)["DHS_HVPrc_within"]-1.96*summary(mbb2a)$beta_table["DHS_HVPrc_within",2])/mean(zb$RptBr)*100,(fixef(mbb2a)["DHS_HVPrc_between"]-1.96*summary(mbb2a)$beta_table["DHS_HVPrc_between",2])/mean(zb$RptBr)*100),
	B2U=c(NA      ,NA                        ,(fixef(mbb2a)["DHS_HVPrc_within"]+1.96*summary(mbb2a)$beta_table["DHS_HVPrc_within",2])/mean(zb$RptBr)*100,(fixef(mbb2a)["DHS_HVPrc_between"]+1.96*summary(mbb2a)$beta_table["DHS_HVPrc_between",2])/mean(zb$RptBr)*100),
	H2C=c(nrow(zh),mean(zh$RptHr)            ,(fixef(mhb2a)["DHS_HVPrc_within"]                                                     )/mean(zh$RptHr)*100,(fixef(mhb2a)["DHS_HVPrc_between"]                                                      )/mean(zh$RptHr)*100),
	H2L=c(NA      ,NA                        ,(fixef(mhb2a)["DHS_HVPrc_within"]-1.96*summary(mhb2a)$beta_table["DHS_HVPrc_within",2])/mean(zh$RptHr)*100,(fixef(mhb2a)["DHS_HVPrc_between"]-1.96*summary(mhb2a)$beta_table["DHS_HVPrc_between",2])/mean(zh$RptHr)*100),
	H2U=c(NA      ,NA                        ,(fixef(mhb2a)["DHS_HVPrc_within"]+1.96*summary(mhb2a)$beta_table["DHS_HVPrc_within",2])/mean(zh$RptHr)*100,(fixef(mhb2a)["DHS_HVPrc_between"]+1.96*summary(mhb2a)$beta_table["DHS_HVPrc_between",2])/mean(zh$RptHr)*100)
)
table3.31





# Child Race/Ethnicity: White, Black, Latino (1=raw coefficients;2=coefficients relative to mean Y)
table3.32<-data.table(
	name=c("N1","N2 or MeanY","MHV_C5kc_within","MHV_C5kc_between"),
	W1C=c(nrow(zw),length(unique(zw$ZipCode)), fixef(mwb2c)["MHV_C5kc_within"]                                                                        , fixef(mwb2c)["MHV_C5kc_between"]                                                                         ),
	W1L=c(NA      ,NA                        , fixef(mwb2c)["MHV_C5kc_within"]-1.96*summary(mwb2c)$beta_table["MHV_C5kc_within",2]                    , fixef(mwb2c)["MHV_C5kc_between"]-1.96*summary(mwb2c)$beta_table["MHV_C5kc_between",2]                    ),
	W1U=c(NA      ,NA                        , fixef(mwb2c)["MHV_C5kc_within"]+1.96*summary(mwb2c)$beta_table["MHV_C5kc_within",2]                    , fixef(mwb2c)["MHV_C5kc_between"]+1.96*summary(mwb2c)$beta_table["MHV_C5kc_between",2]                    ),
	B1C=c(nrow(zb),length(unique(zb$ZipCode)), fixef(mbb2c)["MHV_C5kc_within"]                                                                        , fixef(mbb2c)["MHV_C5kc_between"]                                                                         ),
	B1L=c(NA      ,NA                        , fixef(mbb2c)["MHV_C5kc_within"]-1.96*summary(mbb2c)$beta_table["MHV_C5kc_within",2]                    , fixef(mbb2c)["MHV_C5kc_between"]-1.96*summary(mbb2c)$beta_table["MHV_C5kc_between",2]                    ),
	B1U=c(NA      ,NA                        , fixef(mbb2c)["MHV_C5kc_within"]+1.96*summary(mbb2c)$beta_table["MHV_C5kc_within",2]                    , fixef(mbb2c)["MHV_C5kc_between"]+1.96*summary(mbb2c)$beta_table["MHV_C5kc_between",2]                    ),
	H1C=c(nrow(zh),length(unique(zh$ZipCode)), fixef(mhb2c)["MHV_C5kc_within"]                                                                        , fixef(mhb2c)["MHV_C5kc_between"]                                                                         ),
	H1L=c(NA      ,NA                        , fixef(mhb2c)["MHV_C5kc_within"]-1.96*summary(mhb2c)$beta_table["MHV_C5kc_within",2]                    , fixef(mhb2c)["MHV_C5kc_between"]-1.96*summary(mhb2c)$beta_table["MHV_C5kc_between",2]                    ),
	H1U=c(NA      ,NA                        , fixef(mhb2c)["MHV_C5kc_within"]+1.96*summary(mhb2c)$beta_table["MHV_C5kc_within",2]                    , fixef(mhb2c)["MHV_C5kc_between"]+1.96*summary(mhb2c)$beta_table["MHV_C5kc_between",2]                    ),
	W2C=c(nrow(zw),mean(zw$RptWr)            ,(fixef(mwb2c)["MHV_C5kc_within"]                                                    )/mean(zw$RptWr)*100,(fixef(mwb2c)["MHV_C5kc_between"]                                                     )/mean(zw$RptWr)*100),
	W2L=c(NA      ,NA                        ,(fixef(mwb2c)["MHV_C5kc_within"]-1.96*summary(mwb2c)$beta_table["MHV_C5kc_within",2])/mean(zw$RptWr)*100,(fixef(mwb2c)["MHV_C5kc_between"]-1.96*summary(mwb2c)$beta_table["MHV_C5kc_between",2])/mean(zw$RptWr)*100),
	W2U=c(NA      ,NA                        ,(fixef(mwb2c)["MHV_C5kc_within"]+1.96*summary(mwb2c)$beta_table["MHV_C5kc_within",2])/mean(zw$RptWr)*100,(fixef(mwb2c)["MHV_C5kc_between"]+1.96*summary(mwb2c)$beta_table["MHV_C5kc_between",2])/mean(zw$RptWr)*100),
	B2C=c(nrow(zb),mean(zb$RptBr)            ,(fixef(mbb2c)["MHV_C5kc_within"]                                                    )/mean(zb$RptBr)*100,(fixef(mbb2c)["MHV_C5kc_between"]                                                     )/mean(zb$RptBr)*100),
	B2L=c(NA      ,NA                        ,(fixef(mbb2c)["MHV_C5kc_within"]-1.96*summary(mbb2c)$beta_table["MHV_C5kc_within",2])/mean(zb$RptBr)*100,(fixef(mbb2c)["MHV_C5kc_between"]-1.96*summary(mbb2c)$beta_table["MHV_C5kc_between",2])/mean(zb$RptBr)*100),
	B2U=c(NA      ,NA                        ,(fixef(mbb2c)["MHV_C5kc_within"]+1.96*summary(mbb2c)$beta_table["MHV_C5kc_within",2])/mean(zb$RptBr)*100,(fixef(mbb2c)["MHV_C5kc_between"]+1.96*summary(mbb2c)$beta_table["MHV_C5kc_between",2])/mean(zb$RptBr)*100),
	H2C=c(nrow(zh),mean(zh$RptHr)            ,(fixef(mhb2c)["MHV_C5kc_within"]                                                    )/mean(zh$RptHr)*100,(fixef(mhb2c)["MHV_C5kc_between"]                                                     )/mean(zh$RptHr)*100),
	H2L=c(NA      ,NA                        ,(fixef(mhb2c)["MHV_C5kc_within"]-1.96*summary(mhb2c)$beta_table["MHV_C5kc_within",2])/mean(zh$RptHr)*100,(fixef(mhb2c)["MHV_C5kc_between"]-1.96*summary(mhb2c)$beta_table["MHV_C5kc_between",2])/mean(zh$RptHr)*100),
	H2U=c(NA      ,NA                        ,(fixef(mhb2c)["MHV_C5kc_within"]+1.96*summary(mhb2c)$beta_table["MHV_C5kc_within",2])/mean(zh$RptHr)*100,(fixef(mhb2c)["MHV_C5kc_between"]+1.96*summary(mhb2c)$beta_table["MHV_C5kc_between",2])/mean(zh$RptHr)*100)
)
table3.32





# Maltreatment Type: Neglect, Physical Abuse, Sexual Abuse (1=raw coefficients;2=coefficients relative to mean Y)
table3.41<-data.table(
	name=c("N1","N2 or MeanY","DHS_HVPrc_within","DHS_HVPrc_between"),
	Neg1C=c(nrow(zn),length(unique(zn$ZipCode)), fixef(mnb2a)["DHS_HVPrc_within"]                                                                         , fixef(mnb2a)["DHS_HVPrc_between"]                                                                          ),
	Neg1L=c(NA      ,NA                        , fixef(mnb2a)["DHS_HVPrc_within"]-1.96*summary(mnb2a)$beta_table["DHS_HVPrc_within",2]                    , fixef(mnb2a)["DHS_HVPrc_between"]-1.96*summary(mnb2a)$beta_table["DHS_HVPrc_between",2]                    ),
	Neg1U=c(NA      ,NA                        , fixef(mnb2a)["DHS_HVPrc_within"]+1.96*summary(mnb2a)$beta_table["DHS_HVPrc_within",2]                    , fixef(mnb2a)["DHS_HVPrc_between"]+1.96*summary(mnb2a)$beta_table["DHS_HVPrc_between",2]                    ),
	Phy1C=c(nrow(zp),length(unique(zp$ZipCode)), fixef(mpb2a)["DHS_HVPrc_within"]                                                                         , fixef(mpb2a)["DHS_HVPrc_between"]                                                                          ),
	Phy1L=c(NA      ,NA                        , fixef(mpb2a)["DHS_HVPrc_within"]-1.96*summary(mpb2a)$beta_table["DHS_HVPrc_within",2]                    , fixef(mpb2a)["DHS_HVPrc_between"]-1.96*summary(mpb2a)$beta_table["DHS_HVPrc_between",2]                    ),
	Phy1U=c(NA      ,NA                        , fixef(mpb2a)["DHS_HVPrc_within"]+1.96*summary(mpb2a)$beta_table["DHS_HVPrc_within",2]                    , fixef(mpb2a)["DHS_HVPrc_between"]+1.96*summary(mpb2a)$beta_table["DHS_HVPrc_between",2]                    ),
	Sex1C=c(nrow(zs),length(unique(zs$ZipCode)), fixef(msb2a)["DHS_HVPrc_within"]                                                                         , fixef(msb2a)["DHS_HVPrc_between"]                                                                          ),
	Sex1L=c(NA      ,NA                        , fixef(msb2a)["DHS_HVPrc_within"]-1.96*summary(msb2a)$beta_table["DHS_HVPrc_within",2]                    , fixef(msb2a)["DHS_HVPrc_between"]-1.96*summary(msb2a)$beta_table["DHS_HVPrc_between",2]                    ),
	Sex1U=c(NA      ,NA                        , fixef(msb2a)["DHS_HVPrc_within"]+1.96*summary(msb2a)$beta_table["DHS_HVPrc_within",2]                    , fixef(msb2a)["DHS_HVPrc_between"]+1.96*summary(msb2a)$beta_table["DHS_HVPrc_between",2]                    ),
	Neg2C=c(nrow(zn),mean(zn$NegTr)            ,(fixef(mnb2a)["DHS_HVPrc_within"]                                                     )/mean(zn$NegTr)*100,(fixef(mnb2a)["DHS_HVPrc_between"]                                                      )/mean(zn$NegTr)*100),
	Neg2L=c(NA      ,NA                        ,(fixef(mnb2a)["DHS_HVPrc_within"]-1.96*summary(mnb2a)$beta_table["DHS_HVPrc_within",2])/mean(zn$NegTr)*100,(fixef(mnb2a)["DHS_HVPrc_between"]-1.96*summary(mnb2a)$beta_table["DHS_HVPrc_between",2])/mean(zn$NegTr)*100),
	Neg2U=c(NA      ,NA                        ,(fixef(mnb2a)["DHS_HVPrc_within"]+1.96*summary(mnb2a)$beta_table["DHS_HVPrc_within",2])/mean(zn$NegTr)*100,(fixef(mnb2a)["DHS_HVPrc_between"]+1.96*summary(mnb2a)$beta_table["DHS_HVPrc_between",2])/mean(zn$NegTr)*100),
	Phy2C=c(nrow(zp),mean(zp$PhyTr)            ,(fixef(mpb2a)["DHS_HVPrc_within"]                                                     )/mean(zp$PhyTr)*100,(fixef(mpb2a)["DHS_HVPrc_between"]                                                      )/mean(zp$PhyTr)*100),
	Phy2L=c(NA      ,NA                        ,(fixef(mpb2a)["DHS_HVPrc_within"]-1.96*summary(mpb2a)$beta_table["DHS_HVPrc_within",2])/mean(zp$PhyTr)*100,(fixef(mpb2a)["DHS_HVPrc_between"]-1.96*summary(mpb2a)$beta_table["DHS_HVPrc_between",2])/mean(zp$PhyTr)*100),
	Phy2U=c(NA      ,NA                        ,(fixef(mpb2a)["DHS_HVPrc_within"]+1.96*summary(mpb2a)$beta_table["DHS_HVPrc_within",2])/mean(zp$PhyTr)*100,(fixef(mpb2a)["DHS_HVPrc_between"]+1.96*summary(mpb2a)$beta_table["DHS_HVPrc_between",2])/mean(zp$PhyTr)*100),
	Sex2C=c(nrow(zs),mean(zs$SexTr)            ,(fixef(msb2a)["DHS_HVPrc_within"]                                                     )/mean(zs$SexTr)*100,(fixef(msb2a)["DHS_HVPrc_between"]                                                      )/mean(zs$SexTr)*100),
	Sex2L=c(NA      ,NA                        ,(fixef(msb2a)["DHS_HVPrc_within"]-1.96*summary(msb2a)$beta_table["DHS_HVPrc_within",2])/mean(zs$SexTr)*100,(fixef(msb2a)["DHS_HVPrc_between"]-1.96*summary(msb2a)$beta_table["DHS_HVPrc_between",2])/mean(zs$SexTr)*100),
	Sex2U=c(NA      ,NA                        ,(fixef(msb2a)["DHS_HVPrc_within"]+1.96*summary(msb2a)$beta_table["DHS_HVPrc_within",2])/mean(zs$SexTr)*100,(fixef(msb2a)["DHS_HVPrc_between"]+1.96*summary(msb2a)$beta_table["DHS_HVPrc_between",2])/mean(zs$SexTr)*100)
)
table3.41





# Maltreatment Type: Neglect, Physical Abuse, Sexual Abuse (1=raw coefficients;2=coefficients relative to mean Y)
table3.42<-data.table(
	name=c("N1","N2 or MeanY","MHV_C5kc_within","MHV_C5kc_between"),
	Neg1C=c(nrow(zn),length(unique(zn$ZipCode)), fixef(mnb2c)["MHV_C5kc_within"]                                                                        , fixef(mnb2c)["MHV_C5kc_between"]                                                                         ),
	Neg1L=c(NA      ,NA                        , fixef(mnb2c)["MHV_C5kc_within"]-1.96*summary(mnb2c)$beta_table["MHV_C5kc_within",2]                    , fixef(mnb2c)["MHV_C5kc_between"]-1.96*summary(mnb2c)$beta_table["MHV_C5kc_between",2]                    ),
	Neg1U=c(NA      ,NA                        , fixef(mnb2c)["MHV_C5kc_within"]+1.96*summary(mnb2c)$beta_table["MHV_C5kc_within",2]                    , fixef(mnb2c)["MHV_C5kc_between"]+1.96*summary(mnb2c)$beta_table["MHV_C5kc_between",2]                    ),
	Phy1C=c(nrow(zp),length(unique(zp$ZipCode)), fixef(mpb2c)["MHV_C5kc_within"]                                                                        , fixef(mpb2c)["MHV_C5kc_between"]                                                                         ),
	Phy1L=c(NA      ,NA                        , fixef(mpb2c)["MHV_C5kc_within"]-1.96*summary(mpb2c)$beta_table["MHV_C5kc_within",2]                    , fixef(mpb2c)["MHV_C5kc_between"]-1.96*summary(mpb2c)$beta_table["MHV_C5kc_between",2]                    ),
	Phy1U=c(NA      ,NA                        , fixef(mpb2c)["MHV_C5kc_within"]+1.96*summary(mpb2c)$beta_table["MHV_C5kc_within",2]                    , fixef(mpb2c)["MHV_C5kc_between"]+1.96*summary(mpb2c)$beta_table["MHV_C5kc_between",2]                    ),
	Sex1C=c(nrow(zs),length(unique(zs$ZipCode)), fixef(msb2c)["MHV_C5kc_within"]                                                                        , fixef(msb2c)["MHV_C5kc_between"]                                                                         ),
	Sex1L=c(NA      ,NA                        , fixef(msb2c)["MHV_C5kc_within"]-1.96*summary(msb2c)$beta_table["MHV_C5kc_within",2]                    , fixef(msb2c)["MHV_C5kc_between"]-1.96*summary(msb2c)$beta_table["MHV_C5kc_between",2]                    ),
	Sex1U=c(NA      ,NA                        , fixef(msb2c)["MHV_C5kc_within"]+1.96*summary(msb2c)$beta_table["MHV_C5kc_within",2]                    , fixef(msb2c)["MHV_C5kc_between"]+1.96*summary(msb2c)$beta_table["MHV_C5kc_between",2]                    ),
	Neg2C=c(nrow(zn),mean(zn$NegTr)            ,(fixef(mnb2c)["MHV_C5kc_within"]                                                    )/mean(zn$NegTr)*100,(fixef(mnb2c)["MHV_C5kc_between"]                                                     )/mean(zn$NegTr)*100),
	Neg2L=c(NA      ,NA                        ,(fixef(mnb2c)["MHV_C5kc_within"]-1.96*summary(mnb2c)$beta_table["MHV_C5kc_within",2])/mean(zn$NegTr)*100,(fixef(mnb2c)["MHV_C5kc_between"]-1.96*summary(mnb2c)$beta_table["MHV_C5kc_between",2])/mean(zn$NegTr)*100),
	Neg2U=c(NA      ,NA                        ,(fixef(mnb2c)["MHV_C5kc_within"]+1.96*summary(mnb2c)$beta_table["MHV_C5kc_within",2])/mean(zn$NegTr)*100,(fixef(mnb2c)["MHV_C5kc_between"]+1.96*summary(mnb2c)$beta_table["MHV_C5kc_between",2])/mean(zn$NegTr)*100),
	Phy2C=c(nrow(zp),mean(zp$PhyTr)            ,(fixef(mpb2c)["MHV_C5kc_within"]                                                    )/mean(zp$PhyTr)*100,(fixef(mpb2c)["MHV_C5kc_between"]                                                     )/mean(zp$PhyTr)*100),
	Phy2L=c(NA      ,NA                        ,(fixef(mpb2c)["MHV_C5kc_within"]-1.96*summary(mpb2c)$beta_table["MHV_C5kc_within",2])/mean(zp$PhyTr)*100,(fixef(mpb2c)["MHV_C5kc_between"]-1.96*summary(mpb2c)$beta_table["MHV_C5kc_between",2])/mean(zp$PhyTr)*100),
	Phy2U=c(NA      ,NA                        ,(fixef(mpb2c)["MHV_C5kc_within"]+1.96*summary(mpb2c)$beta_table["MHV_C5kc_within",2])/mean(zp$PhyTr)*100,(fixef(mpb2c)["MHV_C5kc_between"]+1.96*summary(mpb2c)$beta_table["MHV_C5kc_between",2])/mean(zp$PhyTr)*100),
	Sex2C=c(nrow(zs),mean(zs$SexTr)            ,(fixef(msb2c)["MHV_C5kc_within"]                                                    )/mean(zs$SexTr)*100,(fixef(msb2c)["MHV_C5kc_between"]                                                     )/mean(zs$SexTr)*100),
	Sex2L=c(NA      ,NA                        ,(fixef(msb2c)["MHV_C5kc_within"]-1.96*summary(msb2c)$beta_table["MHV_C5kc_within",2])/mean(zs$SexTr)*100,(fixef(msb2c)["MHV_C5kc_between"]-1.96*summary(msb2c)$beta_table["MHV_C5kc_between",2])/mean(zs$SexTr)*100),
	Sex2U=c(NA      ,NA                        ,(fixef(msb2c)["MHV_C5kc_within"]+1.96*summary(msb2c)$beta_table["MHV_C5kc_within",2])/mean(zs$SexTr)*100,(fixef(msb2c)["MHV_C5kc_between"]+1.96*summary(msb2c)$beta_table["MHV_C5kc_between",2])/mean(zs$SexTr)*100)
)
table3.42





# Export Tables
write.csv(table1   ,"Z:/CDCK01/Analysis/ZipCode/HomeVisit/Tables/table1.csv"   )
write.csv(table2.1 ,"Z:/CDCK01/Analysis/ZipCode/HomeVisit/Tables/table2.1.csv" )
write.csv(table2.2 ,"Z:/CDCK01/Analysis/ZipCode/HomeVisit/Tables/table2.2.csv" )
write.csv(table2.1a,"Z:/CDCK01/Analysis/ZipCode/HomeVisit/Tables/table2.1a.csv" )
write.csv(table2.2a,"Z:/CDCK01/Analysis/ZipCode/HomeVisit/Tables/table2.2a.csv" )
write.csv(table3.11,"Z:/CDCK01/Analysis/ZipCode/HomeVisit/Tables/table3.11.csv")
write.csv(table3.12,"Z:/CDCK01/Analysis/ZipCode/HomeVisit/Tables/table3.12.csv")
write.csv(table3.21,"Z:/CDCK01/Analysis/ZipCode/HomeVisit/Tables/table3.21.csv")
write.csv(table3.22,"Z:/CDCK01/Analysis/ZipCode/HomeVisit/Tables/table3.22.csv")
write.csv(table3.31,"Z:/CDCK01/Analysis/ZipCode/HomeVisit/Tables/table3.31.csv")
write.csv(table3.32,"Z:/CDCK01/Analysis/ZipCode/HomeVisit/Tables/table3.32.csv")
write.csv(table3.41,"Z:/CDCK01/Analysis/ZipCode/HomeVisit/Tables/table3.41.csv")
write.csv(table3.42,"Z:/CDCK01/Analysis/ZipCode/HomeVisit/Tables/table3.42.csv")





# Confirm Exported Tables

# Table 1
mean(zt$RptTr)     ;sd(zt$RptTr)     # "Total CM"
mean(z1$Rpt1r)     ;sd(z1$Rpt1r)     # "Young"
mean(z2$Rpt2r)     ;sd(z2$Rpt2r)     # "Middle"
mean(z3$Rpt3r)     ;sd(z3$Rpt3r)     # "Adolescent"
mean(zm$RptMr)     ;sd(zm$RptMr)     # "Male"
mean(zf$RptFr)     ;sd(zf$RptFr)     # "Female"
mean(zw$RptWr)     ;sd(zw$RptWr)     # "White"
mean(zb$RptBr)     ;sd(zb$RptBr)     # "Black"
mean(zh$RptHr)     ;sd(zh$RptHr)     # "Latino"
mean(zn$NegTr)     ;sd(zn$NegTr)     # "Neglect"
mean(zp$PhyTr)     ;sd(zp$PhyTr)     # "Physical Abuse"
mean(zs$SexTr)     ;sd(zs$SexTr)     # "Sexual Abuse"
mean(zt$DHS_HVPr)  ;sd(zt$DHS_HVPr)  # "DHS_HVPr"
mean(zt$MHV_C5k)   ;sd(zt$MHV_C5k)   # "MHV_C5k"
mean(zt$RPovT)     ;sd(zt$RPovT)     # "Relative poverty"
mean(zt$HValueT10k);sd(zt$HValueT10k)# "Median House Value"
mean(zt$VacantT)   ;sd(zt$VacantT)   # "% Vacant"
mean(zt$CPopBP)    ;sd(zt$CPopBP)    # "% Black child"
mean(zt$CPopHP)    ;sd(zt$CPopHP)    # "% Hispanic child"
mean(zt$FBornT)    ;sd(zt$FBornT)    # "% Foreign-Born"
mean(zt$ChildPT)   ;sd(zt$ChildPT)   # "% Child"
mean(zt$ElderT)    ;sd(zt$ElderT)    # "% Elderly"
mean(zt$MalePT)    ;sd(zt$MalePT)    # "% Male"
mean(zt$DisablT)   ;sd(zt$DisablT)   # "% Disabled"
mean(zt$MoveT)     ;sd(zt$MoveT)     # "% Moved"
prop.table(table(zt$USDA_RUC))*100   # "Large Urban"; "Small Urban"; "Rural"
prop.table(table(zt$Yearf))*100      # "2011"; "2012"; "2013"; "2014"; "2015"; "2016"; "2017"; "2018"

# Table 2.1
mtb0a
mtb1a
mtb2a
mtb4a
mtb5a

# Table 2.2
mtb0c
mtb1c
mtb2c
mtb4c
mtb5c

# Table 3.11
m1b2a
m2b2a
m3b2a

# Table 3.12
m1b2c
m2b2c
m3b2c

# Table 3.21
mmb2a
mfb2a

# Table 3.22
mmb2c
mfb2c

# Table 3.31
mwb2a
mbb2a
mhb2a

# Table 3.32
mwb2c
mbb2c
mhb2c

# Table 3.41
mnb2a
mpb2a
msb2a

# Table 3.42
mnb2c
mpb2c
msb2c



skewness(resid(mtb2a))
skewness(resid(mtb2c))
skewness(resid(m1b2a))
skewness(resid(m2b2a))
skewness(resid(m3b2a))
skewness(resid(m1b2c))
skewness(resid(m2b2c))
skewness(resid(m3b2c))
skewness(resid(mmb2a))
skewness(resid(mfb2a))
skewness(resid(mmb2c))
skewness(resid(mfb2c))
skewness(resid(mnb2a))
skewness(resid(mpb2a))
skewness(resid(msb2a))
skewness(resid(mnb2c))
skewness(resid(mpb2c))
skewness(resid(msb2c))








